--ТАБЛИЦЫ.
--Группа доступа. Нужна, потому что может быть создано несколько ролей с одними и теми же правами.
CREATE TABLE ACCESS_GROUP
(
    ID             BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU        TEXT NOT NULL,
    NAME_EN        TEXT NOT NULL,
    DESCRIPTION_RU TEXT NOT NULL,
    DESCRIPTION_EN TEXT NOT NULL,
    PRIMARY KEY (ID)
);

--Метод авторизации клиента в системе (Банковская карта, Карта лояльности).
CREATE TABLE AUTHORIZATION_METHOD
(
    ID      BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU TEXT NOT NULL,
    NAME_EN TEXT NOT NULL,
    PRIMARY KEY (ID)
);

--Распределение банковских идентификационных номеров (БИН) по сегменту.
CREATE TABLE BANK_CARD_SEGMENTATION
(
    ID                BIGINT GENERATED BY DEFAULT AS IDENTITY,
    START_NUMBER      BIGINT NOT NULL,
    HANDBOOKS_KIT_ID  BIGINT NOT NULL,
    END_NUMBER        BIGINT NOT NULL,
    CLIENT_SEGMENT_ID BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

--Схема обслуживания.
CREATE TABLE CARE_SCHEME
(
    ID                              BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU                         TEXT,
    NAME_EN                         TEXT,
    NAME_CUSTOM_LANGUAGE            TEXT,
    HANDBOOKS_KIT_ID                BIGINT  NOT NULL,
    TICKET_TEMPLATES_KIT_ID         BIGINT  NOT NULL,
    GROUP_QUALIFICATION_FILLED      BOOLEAN NOT NULL,
    GROUPING_FILLED                 BOOLEAN NOT NULL,
    PRIMARY KEY (ID)
);

--Настройки уровня Центрального Администратора.
CREATE TABLE CENTRAL_SETTING
(
    ID             BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU        TEXT   NOT NULL,
    NAME_EN        TEXT   NOT NULL,
    DESCRIPTION_RU TEXT   NOT NULL,
    DESCRIPTION_EN TEXT   NOT NULL,
    CODE           TEXT   NOT NULL,
    TYPE_ID        BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

--Значение, выставленное для центральной настройки (CentralSetting) на уровне роли Центрального администратора.
--Поля valueCommon, valueRu, valueEn, valueCustomLanguage1, valueCustomLanguage2, valueCustomLanguage3 добавлены в @EqualsAndHashCode.Include для поддержки нескольких
-- значений. Например, настройка "Отправлять смс с напоминанием о предстоящем визите" позволяет добавить несколько напоминаний (одна и та же настройка) с разным временем
-- отправки. Аналогично настройка "Доступный для выбора финальный статус клиента при обслуживании в УТО" позволяет добавить несколько финальных статусов в выпадающий
-- список на странице УТО.
CREATE TABLE CENTRAL_SETTING_VALUE
(
    ID                     BIGINT GENERATED BY DEFAULT AS IDENTITY,
    CENTRAL_SETTING_ID     BIGINT NOT NULL,
    VALUE_COMMON           TEXT,
    VALUE_RU               TEXT,
    VALUE_EN               TEXT,
    VALUE_CUSTOM_LANGUAGE1 TEXT,
    VALUE_CUSTOM_LANGUAGE2 TEXT,
    VALUE_CUSTOM_LANGUAGE3 TEXT,
    PRIMARY KEY (ID)
);

--Город
CREATE TABLE CITY
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    REGION_ID            BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

--Клиент. Хранит только активных клиентов, т.е. записанных, ожидающих и обслуживающихся.
CREATE TABLE CLIENT
(
    ID                                BIGINT GENERATED BY DEFAULT AS IDENTITY,
    DEPARTMENT_ID                     BIGINT  NOT NULL,
    TICKET_LETTER                     TEXT    NOT NULL,
    TICKET_NUMBER                     INTEGER NOT NULL,
    CLIENT_SEGMENT_ID                 BIGINT  NOT NULL,
    AUTHORIZATION_METHOD_ID           BIGINT  NOT NULL,
    AUTHORIZATION_STRING1             TEXT,
    AUTHORIZATION_STRING2             TEXT,
    LAST_WORKPLACE_ID                 BIGINT,
    USER_ID                           BIGINT,
    OPERATION_NODE_ID                 BIGINT  NOT NULL,
    LAST_OPERATION_NODE_ID            BIGINT,
    GROUP_QUALIFICATION_ID            BIGINT,
    CALL_COUNT                        INTEGER,
    STATUS_ID                         BIGINT  NOT NULL,
    WITH_RETURN                       BOOLEAN,
    RETURN_POSITION                   INTEGER,
    WAITING_TIME                      BIGINT,
    SERVICE_TIME                      BIGINT,
    FULL_NAME                         TEXT,
    SPECIAL_REGISTRATION_DATE_TIME    TIMESTAMP,
    CALL_DATE_TIME                    TIMESTAMP,
    CALL_AFTER_POSTPONE_DATE_TIME     TIMESTAMP,
    REGISTRATION_DATE_TIME            TIMESTAMP,
    LAST_SERVICE_DATE_TIME            TIMESTAMP,
    LAST_RETURN_AFTER_RESET_DATE_TIME TIMESTAMP,
    FACTOR                            BIGINT,
    MULTIOPERATION_NUMBER             BIGINT,
    PRIMARY KEY (ID)
);

--Сегмент клиента.
CREATE TABLE CLIENT_SEGMENT
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    BY_DEFAULT           BOOLEAN NOT NULL,
    HANDBOOKS_KIT_ID     BIGINT  NOT NULL,
    EDITABLE             BOOLEAN,
    PRIMARY KEY (ID)
);

--Статус клиента.
CREATE TABLE CLIENT_STATUS
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT    NOT NULL,
    NAME_EN              TEXT    NOT NULL,
    DESCRIPTION_RU       TEXT    NOT NULL,
    DESCRIPTION_EN       TEXT    NOT NULL,
    REMOTE_SERVICE_POINT BOOLEAN NOT NULL,
    PRIMARY KEY (ID)
);

--Пакет конфигураций.
CREATE TABLE CONFIGURATION_PACKAGE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    HANDBOOKS_KIT_ID     BIGINT    NOT NULL,
    OPERATION_TREE_ID    BIGINT    NOT NULL,
    CARE_SCHEME_ID       BIGINT    NOT NULL,
    CREATE_DATE_TIME     TIMESTAMP NOT NULL,
    PRIMARY KEY (ID)
);

-- История применения пакета конфигураций.
CREATE TABLE CONFIGURATION_PACKAGE_USAGE
(
    ID                       BIGINT GENERATED BY DEFAULT AS IDENTITY,
    CONFIGURATION_PACKAGE_ID BIGINT    NOT NULL,
    DEPARTMENT_ID            BIGINT    NOT NULL,
    APPLY_DATE_TIME          TIMESTAMP NOT NULL,
    PRIMARY KEY (ID)
);

-- Значение, выставленное для настройки устройства (DeviceSetting) на уровне роли Центрального администратора. Входит в набор настроек SettingKit, который используется
--  для обновления отделений. После обновления отделений все значения настроек (DefaultDeviceSettingValue) будут являться настройками по умолчанию для устройств. Эти
--  значения по умолчанию могут быть переопределены на уровне конкретного устройства с помощью RedefinedDeviceSettingValue.
-- Поля valueCommon, valueRu, valueEn, valueCustomLanguage1, valueCustomLanguage2, valueCustomLanguage3 добавлены в @EqualsAndHashCode.Include для поддержки нескольких
--  значений. Например, настройка "Доступная для выбора причина перерыва" позволяет задать несколько значений. Уникально идентифицироваться они будут не только по
--  deviceSetting и settingKit, но и по значению.
CREATE TABLE DEFAULT_DEVICE_SETTING_VALUE
(
    ID                     BIGINT GENERATED BY DEFAULT AS IDENTITY,
    DEVICE_SETTING_ID      BIGINT NOT NULL,
    SETTINGS_KIT_ID        BIGINT NOT NULL,
    VALUE_COMMON           TEXT,
    VALUE_RU               TEXT,
    VALUE_EN               TEXT,
    VALUE_CUSTOM_LANGUAGE1 TEXT,
    VALUE_CUSTOM_LANGUAGE2 TEXT,
    VALUE_CUSTOM_LANGUAGE3 TEXT,
    PRIMARY KEY (ID)
);

--Отделение. Поддерживает иерархию.
CREATE TABLE DEPARTMENT
(
    ID                            BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU                       TEXT,
    NAME_EN                       TEXT,
    NAME_CUSTOM_LANGUAGE          TEXT,
    VISIBLE_IN_PRE_REGISTRATION   BOOLEAN NOT NULL,
    PARENT_ID                     BIGINT,
    ADDRESS                       TEXT    NOT NULL,
    PHONE                         TEXT,
    HEAD                          TEXT,
    REMOTE_SERVICE_POINT          BOOLEAN NOT NULL,
    HANDBOOKS_KIT_ID              BIGINT,
    OPERATION_TREE_ID             BIGINT,
    CARE_SCHEME_ID                BIGINT,
    SETTINGS_KIT_ID               BIGINT,
    SCHEDULE_ID                   BIGINT  NOT NULL,
    CURRENT_DISPATCHING_SCHEME_ID BIGINT,
    CITY_ID                       BIGINT  NOT NULL,
    LANGUAGE_ID                   BIGINT  NOT NULL,
    PRIMARY KEY (ID)
);

--Устройство.
CREATE TABLE DEVICE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    ACTIVE               BOOLEAN NOT NULL,
    DEPARTMENT_ID        BIGINT,
    DEVICE_TYPE_ID       BIGINT  NOT NULL,
    WORKPLACE_ID         BIGINT,
    PRIMARY KEY (ID)
);

--Настройка для устройства конкретного типа. Значение настройки по умолчанию выставляется на уровне центрального администратора в DefaultDeviceSettingValue.
-- Это значение может переопределяться для конкретного устройства в RedefinedDeviceSettingValue.
CREATE TABLE DEVICE_SETTING
(
    ID             BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU        TEXT   NOT NULL,
    DEVICE_TYPE_ID BIGINT NOT NULL,
    NAME_EN        TEXT   NOT NULL,
    DESCRIPTION_RU TEXT   NOT NULL,
    DESCRIPTION_EN TEXT   NOT NULL,
    CODE           TEXT   NOT NULL,
    TYPE_ID        BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

--Тип устройства.
CREATE TABLE DEVICE_TYPE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT NOT NULL,
    NAME_EN              TEXT NOT NULL,
    NAME_CUSTOM_LANGUAGE TEXT,
    PRIMARY KEY (ID)
);

-- Схема диспетчеризации. Зелёная, жёлтая, красная.
CREATE TABLE DISPATCHING_SCHEME
(
    ID      BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU TEXT NOT NULL,
    NAME_EN TEXT NOT NULL,
    PRIMARY KEY (ID)
);

-- Аудит.
--
-- ПОЛЯ, КОТОРЫЕ ЕСТЬ В EVENT В ЦА, НО УБРАНЫ ОТСЮДА:
--
-- аналог в старом СУО - Events.Id
-- NEW! Это поле более не имеет смысла, т.к. ID единые для всех отделений.
-- externalId
--
-- номер талона клиента, например, А001, Б0002. Аналог в старом СУО Events.ClientName
-- NEW! Поле заменено на client_TICKET_LETTER + client_TICKET_NUMBER
-- client_name
--
-- в AuditMapping.xml помечен как «идентификатор устройства». Аналог в старом СУО – audit.Events.Answer
-- device_state_type
--
-- в зависимости от типа события сюда могу писаться разные данные. В базе данных МФЦ всегда 0.
-- В get_sessions, events_after_insert значения crm_category_value, max_WAITING_TIME могут браться из note_float по определённой логике.
-- Аналог в старом СУО – audit.Events.noteFloat
-- note_float
--
-- в зависимости от типа события сюда могу писаться разные данные. В базе данных МФЦ принимает значения от 0 до 4.
-- По словам Распутина при разных событиях туда записываются разные данные: тип авторизации, тип вызова, приоритет. Аналог в старом СУО – audit.Events.noteNumber
-- note_number
--
-- в зависимости от типа события сюда могут писаться разные данные. В 99% случаев это код предварительной регистрации (6 цифр, например 290352, 000032, 752684).
-- Если в очередь встал льготник – значение будет veteran. И т.д. Аналог в старом СУО – audit.Events.noteString
-- NEW! Это поле было заменено на client_confirmation_CODE + veteran
-- note_string
--
-- в базе данных МФЦ принимает значения от 0 до 6000. Аналог в старом СУО – audit.Events.noteTime
-- note_time
--
-- *QMS-9945 Интеграция ЦА с ЕИАП (из ЧТЗ)
-- synced
--
--
--
-- ПОЛЯ, КОТОРЫХ НЕТ В ЦА event, НО БЫЛИ ДОБАВЛЕНЫ СЮДА:
-- AUTHORIZATION_METHOD_ID
-- workplace_ID
-- work_mode_ID int8
-- voting_score int8
CREATE TABLE EVENT
(
    ID                                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    DESCRIPTION                          TEXT   NOT NULL,
    EVENT_TYPE_ID                        BIGINT NOT NULL,
    EVENT_TYPE_NAME_RU                   TEXT   NOT NULL,
    EVENT_TYPE_NAME_EN                   TEXT   NOT NULL,
    CLIENT_ID                            BIGINT,
    CLIENT_TICKET_LETTER                 TEXT,
    CLIENT_TICKET_NUMBER                 INTEGER,
    CLIENT_SEGMENT_ID                    BIGINT,
    CLIENT_CONFIRMATION_CODE             TEXT,
    CLIENT_VETERAN                       BOOLEAN,
    AUTHORIZATION_METHOD_ID              BIGINT,
    DEPARTMENT_ID                        BIGINT,
    WORKPLACE_ID                         BIGINT,
    DEVICE_TYPE_ID                       BIGINT,
    DEVICE_ID                            BIGINT,
    DEVICE_NAME_RU                       TEXT,
    DEVICE_NAME_EN                       TEXT,
    DEVICE_NAME_CUSTOM_LANGUAGE          TEXT,
    USER_ID                              BIGINT,
    USER_LOGIN                           TEXT,
    USER_LAST_NAME                       TEXT,
    USER_FIRST_NAME                      TEXT,
    USER_MIDDLE_NAME                     TEXT,
    OPERATION_ID                         BIGINT,
    OPERATION_NAME_RU                    TEXT,
    OPERATION_NAME_EN                    TEXT,
    OPERATION_NAME_CUSTOM_LANGUAGE1      TEXT,
    OPERATION_NAME_CUSTOM_LANGUAGE2      TEXT,
    OPERATION_NAME_CUSTOM_LANGUAGE3      TEXT,
    GROUP_QUALIFICATION_ID               BIGINT,
    OPERATION_GROUP_NAME_RU              TEXT,
    OPERATION_GROUP_NAME_EN              TEXT,
    OPERATION_GROUP_NAME_CUSTOM_LANGUAGE TEXT,
    DISPATCHING_SCHEME_ID                BIGINT,
    CONFIGURATION_PACKAGE_ID             BIGINT,
    CONFIGURATION_PACKAGE_NAME_RU        TEXT,
    HANDBOOKS_KIT_ID                     BIGINT,
    HANDBOOKS_KIT_NAME_RU                TEXT,
    OPERATION_TREE_ID                    BIGINT,
    OPERATION_TREE_NAME_RU               TEXT,
    CARE_SCHEME_ID                       BIGINT,
    CARE_SCHEME_NAME_RU                  TEXT,
    VOTING_SCORE                         INTEGER,
    DATE_TIME_COLUMN                     TIMESTAMP,
    PRIMARY KEY (ID)
);

-- Тип события.
CREATE TABLE EVENT_TYPE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT NOT NULL,
    NAME_EN              TEXT NOT NULL,
    NAME_CUSTOM_LANGUAGE TEXT,
    PRIMARY KEY (ID)
);

-- Группа. Вынесена отдельно из GroupQualification, чтобы на основе одной и той же Group можно было создать несколько GroupQualification, при этом не вбивая каждый раз имя
-- группы. Тем более, что имя на нескольких языках.
CREATE TABLE GROUP_TABLE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    HANDBOOKS_KIT_ID     BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

-- Распределение по группам. То, что в ЦА называется Группировка клиентов. Для конкретных услуги, сегмента клиента, категории клиента назначение группы, рекламного
-- текста на талоне.
CREATE TABLE GROUPING_TABLE
(
    ID                     BIGINT GENERATED BY DEFAULT AS IDENTITY,
    CARE_SCHEME_ID         BIGINT NOT NULL,
    OPERATION_TABLE_ID     BIGINT NOT NULL,
    CLIENT_SEGMENT_ID      BIGINT NOT NULL,
    GROUP_QUALIFICATION_ID BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

-- Определение группы. Используется в Grouping для назначения конкретным Операции, Сегменту клиента, Категории клиента. Вынесена отдельно из Group, чтобы на основе одной и
-- той же Group можно было создать несколько GroupQualification, при этом не вбивая каждый раз имя группы.
CREATE TABLE GROUP_QUALIFICATION
(
    ID                         BIGINT GENERATED BY DEFAULT AS IDENTITY,
    CARE_SCHEME_ID             BIGINT NOT NULL,
    GROUP_ID                   BIGINT,
    FACTOR                     BIGINT NOT NULL,
    WAIT_MAX_TIME              BIGINT NOT NULL,
    TICKET_TEMPLATE_ID         BIGINT,
    PROMO_TEXT_RU              TEXT,
    PROMO_TEXT_EN              TEXT,
    PROMO_TEXT_CUSTOM_LANGUAGE TEXT,
    LETTER                     TEXT   NOT NULL,
    PRIMARY KEY (ID)
);

-- Набор справочников. На его основе строится дерево услуг и схема диспетчеризации.
CREATE TABLE HANDBOOKS_KIT
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    PRIMARY KEY (ID)
);

--Список языков (ISO 639-1).
CREATE TABLE LANGUAGE_TABLE
(
    ID          BIGINT GENERATED BY DEFAULT AS IDENTITY,
    CODE        TEXT NOT NULL,
    NAME_RU     TEXT NOT NULL,
    NAME_EN     TEXT NOT NULL,
    NAME_ORIGIN TEXT NOT NULL,
    PRIMARY KEY (ID)
);

-- Распределение номеров карт лояльности по сегменту.
CREATE TABLE LOYALTY_CARD_SEGMENTATION
(
    ID                BIGINT GENERATED BY DEFAULT AS IDENTITY,
    START_NUMBER      BIGINT NOT NULL,
    HANDBOOKS_KIT_ID  BIGINT NOT NULL,
    END_NUMBER        BIGINT NOT NULL,
    CLIENT_SEGMENT_ID BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

-- Нормативное время обслуживания по конкретной услуге и схеме диспетчеризации.
CREATE TABLE NORMATIVE_TIME
(
    ID                    BIGINT GENERATED BY DEFAULT AS IDENTITY,
    OPERATION_TABLE_ID    BIGINT NOT NULL,
    DISPATCHING_SCHEME_ID BIGINT NOT NULL,
    NORMATIVE_TIME        BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

-- Услуга.
CREATE TABLE OPERATION_TABLE
(
    ID                               BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU                          TEXT,
    NAME_EN                          TEXT,
    NAME_CUSTOM_LANGUAGE1            TEXT,
    NAME_CUSTOM_LANGUAGE2            TEXT,
    NAME_CUSTOM_LANGUAGE3            TEXT,
    DISPLAY_NAME_RU                  TEXT,
    DISPLAY_NAME_EN                  TEXT,
    DISPLAY_NAME_CUSTOM_LANGUAGE1    TEXT,
    DISPLAY_NAME_CUSTOM_LANGUAGE2    TEXT,
    DISPLAY_NAME_CUSTOM_LANGUAGE3    TEXT,
    DESCRIPTION_RU                   TEXT,
    DESCRIPTION_EN                   TEXT,
    DESCRIPTION_CUSTOM_LANGUAGE1     TEXT,
    DESCRIPTION_CUSTOM_LANGUAGE2     TEXT,
    DESCRIPTION_CUSTOM_LANGUAGE3     TEXT,
    INFO                             BOOLEAN NOT NULL,
    INFO_MESSAGE                     TEXT,
    VISIBLE_IN_PRE_REGISTRATION      BOOLEAN NOT NULL,
    PRE_REGISTRATION_INTERVAL_LENGTH INTEGER,
    ICON_FILE_NAME                   TEXT,
    HANDBOOKS_KIT_ID                 BIGINT  NOT NULL,
    PRIMARY KEY (ID)
);

-- Узел дерева услуг (услуга или папка в дереве).
CREATE TABLE OPERATION_NODE
(
    ID                             BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU                        TEXT,
    NAME_EN                        TEXT,
    NAME_CUSTOM_LANGUAGE1          TEXT,
    NAME_CUSTOM_LANGUAGE2          TEXT,
    NAME_CUSTOM_LANGUAGE3          TEXT,
    DISPLAY_NAME_RU                TEXT,
    DISPLAY_NAME_EN                TEXT,
    DISPLAY_NAME_CUSTOM_LANGUAGE1  TEXT,
    DISPLAY_NAME_CUSTOM_LANGUAGE2  TEXT,
    DISPLAY_NAME_CUSTOM_LANGUAGE3  TEXT,
    DESCRIPTION_RU                 TEXT,
    DESCRIPTION_EN                 TEXT,
    DESCRIPTION_CUSTOM_LANGUAGE1   TEXT,
    DESCRIPTION_CUSTOM_LANGUAGE2   TEXT,
    DESCRIPTION_CUSTOM_LANGUAGE3   TEXT,
    PARENT_ID                      BIGINT,
    ORDER_NUMBER                   INTEGER NOT NULL,
    OPERATION_TREE_ID              BIGINT  NOT NULL,
    OPERATION_ID                   BIGINT,
    SCHEDULE_ID                    BIGINT,
    PRE_REG_LIMIT_PER_INTERVAL     INTEGER,
    TICKET_LIMIT                   INTEGER,
    LIVE_QUEUE_TICKET_LIMIT        INTEGER,
    PRE_REG_TICKET_LIMIT           INTEGER,
    PRE_REG_INTERNET_TICKET_LIMIT  INTEGER,
    PRE_REG_TICKET_KIOSK_LIMIT     INTEGER,
    PRE_REG_ADMIN_MOD_TICKET_LIMIT INTEGER,
    PRIMARY KEY (ID)
);

-- Активность и видимость узлов дерева услуг.
CREATE TABLE OPERATION_NODE_AVAILABILITY
(
    ID                    BIGINT GENERATED BY DEFAULT AS IDENTITY,
    CLIENT_SEGMENT_ID     BIGINT  NOT NULL,
    OPERATION_NODE_ID     BIGINT  NOT NULL,
    DISPATCHING_SCHEME_ID BIGINT  NOT NULL,
    ACTIVE                BOOLEAN NOT NULL,
    VISIBLE               BOOLEAN NOT NULL,
    PRIMARY KEY (ID)
);

-- Дерево услуг.
CREATE TABLE OPERATION_TREE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    HANDBOOKS_KIT_ID     BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

-- Способ постановки клиента в очередь.
CREATE TABLE ORIGINATOR_TYPE
(
    ID      BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU TEXT,
    NAME_EN TEXT,
    PRIMARY KEY (ID)
);

-- Ресурс операторов для предварительной записи.
CREATE TABLE PRE_REG_OPERATOR_RESOURCE
(
    ID            BIGINT GENERATED BY DEFAULT AS IDENTITY,
    DEPARTMENT_ID BIGINT NOT NULL,
    ROLE_ID       BIGINT NOT NULL,
    DAY_OF_WEEK   INTEGER,
    RESOURCE      INTEGER,
    PRIMARY KEY (ID)
);

-- Приоритет. Используется в RoleGroupAssignment. Значения ID: 1 - Основная; 2 - Дополнительная; 3 - Не обслуживается.
CREATE TABLE PRIORITY
(
    ID      BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU TEXT,
    NAME_EN TEXT,
    PRIMARY KEY (ID)
);

-- Переопределенное на уровне конкретного устройства значение настройки.
-- Поля valueCommon, valueRu, valueEn, valueCustomLanguage1, valueCustomLanguage2, valueCustomLanguage3 добавлены в @EqualsAndHashCode.Include для поддержки нескольких
--  значений. Например, настройка "Доступная для выбора причина перерыва" позволяет задать несколько значений. Уникально идентифицироваться они будут не только по
--  deviceSetting и settingKit, но и по значению.
CREATE TABLE REDEFINED_DEVICE_SETTING_VALUE
(
    ID                     BIGINT GENERATED BY DEFAULT AS IDENTITY,
    DEVICE_SETTING_ID      BIGINT NOT NULL,
    DEVICE_ID              BIGINT NOT NULL,
    VALUE_COMMON           TEXT,
    VALUE_RU               TEXT,
    VALUE_EN               TEXT,
    VALUE_CUSTOM_LANGUAGE1 TEXT,
    VALUE_CUSTOM_LANGUAGE2 TEXT,
    VALUE_CUSTOM_LANGUAGE3 TEXT,
    PRIMARY KEY (ID)
);

--Refresh-токен для аутентификации и авторизации.
CREATE TABLE REFRESH_TOKEN
(
    ID           BIGINT GENERATED BY DEFAULT AS IDENTITY,
    USER_ID      BIGINT,
    TOKEN        TEXT,
    EXPIRY_DATE  TIMESTAMP,
    PROJECT_NAME TEXT,
    PRIMARY KEY (ID)
);

-- Список регионов в стране.
CREATE TABLE REGION
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    TIMEZONE_ID          BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

-- Предварительная запись.
CREATE TABLE REGISTRATION
(
    ID                       BIGINT GENERATED BY DEFAULT AS IDENTITY,
    CONFIRMATION_CODE        INTEGER   NOT NULL,
    DEPARTMENT_ID            BIGINT    NOT NULL,
    PHONE                    TEXT      NOT NULL,
    OPERATION_NODE_ID        BIGINT    NOT NULL,
    FULL_NAME                TEXT      NOT NULL,
    STATUS_ID                BIGINT    NOT NULL,
    SMS_COUNT                INTEGER   NOT NULL,
    ORIGINATOR_TYPE_ID       BIGINT    NOT NULL,
    CLIENT_COMMENT           TEXT,
    REGISTERED_TO_LIVE_QUEUE BOOLEAN,
    REGISTRATION_DATE_TIME   TIMESTAMP NOT NULL,
    START_SERVICE_DATE_TIME  TIMESTAMP,
    END_SERVICE_DATE_TIME    TIMESTAMP,
    STATUS_RSP               BIGINT,
    PRIMARY KEY (ID)
);

CREATE TABLE REGISTRATION_STATISTICS
(
    ID                          BIGINT GENERATED BY DEFAULT AS IDENTITY,
    OPERATION_NODE_ID           BIGINT    NOT NULL,
    ORIGINATOR_TYPE_ID          BIGINT    NOT NULL,
    FOR_PRE_REGISTRATION        BOOLEAN   NOT NULL,
    LAST_REGISTRATION_DATE_TIME TIMESTAMP NOT NULL,
    REGISTRATIONS_PER_DAY_COUNT BIGINT    NOT NULL,
    PRIMARY KEY (ID)
);

-- Роль.
CREATE TABLE ROLE_TABLE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    ACCESS_GROUP_ID      BIGINT NOT NULL,
    EDITABLE             BOOLEAN,
    PRIMARY KEY (ID)
);

-- Назначение групп ролям. Для различных схем диспетчеризации.
CREATE TABLE ROLE_GROUP_ASSIGNMENT
(
    ID                     BIGINT GENERATED BY DEFAULT AS IDENTITY,
    ROLE_ID                BIGINT NOT NULL,
    GROUP_QUALIFICATION_ID BIGINT NOT NULL,
    DISPATCHING_SCHEME_ID  BIGINT NOT NULL,
    PRIORITY_ID            BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

-- Режим работы.
CREATE TABLE SCHEDULE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    PRIMARY KEY (ID)
);

--График работы для одного дня недели.
CREATE TABLE SCHEDULE_DAY_OF_WEEK
(
    ID               BIGINT GENERATED BY DEFAULT AS IDENTITY,
    DAY_OF_WEEK      INTEGER NOT NULL,
    SCHEDULE_ID      BIGINT  NOT NULL,
    WORKING          BOOLEAN NOT NULL,
    START_TIME       TIME,
    END_TIME         TIME,
    LUNCH            BOOLEAN,
    LUNCH_START_TIME TIME,
    LUNCH_END_TIME   TIME,
    PRIMARY KEY (ID)
);

-- Исключение из графика работы.
CREATE TABLE SCHEDULE_EXCLUSION
(
    ID               BIGINT GENERATED BY DEFAULT AS IDENTITY,
    DATE_COLUMN      DATE    NOT NULL,
    SCHEDULE_ID      BIGINT  NOT NULL,
    HOLIDAY          BOOLEAN NOT NULL,
    START_TIME       TIME,
    END_TIME         TIME,
    LUNCH            BOOLEAN,
    LUNCH_START_TIME TIME,
    LUNCH_END_TIME   TIME,
    PRIMARY KEY (ID)
);

-- Набор настроек.
CREATE TABLE SETTINGS_KIT
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    APPLY_DATE_TIME      TIMESTAMP,
    PRIMARY KEY (ID)
);

-- Шаблон талона.
CREATE TABLE TICKET_TEMPLATE
(
    ID                      BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU                 TEXT,
    NAME_EN                 TEXT,
    NAME_CUSTOM_LANGUAGE    TEXT,
    PATTERN_RU              TEXT,
    PATTERN_EN              TEXT,
    PATTERN_CUSTOM_LANGUAGE TEXT,
    TICKET_TEMPLATES_KIT_ID BIGINT NOT NULL,
    PRIMARY KEY (ID)
);

-- Набор шаблонов талонов.
CREATE TABLE TICKET_TEMPLATES_KIT
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    PRIMARY KEY (ID)
);

-- Часовые пояса. Используются для определения часового сдвига для местного времени.
CREATE TABLE TIMEZONE
(
    ID        BIGINT GENERATED BY DEFAULT AS IDENTITY,
    CODE      TEXT    NOT NULL,
    BASE      INTEGER NOT NULL,
    DST_SHIFT INTEGER NOT NULL,
    PRIMARY KEY (ID)
);

--Даты перехода на зимнее и обратно на летнее время для таймзон по годам.
--Даты переходов на зимнее и летнее время даже в пределах одной таймзоны могут отличаться от года к году.
CREATE TABLE TIMEZONE_YEAR
(
    ID          BIGINT GENERATED BY DEFAULT AS IDENTITY,
    TIMEZONE_ID BIGINT    NOT NULL,
    YEAR_COLUMN INTEGER   NOT NULL,
    WINTER      TIMESTAMP NOT NULL,
    SUMMER      TIMESTAMP NOT NULL,
    PRIMARY KEY (ID)
);

CREATE TABLE TYPE_TABLE
(
    ID          BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_COLUMN TEXT NOT NULL,
    PRIMARY KEY (ID)
);

-- Пользователь. Оператор или администратор.
CREATE TABLE USER_TABLE
(
    ID                           BIGINT GENERATED BY DEFAULT AS IDENTITY,
    LOGIN_COLUMN                 TEXT   NOT NULL,
    LAST_NAME                    TEXT   NOT NULL,
    FIRST_NAME                   TEXT   NOT NULL,
    MIDDLE_NAME                  TEXT,
    PASSWORD                     TEXT   NOT NULL,
    ADMIN_STATUS_ID              BIGINT NOT NULL,
    OPERATOR_STATUS_ID           BIGINT NOT NULL,
    PHOTO_FILE_NAME              TEXT,
    DEPARTMENT_ID                BIGINT,
    WORKPLACE_ID                 BIGINT,
    AUTHORIZATION_ROLE_ID        BIGINT,
    LANGUAGE_ID                  BIGINT NOT NULL,
    STATUS_LAST_CHANGE_DATE_TIME TIMESTAMP,
    PRIMARY KEY (ID)
);

--Связь многие-ко-многим между USER_TABLE и ROLE_TABLE.
CREATE TABLE USER_ROLE
(
    USER_ID BIGINT NOT NULL,
    ROLE_ID BIGINT NOT NULL,
    PRIMARY KEY (USER_ID, ROLE_ID)
);

-- Статус пользователя.
CREATE TABLE OPERATOR_STATUS
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT    NOT NULL,
    NAME_EN              TEXT    NOT NULL,
    DESCRIPTION_RU       TEXT    NOT NULL,
    DESCRIPTION_EN       TEXT    NOT NULL,
    REMOTE_SERVICE_POINT BOOLEAN NOT NULL,
    PRIMARY KEY (ID)
);

-- Статус пользователя.
CREATE TABLE ADMIN_STATUS
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT    NOT NULL,
    NAME_EN              TEXT    NOT NULL,
    DESCRIPTION_RU       TEXT    NOT NULL,
    DESCRIPTION_EN       TEXT    NOT NULL,
    REMOTE_SERVICE_POINT BOOLEAN NOT NULL,
    PRIMARY KEY (ID)
);

-- Рабочее место. Выбирается пользователем при авторизации.
CREATE TABLE WORKPLACE
(
    ID                   BIGINT GENERATED BY DEFAULT AS IDENTITY,
    NAME_RU              TEXT,
    NAME_EN              TEXT,
    NAME_CUSTOM_LANGUAGE TEXT,
    DEPARTMENT_ID        BIGINT NOT NULL,
    PRIMARY KEY (ID)
);


--UNIQUE CONSTRAINTS.
ALTER TABLE IF EXISTS AUTHORIZATION_METHOD
    ADD CONSTRAINT UKQIA7RUU349BPJVR7N18HBT4II UNIQUE (NAME_RU);

ALTER TABLE IF EXISTS BANK_CARD_SEGMENTATION
    ADD CONSTRAINT UKHF4APNV6UNE4HRJ7H9S9087XG UNIQUE (START_NUMBER, HANDBOOKS_KIT_ID);

ALTER TABLE IF EXISTS CENTRAL_SETTING
    ADD CONSTRAINT UKNIG9H05H37X2LSQ8N60HXSE58 UNIQUE (NAME_RU);

ALTER TABLE IF EXISTS CENTRAL_SETTING_VALUE
    ADD CONSTRAINT UKIUQY4SS452ETT662U4XLG7BPT UNIQUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                                       VALUE_CUSTOM_LANGUAGE3);

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT UKMKNXY415DI8QSJDE90UULGXNX UNIQUE (DEPARTMENT_ID, TICKET_LETTER, TICKET_NUMBER);


ALTER TABLE IF EXISTS CONFIGURATION_PACKAGE_USAGE
    ADD CONSTRAINT UKMJY3I3U35LXAUVT4WRUBN2MZR UNIQUE (CONFIGURATION_PACKAGE_ID, DEPARTMENT_ID, APPLY_DATE_TIME);

ALTER TABLE IF EXISTS DEFAULT_DEVICE_SETTING_VALUE
    ADD CONSTRAINT UKHQF5GFDCF4XADLEFP26V6KTKS UNIQUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1,
                                                       VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3);

ALTER TABLE IF EXISTS DEVICE_SETTING
    ADD CONSTRAINT UK2LUUUUT9GQ86JWYKBO2K9M3J2 UNIQUE (NAME_RU, DEVICE_TYPE_ID);

ALTER TABLE IF EXISTS DEVICE_TYPE
    ADD CONSTRAINT UK71OTGHM06TX3ALND3MAT1UIK8 UNIQUE (NAME_RU);

ALTER TABLE IF EXISTS DISPATCHING_SCHEME
    ADD CONSTRAINT UKT1XVRJID9S613T4KXQDRDL473 UNIQUE (NAME_RU);

ALTER TABLE IF EXISTS GROUPING_TABLE
    ADD CONSTRAINT UKQYKW8NBOVAOOJP7G6SLNUQTMD UNIQUE (CARE_SCHEME_ID, OPERATION_TABLE_ID, CLIENT_SEGMENT_ID);

ALTER TABLE IF EXISTS GROUP_QUALIFICATION
    ADD CONSTRAINT UKGRNSX5XH9900XE5YE2JEHNA8D UNIQUE (CARE_SCHEME_ID, GROUP_ID);

ALTER TABLE IF EXISTS LANGUAGE_TABLE
    ADD CONSTRAINT UK4F9UMF4VTWPEUPCSG4K1MIXF0 UNIQUE (CODE);

ALTER TABLE IF EXISTS LOYALTY_CARD_SEGMENTATION
    ADD CONSTRAINT UK2RAV5QQS88IYOVFBRKGE94XQK UNIQUE (START_NUMBER, HANDBOOKS_KIT_ID);

ALTER TABLE IF EXISTS NORMATIVE_TIME
    ADD CONSTRAINT UK9C96MFLA0UEEHPYXRP6PAK2D3 UNIQUE (OPERATION_TABLE_ID, DISPATCHING_SCHEME_ID);

ALTER TABLE IF EXISTS OPERATION_NODE_AVAILABILITY
    ADD CONSTRAINT UK2TM5TVTQWEMXAWT1VWDGFJHC7 UNIQUE (CLIENT_SEGMENT_ID, OPERATION_NODE_ID, DISPATCHING_SCHEME_ID);

ALTER TABLE IF EXISTS REDEFINED_DEVICE_SETTING_VALUE
    ADD CONSTRAINT UK2VWOOREMISIQN3OJO90M4I4CL UNIQUE (DEVICE_SETTING_ID, DEVICE_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                                       VALUE_CUSTOM_LANGUAGE3);

ALTER TABLE IF EXISTS ROLE_GROUP_ASSIGNMENT
    ADD CONSTRAINT UKA7VKUWE0H5IYPEUTMAAYQ6IYT UNIQUE (ROLE_ID, GROUP_QUALIFICATION_ID, DISPATCHING_SCHEME_ID);

ALTER TABLE IF EXISTS SCHEDULE_EXCLUSION
    ADD CONSTRAINT UKID6K7RFYK49Q179RS09FLATPJ UNIQUE (DATE_COLUMN, SCHEDULE_ID);

ALTER TABLE IF EXISTS TIMEZONE
    ADD CONSTRAINT UKHCJTI8K904BAEBCABAB355FMJ UNIQUE (CODE);

ALTER TABLE IF EXISTS TIMEZONE_YEAR
    ADD CONSTRAINT UK7P99X3QPS1R21PQKPY4XGXTS5 UNIQUE (TIMEZONE_ID, YEAR_COLUMN);

ALTER TABLE IF EXISTS TYPE_TABLE
    ADD CONSTRAINT UKIENYTDMGABMIUJU3GVO8NRAGI UNIQUE (NAME_COLUMN);

ALTER TABLE IF EXISTS USER_TABLE
    ADD CONSTRAINT UKINRVK6D3RTJKV3QSRR3H35NJ8 UNIQUE (LOGIN_COLUMN);


--FOREIGN KEYS
ALTER TABLE IF EXISTS BANK_CARD_SEGMENTATION
    ADD CONSTRAINT FKGYIBKQ44F1LFAR1YYL7QD73EI
        FOREIGN KEY (CLIENT_SEGMENT_ID)
            REFERENCES CLIENT_SEGMENT;

ALTER TABLE IF EXISTS BANK_CARD_SEGMENTATION
    ADD CONSTRAINT FK5TP0SD2AUPMTO0YEAG558OTVE
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS CARE_SCHEME
    ADD CONSTRAINT FKEG5H9BYEC1QU5HRQE7TA2IJJM
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS CARE_SCHEME
    ADD CONSTRAINT FK78C9QQP4EUIKDTCJX0OQNTWJ1
        FOREIGN KEY (TICKET_TEMPLATES_KIT_ID)
            REFERENCES TICKET_TEMPLATES_KIT;

ALTER TABLE IF EXISTS CENTRAL_SETTING
    ADD CONSTRAINT FK75EWDJA2WG47AE72NP672HAE
        FOREIGN KEY (TYPE_ID)
            REFERENCES TYPE_TABLE;

ALTER TABLE IF EXISTS CENTRAL_SETTING_VALUE
    ADD CONSTRAINT FKHJ3GMWGBEO8HYSTJ3JYW17F5M
        FOREIGN KEY (CENTRAL_SETTING_ID)
            REFERENCES CENTRAL_SETTING;

ALTER TABLE IF EXISTS CITY
    ADD CONSTRAINT FKSI0DKM9KK6DYUEDMC0J18T770
        FOREIGN KEY (REGION_ID)
            REFERENCES REGION;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FKEEGLH969XQ27Y0ECMXBEGBYPP
        FOREIGN KEY (AUTHORIZATION_METHOD_ID)
            REFERENCES AUTHORIZATION_METHOD;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FKKIGARUSW4IBRDXEE1FHBYMJ9M
        FOREIGN KEY (CLIENT_SEGMENT_ID)
            REFERENCES CLIENT_SEGMENT;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FKPLJ4XW6BR7VIWKQF4I4FPNEO1
        FOREIGN KEY (DEPARTMENT_ID)
            REFERENCES DEPARTMENT;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FKTJ4CO1KVR8LLTMVL0MLRXEMKN
        FOREIGN KEY (GROUP_QUALIFICATION_ID)
            REFERENCES GROUP_QUALIFICATION;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FK814W7512C41VYE804I2EMP7H
        FOREIGN KEY (LAST_OPERATION_NODE_ID)
            REFERENCES OPERATION_NODE;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FK6T85AUINUB34WRM55XVG0FYCU
        FOREIGN KEY (LAST_WORKPLACE_ID)
            REFERENCES WORKPLACE;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FK6C09PCDEPG3M8LHTNHND5HJU0
        FOREIGN KEY (OPERATION_NODE_ID)
            REFERENCES OPERATION_NODE;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FKBLAX604EHI332EQM7T0HY59RT
        FOREIGN KEY (STATUS_ID)
            REFERENCES CLIENT_STATUS;

ALTER TABLE IF EXISTS CLIENT
    ADD CONSTRAINT FKCWO2II5IKJLA2QOQM214NMH3Q
        FOREIGN KEY (USER_ID)
            REFERENCES USER_TABLE;

ALTER TABLE IF EXISTS CLIENT_SEGMENT
    ADD CONSTRAINT FKF8CV3F3M2WE2HX33U4SHXT589
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS CONFIGURATION_PACKAGE
    ADD CONSTRAINT FK193BIMRS53VYAR3WKGE45RSYU
        FOREIGN KEY (CARE_SCHEME_ID)
            REFERENCES CARE_SCHEME;

ALTER TABLE IF EXISTS CONFIGURATION_PACKAGE
    ADD CONSTRAINT FKEGQ659PYGF0M2Y4UGYWXV1I3D
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS CONFIGURATION_PACKAGE
    ADD CONSTRAINT FKDP3YOQU5MA767Y1BAQJIH9GRG
        FOREIGN KEY (OPERATION_TREE_ID)
            REFERENCES OPERATION_TREE;

ALTER TABLE IF EXISTS CONFIGURATION_PACKAGE_USAGE
    ADD CONSTRAINT FK1OEBWYTFWRLV6L0R0XQMAC93K
        FOREIGN KEY (CONFIGURATION_PACKAGE_ID)
            REFERENCES CONFIGURATION_PACKAGE;

ALTER TABLE IF EXISTS CONFIGURATION_PACKAGE_USAGE
    ADD CONSTRAINT FK2B2L5F0F0I27KC32IPK8DMDB2
        FOREIGN KEY (DEPARTMENT_ID)
            REFERENCES DEPARTMENT;

ALTER TABLE IF EXISTS DEFAULT_DEVICE_SETTING_VALUE
    ADD CONSTRAINT FK17MXC5IT8KB53F2U7I7F6UQ9G
        FOREIGN KEY (DEVICE_SETTING_ID)
            REFERENCES DEVICE_SETTING;

ALTER TABLE IF EXISTS DEFAULT_DEVICE_SETTING_VALUE
    ADD CONSTRAINT FK4VX1F2IMP4H95KPBOM6Y85KS5
        FOREIGN KEY (SETTINGS_KIT_ID)
            REFERENCES SETTINGS_KIT;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FKH6VAQ0OEA7TOIJDHKDPEWWN90
        FOREIGN KEY (CARE_SCHEME_ID)
            REFERENCES CARE_SCHEME;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FKNAVMWCKIKADL3ISNFKRWV1RT9
        FOREIGN KEY (CITY_ID)
            REFERENCES CITY;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FK4XYWKMJIM7O9QWXUIASST63F0
        FOREIGN KEY (CURRENT_DISPATCHING_SCHEME_ID)
            REFERENCES DISPATCHING_SCHEME;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FKK9U1LIHBT15J7E5J22AW77TJ4
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FKLUAJPJH2BGP19OAGOVVNY8MFX
        FOREIGN KEY (LANGUAGE_ID)
            REFERENCES LANGUAGE_TABLE;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FKD7URTYXU2A1T2HQ8CX6F85GYY
        FOREIGN KEY (OPERATION_TREE_ID)
            REFERENCES OPERATION_TREE;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FKMGSNNMUDXRWQIDN4F64Q8RP4O
        FOREIGN KEY (PARENT_ID)
            REFERENCES DEPARTMENT;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FKJ981WET47O7284Q1LXR4H7RCF
        FOREIGN KEY (SCHEDULE_ID)
            REFERENCES SCHEDULE;

ALTER TABLE IF EXISTS DEPARTMENT
    ADD CONSTRAINT FKSR2FURDTJMAE86R1RLDMSEMM6
        FOREIGN KEY (SETTINGS_KIT_ID)
            REFERENCES SETTINGS_KIT;

ALTER TABLE IF EXISTS DEVICE
    ADD CONSTRAINT FK4ABY9D7R7TOI1W2VBGOL80YVX
        FOREIGN KEY (DEPARTMENT_ID)
            REFERENCES DEPARTMENT;

ALTER TABLE IF EXISTS DEVICE
    ADD CONSTRAINT FKO9OABHNK3F79Y77IFAPU6YP7T
        FOREIGN KEY (DEVICE_TYPE_ID)
            REFERENCES DEVICE_TYPE;

ALTER TABLE IF EXISTS DEVICE
    ADD CONSTRAINT FKGBR3ORXV6XKJH9L2C72711GFG
        FOREIGN KEY (WORKPLACE_ID)
            REFERENCES WORKPLACE;

ALTER TABLE IF EXISTS DEVICE_SETTING
    ADD CONSTRAINT FKJK0CURQR5787BXF2PXFMRN9KR
        FOREIGN KEY (DEVICE_TYPE_ID)
            REFERENCES DEVICE_TYPE;

ALTER TABLE IF EXISTS DEVICE_SETTING
    ADD CONSTRAINT FK6X3MI5Y7MIX26XH9G8XX7LKQR
        FOREIGN KEY (TYPE_ID)
            REFERENCES TYPE_TABLE;

ALTER TABLE IF EXISTS GROUP_TABLE
    ADD CONSTRAINT FKCX093LC69BSCLOIC58JEQOH3L
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS GROUPING_TABLE
    ADD CONSTRAINT FKHRQ65N2Y4SFBPW516J2IENQ64
        FOREIGN KEY (CARE_SCHEME_ID)
            REFERENCES CARE_SCHEME;

ALTER TABLE IF EXISTS GROUPING_TABLE
    ADD CONSTRAINT FKEDI6W0FNEK8IAW0X2A3059JG
        FOREIGN KEY (CLIENT_SEGMENT_ID)
            REFERENCES CLIENT_SEGMENT;

ALTER TABLE IF EXISTS GROUPING_TABLE
    ADD CONSTRAINT FKMD3KKMSV5K8S5UT44HSNN7NXK
        FOREIGN KEY (GROUP_QUALIFICATION_ID)
            REFERENCES GROUP_QUALIFICATION;

ALTER TABLE IF EXISTS GROUPING_TABLE
    ADD CONSTRAINT FKHPTQUP3YK4LWKJJCRM7NNJNTM
        FOREIGN KEY (OPERATION_TABLE_ID)
            REFERENCES OPERATION_TABLE;

ALTER TABLE IF EXISTS GROUP_QUALIFICATION
    ADD CONSTRAINT FKJO4C3SDLIC1AH3L3CC6EIKAYH
        FOREIGN KEY (CARE_SCHEME_ID)
            REFERENCES CARE_SCHEME;

ALTER TABLE IF EXISTS GROUP_QUALIFICATION
    ADD CONSTRAINT FK7YGUOXLJJHWPUHRIW4V2JA9OT
        FOREIGN KEY (GROUP_ID)
            REFERENCES GROUP_TABLE;

ALTER TABLE IF EXISTS GROUP_QUALIFICATION
    ADD CONSTRAINT FKRF199I5K4Q4J1S85D0HGE3NSL
        FOREIGN KEY (TICKET_TEMPLATE_ID)
            REFERENCES TICKET_TEMPLATE;

ALTER TABLE IF EXISTS LOYALTY_CARD_SEGMENTATION
    ADD CONSTRAINT FKE2N7F53XSOVYWUYQWU4OFVTE8
        FOREIGN KEY (CLIENT_SEGMENT_ID)
            REFERENCES CLIENT_SEGMENT;

ALTER TABLE IF EXISTS LOYALTY_CARD_SEGMENTATION
    ADD CONSTRAINT FKB3CXNRRXB7FTYDABDJ53CSAEN
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS NORMATIVE_TIME
    ADD CONSTRAINT FKCK5JLB0O0AWPMPXNXLFYWCEIW
        FOREIGN KEY (DISPATCHING_SCHEME_ID)
            REFERENCES DISPATCHING_SCHEME;

ALTER TABLE IF EXISTS NORMATIVE_TIME
    ADD CONSTRAINT FK6N3DJ947LA9X0HRG20493UIPK
        FOREIGN KEY (OPERATION_TABLE_ID)
            REFERENCES OPERATION_TABLE;

ALTER TABLE IF EXISTS OPERATION_TABLE
    ADD CONSTRAINT FKJ4FHKBVGJHTKVOL5WA99K4ROB
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS OPERATION_NODE
    ADD CONSTRAINT FKHF0H9EETOWLUHFC9VWYOO0M9
        FOREIGN KEY (OPERATION_ID)
            REFERENCES OPERATION_TABLE;

ALTER TABLE IF EXISTS OPERATION_NODE
    ADD CONSTRAINT FKAR5CD1HIW90B25KJ3MMWO9LQS
        FOREIGN KEY (OPERATION_TREE_ID)
            REFERENCES OPERATION_TREE;

ALTER TABLE IF EXISTS OPERATION_NODE
    ADD CONSTRAINT FKEFXJYA224O9OO1MQDOW50KKJN
        FOREIGN KEY (PARENT_ID)
            REFERENCES OPERATION_NODE;

ALTER TABLE IF EXISTS OPERATION_NODE
    ADD CONSTRAINT FKCKEJ6CMJ1SBOHSKHWCLOLSX58
        FOREIGN KEY (SCHEDULE_ID)
            REFERENCES SCHEDULE;

ALTER TABLE IF EXISTS OPERATION_NODE_AVAILABILITY
    ADD CONSTRAINT FK19A4P4TGTB7VJ2BNATLMFYDG7
        FOREIGN KEY (CLIENT_SEGMENT_ID)
            REFERENCES CLIENT_SEGMENT;

ALTER TABLE IF EXISTS OPERATION_NODE_AVAILABILITY
    ADD CONSTRAINT FKQMRKEO73R7OIH509VGOBYP63I
        FOREIGN KEY (DISPATCHING_SCHEME_ID)
            REFERENCES DISPATCHING_SCHEME;

ALTER TABLE IF EXISTS OPERATION_NODE_AVAILABILITY
    ADD CONSTRAINT FKDOC0EPQK5G9Q3OXW5JNANFQBX
        FOREIGN KEY (OPERATION_NODE_ID)
            REFERENCES OPERATION_NODE;

ALTER TABLE IF EXISTS OPERATION_TREE
    ADD CONSTRAINT FKJNWTJRCGIYNUYVU4UUBPIS4H2
        FOREIGN KEY (HANDBOOKS_KIT_ID)
            REFERENCES HANDBOOKS_KIT;

ALTER TABLE IF EXISTS PRE_REG_OPERATOR_RESOURCE
    ADD CONSTRAINT FK53FI3IKCW5QW0GLNB3CSQ37QE
        FOREIGN KEY (DEPARTMENT_ID)
            REFERENCES DEPARTMENT;

ALTER TABLE IF EXISTS PRE_REG_OPERATOR_RESOURCE
    ADD CONSTRAINT FK5824VFRJWDUFVQNPVR7OPHHX4
        FOREIGN KEY (ROLE_ID)
            REFERENCES ROLE_TABLE;

ALTER TABLE IF EXISTS REDEFINED_DEVICE_SETTING_VALUE
    ADD CONSTRAINT FKESNA99IF7MB91W3NR42R1CR7N
        FOREIGN KEY (DEVICE_ID)
            REFERENCES DEVICE;

ALTER TABLE IF EXISTS REDEFINED_DEVICE_SETTING_VALUE
    ADD CONSTRAINT FKLQU77NCSTMSMV43RFM1TVIMID
        FOREIGN KEY (DEVICE_SETTING_ID)
            REFERENCES DEVICE_SETTING;

ALTER TABLE IF EXISTS REFRESH_TOKEN
    ADD CONSTRAINT FKDMFLV3D4GGAU3EWK0T5JSMGK0
        FOREIGN KEY (USER_ID)
            REFERENCES USER_TABLE;

ALTER TABLE IF EXISTS REGION
    ADD CONSTRAINT FKCD4I1G0OM99TYDKKGBI8WQVD1
        FOREIGN KEY (TIMEZONE_ID)
            REFERENCES TIMEZONE;

ALTER TABLE IF EXISTS REGISTRATION
    ADD CONSTRAINT FK9C08D3VYPPUD18KTPONVBG4TB
        FOREIGN KEY (DEPARTMENT_ID)
            REFERENCES DEPARTMENT;

ALTER TABLE IF EXISTS REGISTRATION
    ADD CONSTRAINT FKTN73FRHA3YKXM2OLMOPBCHRWJ
        FOREIGN KEY (OPERATION_NODE_ID)
            REFERENCES OPERATION_NODE;

ALTER TABLE IF EXISTS REGISTRATION
    ADD CONSTRAINT FKBF8NGAG7JI6PNG2JV9SE9FXTO
        FOREIGN KEY (ORIGINATOR_TYPE_ID)
            REFERENCES ORIGINATOR_TYPE;

ALTER TABLE IF EXISTS REGISTRATION
    ADD CONSTRAINT FK48LP8NN414LKKQE14N6MQV2JK
        FOREIGN KEY (STATUS_ID)
            REFERENCES CLIENT_STATUS;

ALTER TABLE IF EXISTS REGISTRATION_STATISTICS
    ADD CONSTRAINT FK3KX85DU1MGKRX929DEATBNYML
        FOREIGN KEY (OPERATION_NODE_ID)
            REFERENCES OPERATION_NODE;

ALTER TABLE IF EXISTS REGISTRATION_STATISTICS
    ADD CONSTRAINT FK3RQE886JG95LDAKTAGN37C6QO
        FOREIGN KEY (ORIGINATOR_TYPE_ID)
            REFERENCES ORIGINATOR_TYPE;

ALTER TABLE IF EXISTS ROLE_TABLE
    ADD CONSTRAINT FKSVTCP3IVQ4HKH20QDRCA3JKW7
        FOREIGN KEY (ACCESS_GROUP_ID)
            REFERENCES ACCESS_GROUP;

ALTER TABLE IF EXISTS ROLE_GROUP_ASSIGNMENT
    ADD CONSTRAINT FKPOFLOHNRAP0JAQFC9FXGRH3MO
        FOREIGN KEY (DISPATCHING_SCHEME_ID)
            REFERENCES DISPATCHING_SCHEME;

ALTER TABLE IF EXISTS ROLE_GROUP_ASSIGNMENT
    ADD CONSTRAINT FKLO1JTNPHAPUTR2VFVDYIP6KTR
        FOREIGN KEY (GROUP_QUALIFICATION_ID)
            REFERENCES GROUP_QUALIFICATION;

ALTER TABLE IF EXISTS ROLE_GROUP_ASSIGNMENT
    ADD CONSTRAINT FKPNY5I404F2EI9899T3P9B3TVN
        FOREIGN KEY (PRIORITY_ID)
            REFERENCES PRIORITY;

ALTER TABLE IF EXISTS ROLE_GROUP_ASSIGNMENT
    ADD CONSTRAINT FKM179379X6NTWGQOKJO13EHPBJ
        FOREIGN KEY (ROLE_ID)
            REFERENCES ROLE_TABLE;

ALTER TABLE IF EXISTS SCHEDULE_DAY_OF_WEEK
    ADD CONSTRAINT FK3O2U30ACUSKHP8YH0XYKOEBD0
        FOREIGN KEY (SCHEDULE_ID)
            REFERENCES SCHEDULE;

ALTER TABLE IF EXISTS SCHEDULE_EXCLUSION
    ADD CONSTRAINT FKMTBJ0U4X68G9FXP6O96PWFQPK
        FOREIGN KEY (SCHEDULE_ID)
            REFERENCES SCHEDULE;

ALTER TABLE IF EXISTS TICKET_TEMPLATE
    ADD CONSTRAINT FKQT04I81V3E1PWSQRFMLQH4Y9P
        FOREIGN KEY (TICKET_TEMPLATES_KIT_ID)
            REFERENCES TICKET_TEMPLATES_KIT;

ALTER TABLE IF EXISTS TIMEZONE_YEAR
    ADD CONSTRAINT FK4LFWYU980A54XI50V3FWSHBJ2
        FOREIGN KEY (TIMEZONE_ID)
            REFERENCES TIMEZONE;

ALTER TABLE IF EXISTS USER_TABLE
    ADD CONSTRAINT FK9HBDAXYCJVOR9UJDUHY73FSDJ
        FOREIGN KEY (AUTHORIZATION_ROLE_ID)
            REFERENCES ROLE_TABLE;

ALTER TABLE IF EXISTS USER_TABLE
    ADD CONSTRAINT FK543ERG73BOY8G4J974S8RC5KD
        FOREIGN KEY (DEPARTMENT_ID)
            REFERENCES DEPARTMENT;

ALTER TABLE IF EXISTS USER_TABLE
    ADD CONSTRAINT FK1RQRFO0JDSLQMEX89LUPWIY0O
        FOREIGN KEY (LANGUAGE_ID)
            REFERENCES LANGUAGE_TABLE;

ALTER TABLE IF EXISTS USER_TABLE
    ADD CONSTRAINT FK29WM4VQG5F94IWJTRDP5GKR8K
        FOREIGN KEY (OPERATOR_STATUS_ID)
            REFERENCES OPERATOR_STATUS;

ALTER TABLE IF EXISTS USER_TABLE
    ADD CONSTRAINT FKQ6W5RBJ3961WKW24VPYACT8FQ
        FOREIGN KEY (ADMIN_STATUS_ID)
            REFERENCES ADMIN_STATUS;

ALTER TABLE IF EXISTS USER_TABLE
    ADD CONSTRAINT FKKYHQXAH89FO9GJT0Q7LDUV49R
        FOREIGN KEY (WORKPLACE_ID)
            REFERENCES WORKPLACE;

ALTER TABLE IF EXISTS USER_ROLE
    ADD CONSTRAINT FKGWC1K06GS7PYB1NFW7M4GHM4S
        FOREIGN KEY (ROLE_ID)
            REFERENCES ROLE_TABLE;

ALTER TABLE IF EXISTS USER_ROLE
    ADD CONSTRAINT FK5CWPLLHE458F6J6FB7RMHFYT2
        FOREIGN KEY (USER_ID)
            REFERENCES USER_TABLE;

ALTER TABLE IF EXISTS WORKPLACE
    ADD CONSTRAINT FKRAFV8BI1WRDNCUBWPRKNQ4CGY
        FOREIGN KEY (DEPARTMENT_ID)
            REFERENCES DEPARTMENT;


--ДАННЫЕ.
INSERT INTO ACCESS_GROUP (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN)
VALUES ('Центральный администратор', 'Central administrator', 'Все отделения. Все права, включая конфигурирование, создание ролей и пользователей.',
        'All departments. All rights, including configuring, creating roles and users.');
INSERT INTO ACCESS_GROUP (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN)
VALUES ('Центральный бизнес-администратор', 'Central business administrator', 'Все отделения. Мониторинг, отчетность, аудит, медиа-контент (в виде ссылке на web-ГИТ).',
        'All branches. Monitoring, reporting, audit, media content (as a link to web Main Information Board).');
INSERT INTO ACCESS_GROUP (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN)
VALUES ('Администратор отделения', 'Department administrator',
        'Одно отделение. Мониторинг, отчетность, аудит, медиа-контент (в виде ссылки на web-ГИТ), режим работы услуг, просмотр ролей и пользователей.',
        'One department. Monitoring, reporting, audit, media content (as a link to the web Main Information Board), operating mode of operations, viewing roles and users.');
INSERT INTO ACCESS_GROUP (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN)
VALUES ('Операционист', 'Operator', 'Одно отделение. Пульты оператора.', 'One department. Operator consoles.');



INSERT INTO AUTHORIZATION_METHOD (NAME_RU, NAME_EN)
VALUES ('Не идентифицирован', 'Not Identified');
INSERT INTO AUTHORIZATION_METHOD (NAME_RU, NAME_EN)
VALUES ('Банковская карта', 'Bank card');
INSERT INTO AUTHORIZATION_METHOD (NAME_RU, NAME_EN)
VALUES ('Карта лояльности', 'Loyalty card');
INSERT INTO AUTHORIZATION_METHOD (NAME_RU, NAME_EN)
VALUES ('Код предварительной записи', 'Pre registration code');



INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('В очереди', 'In queue', 'В очереди.', 'In queue.', false);
INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Вызван', 'Called', 'Вызван.', 'Called.', false);
INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Обслуживается', 'Being served', 'Был вызван и в данный момент обслуживается.', 'Was called and is currently being serviced.', false);
INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Отложен', 'Postponed', 'Отложен', 'Postponed.', false);
INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Сброшен', 'Reset', 'Сброшен.', 'Reset.', false);
INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Обслуживается по другой услуге', 'Served under a different operation', 'Обслуживается по другой услуге мультитилона или динамического маршрута.',
        'Served under a different operation using another multiticket or dynamic route.', false);
INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Предварительная запись', 'Preregistration', 'Записан на обслуживание через функцию предварительной записи',
        'Signed up for service through the pre-registration function.', false);
INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('УТО', 'RSP', 'УТО.', 'RSP.', true);
INSERT INTO CLIENT_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Обслужен', 'Served', 'Обслужен.', 'Served.', false);



INSERT INTO DEVICE_TYPE (NAME_RU, NAME_EN)
VALUES ('Регистратор', 'Ticket kiosk');
INSERT INTO DEVICE_TYPE (NAME_RU, NAME_EN)
VALUES ('Главное информационное табло', 'Main information board');
INSERT INTO DEVICE_TYPE (NAME_RU, NAME_EN)
VALUES ('Табло оператора', 'Operator panel');
INSERT INTO DEVICE_TYPE (NAME_RU, NAME_EN)
VALUES ('Пульт оператора', 'Operator console');



INSERT INTO HANDBOOKS_KIT (NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Текущий', 'Current', '');



INSERT INTO CLIENT_SEGMENT (NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE, BY_DEFAULT, HANDBOOKS_KIT_ID, EDITABLE)
VALUES ('Предварительная запись', 'Pre-registration', '', false, 1, false);
INSERT INTO CLIENT_SEGMENT (NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE, BY_DEFAULT, HANDBOOKS_KIT_ID, EDITABLE)
VALUES ('Стандарт', 'Standard', '', true, 1, true);
INSERT INTO CLIENT_SEGMENT (NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE, BY_DEFAULT, HANDBOOKS_KIT_ID, EDITABLE)
VALUES ('VIP', 'VIP', '', false, 1, true);



INSERT INTO DISPATCHING_SCHEME (NAME_RU, NAME_EN)
VALUES ('Зелёная', 'Green');
INSERT INTO DISPATCHING_SCHEME (NAME_RU, NAME_EN)
VALUES ('Жёлтая', 'Yellow');
INSERT INTO DISPATCHING_SCHEME (NAME_RU, NAME_EN)
VALUES ('Красная', 'Red');


--1
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Вход в систему', 'Login to system', null);
--2
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Выход из системы', 'Logout from system', null);
--3
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Ошибка входа в систему', 'Login failed', null);
--4
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Добавление нового пользователя [%s]', 'Adding a new user [%s]', null);
--5
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Редактирование пользователя [%s]', 'Editing a user [%s]', null);
--6
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Удаление пользователя [%s]', 'Deleting a user [%s]', null);
--7
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Изменение схемы диспетчеризации с [%s] на [%s] для очереди [%s] пользователем [%s] ', 'Change of dispatch scheme from [%s] to [%s] for queue [%s] by user [%s]',
        null);
--8
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Успешная авторизация: [%s]', 'Successful authorization: [%s]', null);
--9
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Регистрация клиента [%s%d] на услугу [%s]', 'Registration of client [%s%d] for service [%s]', null);
--10
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Вызов клиента [%s%d] по услуге [%s]', 'Calling client [%s%d] for service [%s]', null);
--11
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Завершение обслуживания клиента [%s%d] по услуге [%s]', 'End of client service [%s%d] for service [%s]', null);
--12
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Явка клиента [%s%d] к оператору.', 'Attendance of the client [%s%d] to the operator.', null);
--13
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Неявка клиента [%s%d]', 'failure of the client [%s%d] to appear to the operator', null);
--14
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Регистрация клиента [%s%d] на услугу  [%s] с помощью специальной регистрации.', 'Registration of client [%s%d] for service [%s] using special registration.',
        null);
--15
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Перевод клиента [%s%d] из окна [%s] в окно [%s]. Причина перевода: [%s]', 'Moving client [%s%d] from window [%s] to window [%s]. Reason for transfer: [%s]',
        null);
--16
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Изменение клиенту [%s%d] услуги c [%s] на [%s]. Причина перевода: [%s]', 'Change for client [%s%d] service from [%s] to [%s]. Reason for transfer: [%s]', null);
--17
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Начало пост-обработки пользователем [%s].', 'Post-processing started by user [%s]', null);
--18
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Завершение пост-обработки пользователем [%s]', 'Post-processing finished by user [%s]', null);
--19
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Откладывание клиента [%s%d] на [%d] минут', 'Postponing client [%s%d] for [%d] minutes', null);
--20
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Возвращение клиента [%s%d] в очередь', 'Returning client [%s%d] to queue', null);
--21
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Удаление клиента [%s%d]', 'Removing client [%s%d]', null);
--22
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Сброс клиента [%s%d]', 'Client reset [%s%d]', null);
--23
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Назначение клиента [%s%d] окну [%s]. Причина перевода: [%s]', 'Assigning client [%s%d] to window [%s]. Reason for transfer: [%s]', null);
--24
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Добавление нового устройства [%s]', 'Adding a new device [%s]', null);
--25
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Редактирование устройства [%s]', 'Editing device [%s]', null);
--26
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Удаление устройства [%s]', 'Removing device [%s]', null);
--27
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Ошибка связи с устройством [%s] по IP: [%s]', 'Error communicating with device [%s] by IP: [%s]', null);
--28
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Восстановление связи с утройством [%s]', 'Reestablishing connection with device [%s]', null);
--29
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Перевод устройства [%s] в состояние [%s]', 'Putting the device [%s] into the state [%s]', null);
--30
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Превышение допустимого среднего времени ожидания: %d мин.', 'Exceeded the allowed average waiting time:%d min.', null);
--31
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Активация кнопки Пауза пользователем [%s].', 'Activation of the Pause button by user [%s].', null);
--32
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Деактивация кнопки Пауза пользователем [%s].', 'Deactivation of the Pause button by user [%s].', null);
--33
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Превышение нормативного времени обслуживания клиента [%s%d]', 'Timeout for customer service [%s%d]', null);
--34
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Переход группы услуг [%s] в красную зону', 'Moving service group [%s] to the red zone', null);
--35
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Переход группы услуг [%s] перешла в зеленую зону', 'Moving service group [% s] to the green zone', null);
--36
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Начало перерыва у пользователя [%s].  Причина перерыва: [%s].', 'User [%s] break start. Break reason: [%s].', null);
--37
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Конец перерыва у пользователя [%s]', 'End of user break [%s]', null);
--38
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Создание нового пакета [%s] со следующей конфигурацией: набор справочников [%s], дерево услуг [%s], схема обслуживания [%s].',
        'Create a new configuration package [%s] with the following configuration: handbooksKit [%s], operationTree [%s], careSchema [%s].', null);
--39
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Редактирование пакета конфигураций [%s]: набор справочников [%s], дерево услуг [%s], схема обслуживания [%s].',
        'Configuration package [%s] changed: handbooksKit [%s], operationTree [%s], careSchema [%s].', null);
--40
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Удаление пакета конфигураций [%s].', 'Configuration package [%s] removed.', null);
--37
INSERT INTO EVENT_TYPE(NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Пакет конфигураций [%s] применен в отделении [%s].', 'Configuration package [%s] applied to department [%s].', null);




--ISO 639-1
--Список языков и английские переводы взяты отсюда
--https://en.wikipedia.org/wiki/List_of_ISO_639-1_CODEs
--Русские переводы этих языков взяты отсюда
--https://ru.wikipedia.org/wiki/%D0%9A%D0%BE%D0%B4%D1%8B_%D1%8F%D0%B7%D1%8B%D0%BA%D0%BE%D0%B2
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (1, 'ab', 'Абхазский', 'Abkhazian', 'Аҧсуа Бызшәа, Аҧсшәа');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (2, 'aa', 'Афарский', 'Afar', 'Afaraf');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (3, 'af', 'Африкаанс', 'Afrikaans', 'Afrikaans');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (4, 'ak', 'Акан', 'Akan', 'Akan');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (5, 'sq', 'Албанский', 'Albanian', 'Shqip');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (6, 'am', 'Амхарский', 'Amharic', 'አማርኛ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (7, 'ar', 'Арабский', 'Arabic', 'العربية');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (8, 'an', 'Арагонский', 'Aragonese', 'Aragonés');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (9, 'hy', 'Армянский', 'Armenian', 'Հայերեն');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (10, 'as', 'Ассамский', 'Assamese', 'অসমীয়া');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (11, 'av', 'Аварский', 'Avaric', 'Авар Мацӏ, Магӏарул Мацӏ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (12, 'ae', 'Авестийский', 'Avestan', 'Avesta');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (13, 'ay', 'Аймара', 'Aymara', 'Aymar Aru');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (14, 'az', 'Азербайджанский', 'Azerbaijani', 'Azərbaycan Dili');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (15, 'bm', 'Бамбара', 'Bambara', 'Bamanankan');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (16, 'ba', 'Башкирский', 'Bashkir', 'Башҡорт Теле');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (17, 'eu', 'Баскский', 'Basque', 'Euskara, Euskera');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (18, 'be', 'Белорусский', 'Belarusian', 'Беларуская Мова');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (19, 'bn', 'Бенгальский', 'Bengali', 'বাংলা');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (20, 'bh', 'Бихари', 'Bihari languages', 'भोजपुरी');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (21, 'bi', 'Бислама', 'Bislama', 'Bislama');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (22, 'bs', 'Боснийский', 'Bosnian', 'Bosanski Jezik');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (23, 'br', 'Бретонский', 'Breton', 'Brezhoneg');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (24, 'bg', 'Болгарский', 'Bulgarian', 'Български Език');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (25, 'my', 'Бирманский', 'Burmese', 'ဗမာစာ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (26, 'ca', 'Каталанский', 'Catalan, Valencian', 'Català, Valencià');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (27, 'ch', 'Чаморр', 'Chamorro', 'Chamoru');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (28, 'ce', 'Чеченский', 'Chechen', 'Нохчийн Мотт');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (29, 'ny', 'Ньянджа', 'Chichewa, Chewa, Nyanja', 'Chicheŵa, Chinyanja');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (30, 'zh', 'Китайский', 'Chinese', '中文 (Zhōngwén), 汉语, 漢語');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (31, 'cv', 'Чувашский', 'Chuvash', 'Чӑваш Чӗлхи');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (32, 'kw', 'Корнский', 'Cornish', 'Kernewek');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (33, 'co', 'Корсиканский', 'Corsican', 'Corsu, Lingua Corsa');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (34, 'cr', 'Кри', 'Cree', 'ᓀᐦᐃᔭᐍᐏᐣ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (35, 'hr', 'Хорватский', 'Croatian', 'Hrvatski Jezik');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (36, 'cs', 'Чешский', 'Czech', 'Čeština, Český Jazyk');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (37, 'da', 'Датский', 'Danish', 'Dansk');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (38, 'dv', 'Дивехи (Мальдивский)', 'Divehi, Dhivehi, Maldivian', 'ދިވެހި');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (39, 'nl', 'Нидерландский (Голландский)', 'Dutch, Flemish', 'Nederlands, Vlaams');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (40, 'dz', 'Дзонг-кэ', 'Dzongkha', 'རྫོང་ཁ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (41, 'en', 'Английский', 'English', 'English');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (42, 'eo', 'Эсперанто', 'Esperanto', 'Esperanto');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (43, 'et', 'Эстонский', 'Estonian', 'Eesti, Eesti Keel');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (44, 'ee', 'Эве', 'Ewe', 'Eʋegbe');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (45, 'fo', 'Фарерский', 'Faroese', 'Føroyskt');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (46, 'fj', 'Фиджи', 'Fijian', 'Vosa Vakaviti');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (47, 'fi', 'Филиппинский', 'Finnish', 'Suomi, Suomen Kieli');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (48, 'fr', 'Французский', 'French', 'Français, langue Française');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (49, 'ff', 'Фулах', 'Fulah', 'Fulfulde, Pulaar, Pular');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (50, 'gl', 'Галисийский', 'Galician', 'Galego');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (51, 'ka', 'Грузинский', 'Georgian', 'ქართული');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (52, 'de', 'Немецкий', 'German', 'Deutsch');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (53, 'el', 'Греческий (новогреческий)', 'Greek, Modern (1453–)', 'Ελληνικά');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (54, 'gn', 'Греческий (новогреческий)', 'Guarani', 'Avañe''ẽ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (55, 'gu', 'Гуджарати', 'Gujarati', 'ગુજરાતી');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (56, 'ht', 'Гаитянский креольский', 'Haitian, Haitian Creole', 'Kreyòl Ayisyen');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (57, 'ha', 'Хауса', 'Hausa', '(Hausa) هَوُسَ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (58, 'he', 'Иврит', 'Hebrew', 'עברית');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (59, 'hz', 'Гереро', 'Herero', 'Otjiherero');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (60, 'hi', 'Хинди', 'Hindi', 'हिन्दी, हिंदी');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (61, 'ho', 'Хиримоту', 'Hiri Motu', 'Hiri Motu');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (62, 'hu', 'Венгерский', 'Hungarian', 'Magyar');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (63, 'ia', 'Интерлингва', 'Interlingua (International Auxiliary language Association)', 'Interlingua');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (64, 'ID', 'Индонезийский', 'Indonesian', 'Bahasa Indonesia');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (65, 'ie', 'Интерлингве', 'Interlingue, OccIDental', '(Originally:) OccIDental, (After Wwii:) Interlingue');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (66, 'ga', 'Ирландский', 'Irish', 'Gaeilge');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (67, 'ig', 'Игбо', 'Igbo', 'Asụsụ Igbo');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (68, 'ik', 'Игбо', 'Inupiaq', 'Iñupiaq, Iñupiatun');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (69, 'io', 'Идо', 'Ido', 'Ido');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (70, 'is', 'Исландский', 'Icelandic', 'Íslenska');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (71, 'it', 'Итальянский', 'Italian', 'Italiano');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (72, 'iu', 'Инуктитут', 'Inuktitut', 'ᐃᓄᒃᑎᑐᑦ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (73, 'ja', 'Японский', 'Japanese', '日本語 (にほんご)');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (74, 'jv', 'Яванский', 'Javanese', 'ꦧꦱꦗꦮ, Basa Jawa');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (75, 'kl', 'Яванский', 'Kalaallisut, Greenlandic', 'Kalaallisut, Kalaallit Oqaasii');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (76, 'kn', 'Каннада', 'Kannada', 'ಕನ್ನಡ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (77, 'kr', 'Канури', 'Kanuri', 'Kanuri');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (78, 'ks', 'Кашмири', 'Kashmiri', 'कश्मीरी, كشميري‎');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (79, 'kk', 'Казахский', 'Kazakh', 'Қазақ Тілі');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (80, 'km', 'Кхмерский', 'Central Khmer', 'ខ្មែរ, ខេមរភាសា, ភាសាខ្មែរ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (81, 'ki', 'Кикуйю', 'Kikuyu, Gikuyu', 'Gĩkũyũ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (82, 'rw', 'Руанда', 'Kinyarwanda', 'Ikinyarwanda');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (83, 'ky', 'Киргизский', 'Kirghiz, Kyrgyz', 'Кыргызча, Кыргыз Тили');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (84, 'kv', 'Коми', 'Komi', 'Коми Кыв');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (85, 'kg', 'Конго', 'Kongo', 'Kikongo');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (86, 'ko', 'Конго', 'Korean', '한국어');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (87, 'ku', 'Курдский', 'Kurdish', 'Kurdî, کوردی‎');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (88, 'kj', 'Киньяма', 'Kuanyama, Kwanyama', 'Kuanyama');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (89, 'la', 'Латинский', 'Latin', 'Latine, Lingua Latina');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (90, 'lb', 'Люксембургский', 'Luxembourgish, Letzeburgesch', 'Lëtzebuergesch');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (91, 'lg', 'Ганда', 'Ganda', 'Luganda');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (92, 'li', 'Лимбургский', 'Limburgan, Limburger, Limburgish', 'Limburgs');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (93, 'ln', 'Лингала', 'Lingala', 'Lingála');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (94, 'lo', 'Лаосский', 'Lao', 'ພາສາລາວ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (95, 'lt', 'Лаосский', 'Lithuanian', 'Lietuvių Kalba');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (96, 'lu', 'Луба-катанга', 'Luba-Katanga', 'Kiluba');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (97, 'lv', 'Латышский', 'Latvian', 'Latviešu Valoda');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (98, 'gv', 'Латышский', 'Manx', 'Gaelg, Gailck');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (99, 'mk', 'Македонский', 'Macedonian', 'Македонски Јазик');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (100, 'mg', 'Малагасийский', 'Malagasy', 'Fiteny Malagasy');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (101, 'ms', 'Малайский', 'Malay', 'Bahasa Melayu, بهاس ملايو‎');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (102, 'ml', 'Малаялам', 'Malayalam', 'മലയാളം');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (103, 'mt', 'Мальтийский', 'Maltese', 'Malti');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (104, 'mi', 'Маори', 'Maori', 'Te Reo Māori');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (105, 'mr', 'Маратхи', 'Marathi', 'मराठी');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (106, 'mh', 'Маршалльский', 'Marshallese', 'Kajin M̧Ajeļ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (107, 'mn', 'Монгольский', 'Mongolian', 'Монгол Хэл');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (108, 'na', 'Науру', 'Nauru', 'Dorerin Naoero');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (109, 'nv', 'Навахо', 'Navajo, Navaho', 'Diné Bizaad');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (110, 'nd', 'Ндебеле северный', 'North Ndebele', 'Isindebele');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (111, 'ne', 'Непальский', 'Nepali', 'नेपाली');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (112, 'ng', 'Ндунга', 'Ndonga', 'Owambo');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (113, 'nb', 'Букмол', 'Norwegian Bokmål', 'Norsk Bokmål');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (114, 'nn', 'Нюнорск (новонорвежский)', 'Norwegian Nynorsk', 'Norsk Nynorsk');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (115, 'no', 'Норвежский', 'Norwegian', 'Norsk');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (116, 'ii', 'Нуосу', 'Sichuan Yi, Nuosu', 'ꆈꌠ꒿ Nuosuhxop');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (117, 'nr', 'Ндебеле южный', 'South Ndebele', 'Isindebele');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (118, 'oc', 'Окситанский', 'Occitan', 'Occitan, Lenga D''Òc');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (119, 'oj', 'Оджибве', 'Ojibwa', 'ᐊᓂᔑᓈᐯᒧᐎᓐ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (120, 'cu', 'Церковнославянский (Старославянский)', 'Church Slavic, Old Slavonic, Church Slavonic, Old Bulgarian, Old Church Slavonic', 'Ѩзыкъ Словѣньскъ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (121, 'om', 'Оромо', 'Oromo', 'Afaan Oromoo');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (122, 'or', 'Ория', 'Oriya', 'ଓଡ଼ିଆ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (123, 'os', 'Осетинский', 'Ossetian, Ossetic', 'Ирон Æвзаг');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (124, 'pa', 'Пенджабский', 'Punjabi, Panjabi', 'ਪੰਜਾਬੀ, پنجابی‎');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (125, 'pi', 'Пали', 'Pali', 'पालि, पाळि');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (126, 'fa', 'Персидский', 'Persian', 'فارسی');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (127, 'pl', 'Польский', 'Polish', 'Język Polski, Polszczyzna');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (128, 'ps', 'Пушту', 'Pashto, Pushto', 'پښتو');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (129, 'pt', 'Португальский', 'Portuguese', 'Português');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (130, 'qu', 'Кечуа', 'Quechua', 'Runa Simi, Kichwa');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (131, 'rm', 'Ретороманский', 'Romansh', 'Rumantsch Grischun');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (132, 'rn', 'Рунди', 'Rundi', 'Ikirundi');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (133, 'ro', 'Румынский', 'Romanian, Moldavian, Moldovan', 'Română');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (134, 'ru', 'Русский', 'Russian', 'Русский');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (135, 'sa', 'Санскрит', 'Sanskrit', 'संस्कृतम्');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (136, 'sc', 'Сардинский', 'Sardinian', 'Sardu');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (137, 'sd', 'Синдхи', 'Sindhi', 'सिन्धी, سنڌي، سندھی‎');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (138, 'se', 'Северо - саамский', 'Northern Sami', 'Davvisámegiella');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (139, 'sm', 'Самоанский', 'Samoan', 'Gagana Fa''A Samoa');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (140, 'sg', 'Санго', 'Sango', 'Yângâ Tî Sängö');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (141, 'sr', 'Сербский', 'Serbian', 'Српски Језик');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (142, 'gd', 'Гэльский', 'Gaelic, Scottish Gaelic', 'GàIDhlig');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (143, 'sn', 'Шона', 'Shona', 'Chishona');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (144, 'si', 'Сингальский', 'Sinhala, Sinhalese', 'සිංහල');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (145, 'sk', 'Словацкий', 'Slovak', 'Slovenčina, Slovenský Jazyk');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (146, 'sl', 'Словенский', 'Slovenian', 'Slovenski Jezik, Slovenščina');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (147, 'so', 'Сомали', 'Somali', 'Soomaaliga, Af Soomaali');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (148, 'st', 'Сото южный', 'Southern Sotho', 'Sesotho');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (149, 'es', 'Испанский', 'Spanish, Castilian', 'Español');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (150, 'su', 'Сунданский', 'Sundanese', 'Basa Sunda');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (151, 'sw', 'Суахили', 'Swahili', 'Kiswahili');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (152, 'ss', 'Свази', 'Swati', 'Siswati');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (153, 'sv', 'Шведский', 'Swedish', 'Svenska');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (154, 'ta', 'Тамильский', 'Tamil', 'தமிழ்');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (155, 'te', 'Телугу', 'Telugu', 'తెలుగు');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (156, 'tg', 'Таджикский', 'Tajik', 'Тоҷикӣ, Toçikī, تاجیکی‎');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (157, 'th', 'Тайский', 'Thai', 'ไทย');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (158, 'ti', 'Тигринья', 'Tigrinya', 'ትግርኛ');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (159, 'bo', 'Тибетский', 'Tibetan', 'བོད་ཡིག');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (160, 'tk', 'Туркменский', 'Turkmen', 'Türkmen, Түркмен');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (161, 'tl', 'Тагальский', 'Tagalog', 'Wikang Tagalog');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (162, 'tn', 'Тайский', 'Tswana', 'Setswana');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (163, 'to', 'Тонганский', 'Tonga (Tonga Islands)', 'Faka Tonga');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (164, 'tr', 'Турецкий', 'Turkish', 'Türkçe');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (165, 'ts', 'Тсонга', 'Tsonga', 'Xitsonga');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (166, 'tt', 'Татарский', 'Tatar', 'Татар Теле, Tatar Tele');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (167, 'tw', 'Тви', 'Twi', 'Twi');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (168, 'ty', 'Таитянский', 'Tahitian', 'Reo Tahiti');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (169, 'ug', 'Уйгурский', 'Uighur, Uyghur', 'ئۇيغۇرچە‎, Uyghurche');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (170, 'uk', 'Украинский', 'Ukrainian', 'Українська');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (171, 'ur', 'Урду', 'Urdu', 'اردو');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (172, 'uz', 'Узбекский', 'Uzbek', 'Oʻzbek, Ўзбек, أۇزبېك‎');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (173, 've', 'Венда', 'Venda', 'Tshivenḓa');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (174, 'vi', 'Вьетнамский', 'Vietnamese', 'Tiếng Việt');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (175, 'vo', 'Волапюк', 'Volapük', 'Volapük');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (176, 'wa', 'Валлония', 'Walloon', 'Walon');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (177, 'cy', 'Валлийский', 'Welsh', 'Cymraeg');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (178, 'wo', 'Волоф', 'Wolof', 'Wollof');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (179, 'fy', 'Фризский', 'Western Frisian', 'Frysk');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (180, 'xh', 'Коса', 'Xhosa', 'Isixhosa');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (181, 'yi', 'Идиш', 'YIDdish', 'ייִדיש');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (182, 'yo', 'Йоруба', 'Yoruba', 'Yorùbá');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (183, 'za', 'Чжуанский', 'Zhuang, Chuang', 'Saɯ Cueŋƅ, Saw Cuengh');
INSERT INTO LANGUAGE_TABLE (ID, CODE, NAME_RU, NAME_EN, NAME_ORIGIN)
VALUES (184, 'zu', 'Зулу', 'Zulu', 'Isizulu');



INSERT INTO ORIGINATOR_TYPE (ID, NAME_RU, NAME_EN)
VALUES (1, 'Регистратор', 'Registrar');
INSERT INTO ORIGINATOR_TYPE (ID, NAME_RU, NAME_EN)
VALUES (2, 'Интернет', 'Internet');
INSERT INTO ORIGINATOR_TYPE (ID, NAME_RU, NAME_EN)
VALUES (3, 'Модуль администрирования', 'Admin module');
INSERT INTO ORIGINATOR_TYPE (ID, NAME_RU, NAME_EN)
VALUES (4, 'Живая очередь', 'Live queue');
INSERT INTO ORIGINATOR_TYPE (ID, NAME_RU, NAME_EN)
VALUES (5, 'Все устройства', 'All devices');



INSERT INTO PRIORITY (NAME_EN, NAME_RU)
VALUES (NULL, 'Основная');
INSERT INTO PRIORITY (NAME_EN, NAME_RU)
VALUES (NULL, 'Дополнительная');
INSERT INTO PRIORITY (NAME_EN, NAME_RU)
VALUES (NULL, 'Не обслуживается');



INSERT INTO ROLE_TABLE (NAME_RU, NAME_EN, ACCESS_GROUP_ID, EDITABLE)
VALUES ('Центральный администратор', 'Central administrator', 1, false);
INSERT INTO ROLE_TABLE (NAME_RU, NAME_EN, ACCESS_GROUP_ID, EDITABLE)
VALUES ('Центральный бизнес-администратор', 'Central business administrator', 2, false);
INSERT INTO ROLE_TABLE (NAME_RU, NAME_EN, ACCESS_GROUP_ID, EDITABLE)
VALUES ('Администратор отделения', 'Department administrator', 3, true);
INSERT INTO ROLE_TABLE (NAME_RU, NAME_EN, ACCESS_GROUP_ID, EDITABLE)
VALUES ('Операционист', 'Operator', 4, true);



INSERT INTO SETTINGS_KIT (NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('По умолчанию', 'Default', '');
INSERT INTO SETTINGS_KIT (NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Текущий', 'Current', '');



INSERT INTO TICKET_TEMPLATES_KIT (NAME_RU, NAME_EN, NAME_CUSTOM_LANGUAGE)
VALUES ('Текущий', 'Current', '');



INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (1, 'Antarctica/Vostok', 360, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (2, 'Asia/Anadyr', 720, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (3, 'Asia/Barnaul', 420, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (4, 'Asia/Chita', 540, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (5, 'Asia/Irkutsk', 480, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (6, 'Asia/Kamchatka', 720, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (7, 'Asia/Khandyga', 540, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (8, 'Asia/Krasnoyarsk', 420, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (9, 'Asia/Magadan', 660, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (10, 'Asia/Novokuznetsk', 420, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (11, 'Asia/Novosibirsk', 420, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (12, 'Asia/Omsk', 360, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (13, 'Asia/Sakhalin', 660, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (14, 'Asia/Srednekolymsk', 660, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (15, 'Asia/Tomsk', 420, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (16, 'Asia/Ust-Nera', 600, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (17, 'Asia/Vladivostok', 600, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (18, 'Asia/Yakutsk', 540, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (19, 'Asia/Yekaterinburg', 300, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (20, 'Europe/Astrakhan', 240, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (21, 'Europe/Kaliningrad', 120, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (22, 'Europe/Kirov', 180, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (23, 'Europe/Moscow', 180, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (24, 'Europe/Samara', 240, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (25, 'Europe/Saratov', 240, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (26, 'Europe/Simferopol', 180, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (27, 'Europe/Ulyanovsk', 240, 0);
INSERT INTO TIMEZONE (ID, CODE, BASE, DST_SHIFT)
VALUES (28, 'Europe/Volgograd', 240, 0);



--Тип настройки для фронта
--1-- boolean
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('boolean');
--2-- combobox
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('combobox');
--3-- number
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('number');
--4-- stringInOneLanguage
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('stringInOneLanguage');
--5-- stringInMultipleLanguages
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('stringInMultipleLanguages');
--6-- multiSelectInSeveralLanguages
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('multiSelectInSeveralLanguages');
--7-- ip
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('ip');
--8-- color
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('color');
--9-- time
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('time');
--10-- multiSelectNumber
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('multiSelectNumber');
--11-- selectFromTree
INSERT INTO TYPE_TABLE (NAME_COLUMN)
VALUES ('selectFromTree');


--1
INSERT INTO ADMIN_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Не авторизован', 'Unauthorised', 'Не авторизован.', 'Not authorized.', false);
--2-
INSERT INTO ADMIN_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Авторизован в модуле администрирования.', 'Authorized in the administration module.', 'Авторизован в модуле администрирования.',
        'Authorized in the administration module.', false);


--1
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Не авторизован', 'Unauthorised', 'Не авторизован.', 'Not authorized.', false);
--2
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Готов к обслуживанию, но клиентов нет', 'Ready, but no clients', 'Готов к обслуживанию клиента, но клиентов нет.',
        'Ready for customer service, but no customers.', false);
--3
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Бездельничает', 'Loafing around', 'Бездельничает. Свободен, клиенты в очереди есть, автовызов выключен, оператор не нажимает кнопку "Вызов".',
        'Loafing around. Free, there are clients in the queue, auto call is disabled, the operator does not press the "Call" button.', false);
--4
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Ожидает вызванного клиента', 'Waiting for the called client', 'Ожидает, пока подойдет вызыванный клиент.', 'Waits for the called client to arrive.', false);
--5
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Занят', 'Busy', 'Работает.', 'Working.', false);
--6
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('На паузе.', 'Pause', 'На паузе.', 'On pause.', false);
--7
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('На пост-обработке', 'Post-processing', 'Занят пост-обработкой документов.', 'Busy with post-processing of documents.', false);
--8
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Перерыв', 'Break', 'На перерыве.', 'On a break.', false);
-- УТО
--9
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Занят', 'Busy', 'Работает.', 'Working.', true);
--10-
INSERT INTO OPERATOR_STATUS(NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, REMOTE_SERVICE_POINT)
VALUES ('Свободен', 'Free', 'Не обслуживает клиента.', 'Does not serve the client.', true);



-- INSERT INTO USER_TABLE(LOGIN_COLUMN, LAST_NAME, FIRST_NAME, mIDdle_name, password, STATUS_ID, PHOTO_FILE_NAME, DEPARTMENT_ID, workplace_ID, LANGUAGE_ID) VALUES ('admin', '', '', '', 'admin', 1, null, null, null, 134);


-- INSERT INTO USER_ROLE(USER_ID, role_ID) VALUES (1, 1);
-- INSERT INTO USER_ROLE(USER_ID, role_ID) VALUES (1, 2);
-- INSERT INTO USER_ROLE(USER_ID, role_ID) VALUES (1, 3);
-- INSERT INTO USER_ROLE(USER_ID, role_ID) VALUES (1, 4);


-- СЕРВЕР
-- Часовой пояс сервера
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Часовой пояс сервера', 'Server timezone',
        'Часовой пояс сервера, на котором установлено Q5. На его основе будет рассчитываться смещение для других часовых поясов.',
        'Time zone of the server on which Q5 is installed. It will be used to calculate the offset for other time zones.', 'timezone', 2);



-- ЯЗЫКОВЫЕ НАСТРОЙКИ
-- 1.Дополнительный язык интерфейса оператора
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Дополнительный язык интерфейса оператора', 'Custom operator interface language',
        'Язык, доступный для применения в качестве языка интерфейса оператора по умолчанию (помимо русского и английского). Чтобы сделать этот язык языком интерфейса оператора по умолчанию необходимо выбрать его в настройке "Язык интерфейса оператора по умолчанию".',
        'The language available for use as the default operator interface language (in addition to Russian and English). To make this language the default operator interface language, you must select it in the "Default operator interface language" setting.',
        'customOperatorInterfaceLanguage', 2);
-- 2.Дополнительный язык интерфейса посетителя №1
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Дополнительный язык интерфейса посетителя №1', 'Custom interface language for visitor # 1',
        'Язык, доступный для применения в качестве языка для посетителей (помимо русского и английского). Чтобы сделать этот язык языком для посетителей необходимо выбрать его в настройке "Язык для посетителей".',
        'A language available for use as a language for visitors (in addition to Russian and English). To make this language the language for visitors, you must select it in the setting "Language for visitors".',
        'customInterfaceLanguageForVisitor1', 2);
-- 3.Дополнительный язык интерфейса посетителя №2
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Дополнительный язык интерфейса посетителя №2', 'Custom interface language for visitor # 2',
        'Язык, доступный для применения в качестве языка для посетителей (помимо русского и английского). Чтобы сделать этот язык языком для посетителей необходимо выбрать его в настройке "Язык для посетителей".',
        'A language available for use as a language for visitors (in addition to Russian and English). To make this language the language for visitors, you must select it in the setting "Language for visitors".',
        'customInterfaceLanguageForVisitor2', 2);
-- 4.Дополнительный язык интерфейса посетителя №3
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Дополнительный язык интерфейса посетителя №3', 'Custom interface language for visitor # 3',
        'Язык, доступный для применения в качестве языка для посетителей (помимо русского и английского). Чтобы сделать этот язык языком для посетителей необходимо выбрать его в настройке "Язык для посетителей".',
        'A language available for use as a language for visitors (in addition to Russian and English). To make this language the language for visitors, you must select it in the setting "Language for visitors".',
        'customInterfaceLanguageForVisitor3', 2);
-- 5.Язык интерфейса оператора по умолчанию
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Язык интерфейса оператора по умолчанию', 'Default operator interface language',
        'Язык по умолчанию, на котором будет отображаться интерфейс приложения (надписи, кнопки, меню и т.д.), а также все данные за исключением тех, которые видит посетитель. В параметрах пользователя можно поменять язык по умолчанию на другой.',
        'The default language in which the application interface will be displayed (labels, buttons, menus, etc.), as well as all data except for those that the visitor sees. It is possible to change default language in user parameters.',
        'defaultOperatorInterfaceLanguage', 2);
-- 6.Язык интерфейса посетителя по умолчанию
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Язык интерфейса посетителя по умолчанию', 'Default visitor interface language',
        'Язык по умолчанию, на котором будет отображаться элементы дерева услуг - услуги и папки с услугами, текст смс-сообщений и т.д., т.е. все то, что видят клиенты. В параметрах отделения можно поменять язык по умолчанию на другой.',
        'The default language in which the elements of the service tree will be displayed - services and folders with services, text of SMS messages, etc. everything that customers see. In the parameters of the department, you can change the default language to another.',
        'DefaultVisitorInterfaceLanguage', 2);
-- 7.Контролировать заполнение данных интерфейса оператора на русском языке
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Контролировать заполнение данных интерфейса оператора на русском языке', 'Control the filling of the operator interface in Russian',
        'Если эта настройка активирована, то при обнаружении незаполненных обязательных полей на русском языке будет выдано предупреждение. Это относится ко всем данным интерфейса оператора, т.е. данным, которые видят сотрудники, но не видят посетители.',
        'If this parameter is activated, then a warning will be issued if an empty required field is found in Russian. This applies to all operator interface data, i.e. data that employees see but not visitors.',
        'controlFillingOperatorInterfaceRu', 1);
-- 8.Контролировать заполнение данных интерфейса оператора на английском языке
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Контролировать заполнение данных интерфейса оператора на английском языке', 'Control the filling of the operator interface data in English',
        'Если эта настройка активирована, то при обнаружении незаполненных обязательных полей на английском языке будет выдано предупреждение. Это относится ко всем данным интерфейса оператора, т.е. данным, которые видят сотрудники, но не видят посетители.',
        'If this parameter is activated, then a warning will be issued if an empty required field is found in English. This applies to all operator interface data, i.e. data that employees see but not visitors.',
        'controlFillingOperatorInterfaceEn', 1);
-- 9.Контролировать заполнение данных интерфейса оператора на дополнительном языке
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Контролировать заполнение данных интерфейса оператора на дополнительном языке', 'Control the filling of the operator interface data in an additional language',
        'Если эта настройка активирована, то при обнаружении незаполненных обязательных полей на дополнительном языке интерфейса оператора (т.е. на языке, добавленном помимо русского и английского) будет выдано предупреждение.  Это относится ко всем данным интерфейса оператора, т.е. данным, которые видят сотрудники, но не видят посетители.',
        'If this parameter is enabled, a warning will be issued if an empty required field is found in an custom operator interface language (i.e. in a language other than Russian and English). This applies to all operator interface data, i.e. data that employees see but not visitors.',
        'controlFillingOperatorInterfaceAdditional', 1);
-- 10.Контролировать заполнение данных интерфейса посетителя на русском языке
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Контролировать заполнение данных интерфейса посетителя на русском языке', 'Control the filling of the visitor interface data in Russian',
        'Если эта настройка активирована, то при обнаружении незаполненных обязательных полей на русском языке будет выдано предупреждение. Этот параметр относится только к данным, которые видят посетители (дерево услуг, текст смс сообщений и т.д.)',
        'If this parameter is activated, then a warning will be issued if an empty required field is found in Russian. This parameter only applies to the data that visitors see (service tree, SMS text, etc.)',
        'controlFillingVisitorInterfaceRu', 1);
-- 11.Контролировать заполнение данных интерфейса посетителя на английском языке
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Контролировать заполнение данных интерфейса посетителя на английском языке', 'Control the filling of the visitor interface data in English',
        'Если эта настройка активирована, то при обнаружении незаполненных обязательных полей на английском языке будет выдано предупреждение. Этот параметр относится только к данным, которые видят посетители (дерево услуг, текст смс сообщений и т.д.)',
        'If this parameter is activated, then a warning will be issued if an empty required field is found in English. This parameter only applies to the data that visitors see (service tree, SMS text, etc.)',
        'controlFillingVisitorInterfaceEn', 1);
-- 12.Контролировать заполнение данных интерфейса посетителя на дополнительном языке №1
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Контролировать заполнение данных интерфейса посетителя на дополнительном языке №1',
        'Control the filling of the visitor interface data in additional language # 1',
        'Если эта настройка активирована, то при обнаружении незаполненных обязательных полей на дополнительном языке услуг №1 будет выдано предупреждение. Этот параметр относится только к данным, которые видят посетители (дерево услуг, текст смс сообщений и т.д.)',
        'If this parameter is enabled, then a warning will be issued if an empty required field is found in additional operation language # 1. This parameter only applies to the data that visitors see (service tree, SMS text, etc.)',
        'controlFillingVisitorInterfaceAdditional1', 1);
-- 13.Контролировать заполнение данных интерфейса посетителя на дополнительном языке №2
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Контролировать заполнение данных интерфейса посетителя на дополнительном языке №2',
        'Control the filling of the visitor interface data in additional language # 2',
        'Если эта настройка активирована, то при обнаружении незаполненных обязательных полей на дополнительном языке услуг №2 будет выдано предупреждение. Этот параметр относится только к данным, которые видят посетители (дерево услуг, текст смс сообщений и т.д.)',
        'If this parameter is enabled, then a warning will be issued if an empty required field is found in additional operation language # 2. This parameter only applies to the data that visitors see (service tree, SMS text, etc.)',
        'controlFillingVisitorInterfaceAdditional2', 1);
-- 14.Контролировать заполнение данных интерфейса посетителя на дополнительном языке №3
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Контролировать заполнение данных интерфейса посетителя на дополнительном языке №3',
        'Control the filling of the visitor interface data in additional language # 3',
        'Если эта настройка активирована, то при обнаружении незаполненных обязательных полей на дополнительном языке услуг №3 будет выдано предупреждение. Этот параметр относится только к данным, которые видят посетители (дерево услуг, текст смс сообщений и т.д.)',
        'If this parameter is enabled, then a warning will be issued if an empty required field is found in additional operation language # 3. This parameter only applies to the data that visitors see (service tree, SMS text, etc.)',
        'controlFillingVisitorInterfaceAdditional3', 1);



-- ПРЕДВАРИТЕЛЬНАЯ ЗАПИСЬ
-- 1.Использовать предварительную запись
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Использовать предварительную запись', 'Use pre-registration',
        'Если эта настройка выключена, то функция предварительной записи блокируется для всех возможных способов: web-приложение для предварительной записи, регистратор, модуль администрирования.',
        'If this setting is disabled, the pre-recording function is blocked for all possible methods: web-application for pre-recording, ticket kiosk, administration module.',
        'usePreRegistration', 1);
-- 2.День, с которого возможна запись (Отступ в днях от текущего)
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('День, с которого возможна предварительная запись (Отступ в днях от текущего)', 'Day from which pre-registration is possible (Offset in days from current)',
        '0 - означает, что сегодняшний день тоже доступен для предварительной записи.', '0 - means that today is also available for appointment.',
        'dayPreRegistrationPossible', 3);
-- 3.День, до которого возможна запись (Отступ в днях от текущего)
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('День, до которого возможна предварительная запись (Отступ в днях от текущего)',
        'The day until which the pre-registration is possible (Offset in days from the current one)',
        'Например, 7 означает, что предварительная запись доступна на неделю вперед.', 'For example, 7 means that pre-registration is available one week in advance.',
        'dayUntilPreRegistrationPossible', 3);
-- 4.Задержка в часах при записи на сегодняшний день
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Задержка в часах при предварительной записи на сегодняшний день', 'Delay in hours when pre-registration to date',
        'Настройка нужна для предотвращения ситуаций, когда посетитель с помощью предварительной записи регистрируется на ближайшее свободное время и идет вперед всех остальных посетителей, включая тех, кто пришел раньше него.',
        'The setting is needed to prevent situations when a visitor, using an appointment, registers for the next free time and goes ahead of all other visitors, including those who came before him.',
        'delayHoursPreRegistration', 3);
-- 5.Подтверждение на регистраторе
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Подтверждение предварительной записи на регистраторе', 'Confirmation of an appointment at the ticket kiosk',
        'Если настройка включена, то посетитулю, записавшемуся через предварительную запись, при визите в банк необходимо сначала подтвердить свой визит на терминале, введя код подтверждения. Если настройку выключить, то подтверждение на терминале не требуется.',
        'If the setting is enabled, then the visitor who signed up through a pre-registration, when visiting the bank, must first confirm his visit at the terminal by entering the confirmation CODE. If the setting is disabled, then confirmation on the terminal is not required.',
        'confirmationAppointment', 1);
-- 6.НОД длительности обслуживания по услугам
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('НОД длительности обслуживания по услугам', 'GCD of service duration',
        'НОД - Наибольший Общий Делитель. Длительность оказания каждой услуги кратна НОДу (равна длительности нескольких НОДов по своей длительности). При записи на обсуживании на конкретную услугу резервируется определенное количество НОДов.',
        'GCD - Greatest Common Divisor. The duration of the provision of each service is a multiple of the GCD (equal to the duration of several GCDs in their duration). When making an appointment for a specific service, a certain number of GCDs are reserved.',
        'gcdServiceDuration', 3);
-- 7.Использовать автоматическое определение доступности интервалов
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Использовать автоматическое определение доступности интервалов предварительной записи', 'Use automatic detection of the availability of pre-recording intervals',
        'Если настройка включена, то доступность интервалов для предварительной записи определяется автоматически исходя из введенной информации о ресурсах операторов для предварительной записи. Если в системе присутствуют операторы, роли которых могут обслуживать сразу несколько услуг, то при записи на одну из услуг к такому оператору, ресурс доступных интервалов к этому же оператору по другим услугам будет уменьшаться автоматически. Если настройка выключена, то доступность интервалов для предварительной записи будет управляться только исходя из настроек лимитов записи на одну ячейку для услуги; и если в системе присутствуют операторы, роли которых могут обслуживать сразу несколько услуг, то при записи на одну из услуг к такому оператору, ресурс доступных интервалов к этому же оператору по другим услугам уменьшаться не будет. Т.е. в случае, если настройка отключена, доступность интервалов управляется только заданными вручную лимитами.',
        'If the setting is enabled, then the availability of pre-recording intervals is determined automatically based on the entered information about the operators'' resources for pre-recording. If there are operators in the system whose roles can be served by several services at once, then when registering for one of the services to such an operator, the resource of available intervals to the same operator for other services will automatically decrease. If the setting is disabled, then the availability of pre-recording intervals will be controlled only based on the settings of the recording limits for one cell for the service; and if there are operators in the system whose roles can serve several services at once, then when registering for one of the services to such an operator, the resource of available intervals to the same operator for other services will not decrease. Those. if the setting is disabled, the availability of intervals is controlled only by manually set limits.',
        'useAutomaticDetectionAvailabilityInterval', 1);
-- 8.Использовать SSL в web-приложении предварительной записи
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Использовать SSL в web-приложении предварительной записи', 'Use SSL in the pre-registration web application',
        'Использовать https-соединение с самоподписанным сертификатом для установления защищенного соединения.',
        'Use an https connection with a self-signed certificate to establish a secure connection.', 'useSSL', 1);



-- Смс
-- 1.Отправлять сообщение после предварительной записи
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Отправлять смс после предварительной записи', 'Send sms after appointment',
        'Сообщение может содержать информацию о записи, а также ссылку для переноса времени визита.',
        'The message may contain information about the appointment, as well as a link to reschedule the visit.', 'sendSMSAfterAppointment', 1);
-- 2.Шаблон сообщения, отправляемого после предварительной записи
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Шаблон cмс, отправляемого после предварительной записи', 'Post-appointment sms template',
        'Может содержать регистрационную информацию (дата и время визита, контактные данные отделения, длительность оказания услуги и т.д.), а также ссылку, позволяющую изменить дату и время оказания услуги или отменить запись.',
        'It may contain registration information (date and time of the visit, contact details of the department, duration of the service, etc.), as well as a link that allows you to change the date and time of the service or cancel the entry.',
        'postAppointmentSmsTemplate', 5);
-- 3.Напоминание о предстоящем через 2 часа визите. Таких настроек может быть несколько. Каждая обозначает напоминание за какое-то время. Например, одна настройка задает напоминание за 2 часа до визита, другая - за сутки до визита и т.д. Предустановленной является одна настройка с напоминанием за 2 часа, однако эту настройку можно удалить, также как и добавить неограниченное количество других.
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Отправлять смс с напоминанием о предстоящем визите', 'Send a sms to remind you of an upcoming visit',
        'Напоминание о предстоящем через 2 часа визите. Такие сообщения позволяют исключить ситуации, при которых посетитель забывает о предстоящем визите.',
        'Reminder of an upcoming visit in 2 hours. Such messages allow eliminating situations in which the visitor forgets about the upcoming visit.', 'sendSmsRemind',
        10);
-- 4.Шаблон сообщения с напоминанием о предстоящем визите
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Шаблон смс с напоминанием о предстоящем визите', 'Upcoming visit reminder sms template',
        'Одинаков для всех сообщений с напоминанием о предстоящем визите вне зависимости от того, за какое количество часов срабатывает напоминание. Может содержать регистрационную информацию (дата и время визита, контактные данные отделения, длительность оказания услуги и т.д.)',
        'The same for all messages with a reminder of an upcoming visit, regardless of how many hours the reminder is triggered. It may contain registration information (date and time of the visit, contact details of the department, duration of the service, etc.)',
        'upcomingVisitReminderSmsTemplate', 5);
-- 5.Отправлять сообщение после обслуживания
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Отправлять смс после обслуживания', 'Send sms after service', 'Например. "Благодарим Вас за то, что выбрали нас! Надеемся скоро увидеть Вас снова!"',
        'For instance. "Thank you for choosing us! Hope to see you again soon!"', 'sendSmsAfterService', 1);
-- 6.Шаблон сообщения, отправляемого после обслуживания
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Шаблон смс, отправляемого после обслуживания', 'Post-service sms template', 'Указывается ссылка для оценки работы персонала и степени обслуживания клиентов.',
        'ProvIDes a link to assess staff performance and customer service.', 'postServiceSmsTemplate', 5);
-- 7.Отправитель сообщения
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Отправитель смс', 'Sms sender',
        'Отображается на устройстве получателя. Может состоять из латинских букв, цифр и знаков пунктуации. Символы других языков принудительно транслитерируются в латинские.',
        'Displayed on the recipient''s device. It can consist of Latin letters, numbers and punctuation marks. Characters from other languages are forced to transliterate into Latin.',
        'smsSender', 4);
-- 8.Логин в системе SMS Traffic
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Логин в системе SMS Traffic', 'Login in the SMS Traffic system', 'Логин в системе SMS Traffic для автоматической отправки СМС-сообщений',
        'Login in the SMS Traffic system for automatic sending of SMS messages', 'loginSmsTraffic', 4);
-- 9.Пароль в системе SMS Traffic
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Пароль в системе SMS Traffic', 'Password in SMS Traffic system', 'Пароль в системе SMS Traffic для автоматической отправки СМС-сообщений',
        'Password in the SMS Traffic system for automatic sending of SMS messages', 'passwordSmsTraffic', 4);



-- УТО
-- 1.Список финальных статусов
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Доступный для выбора финальный статус клиента при обслуживании в УТО', 'Available for selection the final status of the client when servicing in the UTO',
        'Будет доступен как возможный вариант при простановке финального статуса после обслуживания клиента в отделении-УТО.',
        'It will be available as a possible option when setting the final status after serving the client in the RSP department.', 'availableFinalStatus', 6);



-- Другие
-- 1.Буквы, доступные для выбора в качестве буквы в талоне
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Буквы, доступные для выбора в качестве буквы в талоне', 'Letters available for selection as a letter in the coupon', 'Указываются через запятую без пробелов.',
        'Separated by commas without spaces.', 'lettersCoupon', 5);
-- 2.Действие при завершении обслуживания по услуге мультиталона или динамического маршрута
INSERT INTO CENTRAL_SETTING (NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES ('Действие при завершении обслуживания по услуге мультиталона или динамического маршрута',
        'Action at the end of service for a multi ticket or dynamic route service',
        'Выбор действия при завершении обслуживания по услуге мультиталона или динамического маршрута.',
        'Selecting an action to be taken when servicing a multitall service or a dynamic route is completed.', 'actionEndServiceMultiTicket', 2);



INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (1, '23', null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (2, null, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (3, null, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (4, null, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (5, null, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (6, 134, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (7, 134, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (8, true, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (9, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (10, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (11, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (12, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (13, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (14, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (15, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (16, true, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (17, 0, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (18, 30, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (19, 1, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (20, true, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (21, 5, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (22, true, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (23, true, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (24, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (25, null,
        'Уважаемый клиент! Ждем Вас {registrationDate} в {registrationStart} в {departmentName} по адресу {departmentAddress}. Код Вашей записи {registrationNumber}',
        'Dear Customer! We are waiting for you  {registrationDate} in  {registrationStart} in  {departmentName} at  {departmentAddress}. Your registration CODE is  {registrationNumber}',
        null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (26, 2, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (27, null,
        'Уважаемый клиент! Ждем Вас {registrationDate} в {registrationStart} в {departmentName} по адресу {departmentAddress}. Код Вашей записи {registrationNumber}',
        'Dear Customer! We are waiting for you  {registrationDate} in  {registrationStart} in  {departmentName} at  {departmentAddress}. Your registration CODE is  {registrationNumber}',
        null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (28, false, null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (29, null, 'Оцените, пожалуйста, качество услуги по ссылке', 'Please rate the quality of the service here', null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (30, '_Originator', null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (31, 'c10006165422', null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (32, 'qWERTY123', null, null, null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (33, null, 'Обслужен', 'Served', null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (33, null, 'Не пришел', 'DID not come', null, null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (34, null, 'А,Б,В,Г,Д,Е,Ё,Ж,З,И,Й,К,Л,М,Н,О,П,Р,С,Т,У,Ф,Х,Ц,Ч,Ш,Щ,Ъ,Ы,Ь,Э,Ю,Я,АА,АБ,АВ', 'A,B,C,D,E,F,G,H,I,J,K,L,M,N,O,P,Q,R,S,T,U,V,W,X,Y,Z,AA,AB,AC', null,
        null, null);
INSERT INTO CENTRAL_SETTING_VALUE (CENTRAL_SETTING_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2, VALUE_CUSTOM_LANGUAGE3)
VALUES (35, 'Обнулять время ожидания', null, null, null, null, null);



-- ПУЛЬТ ОПЕРАТОРА
-- 1.Автовызов
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (4, 'Автовызов', 'Autocall',
        'Автоматически вызывать на обслуживание следующего клиента после добавлении клиента в очередь, авторизации оператора на пульте, выходе оператора с перерыва, сбрасывании текущего клиента, откладывании текущего клиента, переводе текущего клиента и специальной регистрации клиента на услугу, которую оператор не может оказать.',
        'Automatically call the next client for service after adding a client to a queue, authorizing the operator at the console, leaving the operator from a break, dropping the current client, postponing the current client, transferring the current client and special client registration for a service that the operator cannot provIDe.',
        'autocall', 1);
-- 2.Количество секунд, через которое становится доступна кнопка Клиент не подошел после вызова клиента
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (4, 'Количество секунд, через которое становится доступна кнопка Клиент не подошел после вызова клиента',
        'The number of seconds after which the button becomes available The client dID not come up after calling the client',
        'Предположим, клиент был вызван на обслуживание. Для того, чтобы найти окно, на которое был произведен вызов, дойти до этого окна клиенту требуется определенное время. В некоторых случаях этот процесс может занимать до минуты и более. Для того, чтобы оператор не мог раньше времени нажать кнопку "Клиент не подошел" настройка позволяет заблокировать кнопку на определенное время.',
        'Let''s say a customer has been called in for service. In order to find the window to which the call was made, the client needs some time to reach this window. In some cases, this process can take up to a minute or more. To prevent the operator from pressing the "Client dID not come" button ahead of time, the setting allows you to block the button for a certain time.',
        'availableButtonNotCome', 3);
-- 3.Доступная для выбора причина перерыва
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (4, 'Доступная для выбора причина перерыва', 'Selectable break reason', 'Причина, которую может выбрать оператор при уходе на перерыв.',
        'The reason the operator can choose when going on break.', 'breakReason', 6);
-- 4.Включать пост-обработку в длительность обслуживания клиента
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (4, 'Включать пост-обработку в длительность обслуживания клиента', 'Include post-processing in customer service duration',
        'Время, затраченное на пост-обработку клиента включать в длительность обслуживания клиента. Влияет на отчетность.',
        'The time spent on post-processing of the client should be included in the duration of the client''s service. Affects reporting.', 'postProcessing', 1);
-- 5.Количество повторных вызовов клиента до блокировки кнопки повторного вызова
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (4, 'Количество повторных вызовов клиента до блокировки кнопки повторного вызова', 'The number of repeated customer calls before the redial button is blocked',
        'После нескольких повторных вызовов клиента кнопка повторного вызова блокируется и оператор может только сбросить клиента. Настройка задает их количество.',
        'After repeated calls to the client, the recall button is disabled and the operator can only reset the client. The setting specifies their number.',
        'redialButtonBlocked', 3);
-- 6.Время простоя
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (4, 'Время простоя', 'Downtime', 'Время между вызовами клиентов, если настройка автовызова отключена.',
        'The time between calls to clients if the auto call setting is disabled.', 'downtime', 9);



-- ТАБЛО ОПЕРАТОРА
-- 7.IP-адрес устройства
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'IP-адрес устройства', 'Device IP address', 'IP-адрес устройства.', 'Device IP address', 'deviceIP', 7);
-- 8.Количество миганий номера талона на табло оператора
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Количество миганий номера талона на табло оператора', 'The number of flashes of the ticket number on the operator''s display',
        'Количество миганий номера талона на табло оператора при вызове или повторном вызове клиента.',
        'The number of flashes of the ticket number on the operator''s board when calling or repeated calling a client.', 'BlinkCount', 3);
-- 9.Номер окна на табло оператора
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Номер окна на табло оператора', 'Window number on the operator''s display', 'Номер окна, который будет отображаться на табло оператора.',
        'Window number that will be displayed on the operator panel.', 'DeviceName', 2);
-- 10.Порт устройства
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Порт устройства', 'Device port', 'Порт устройства. По умолчанию все устройства работают на 80 порту.',
        'Device port. By default, all devices operate on port 80.', 'Port', 3);
-- 11.Скорость прокрутки номера клиента на табло оператора (только для DoCashQ3 RGB)
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Скорость прокрутки номера клиента на табло оператора (только для DoCashQ3 RGB)',
        'Scrolling speed of the client number on the operator''s display (only for DoCashQ3 RGB)', 'Скорость прокрутки номера клиента на табло оператора.',
        'The speed of scrolling the client number on the operator''s board.', 'tabloTextSpeed', 3);
-- 12.Стиль табло оператора
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Стиль табло оператора', 'Operator display style', 'Стиль отображения номера окна на табло оператора.',
        'The style of displaying the window number on the operator panel.', 'TabloStyle', 2);
-- 13.Тип табло оператора
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Тип табло оператора', 'Operator board type', 'Тип табло оператора.', 'Operator board type.', 'TabloType', 2);
-- 14.Цвет номера талона на табло оператора в формате RGB (только для DoCashQ3 RGB)
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Цвет номера талона на табло оператора в формате RGB (только для DoCashQ3 RGB)',
        'Color of the ticket number on the operator''s display in RGB format (only for DoCashQ3 RGB)', 'Цвет номера талона, отображаемого на табло оператора.',
        'The color of the ticket number displayed on the operator''s board.', 'ClientColorHex', 8);
-- 15.Цвет отображаемого шрифта на табло DoCashQ2
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Цвет отображаемого шрифта на табло DoCashQ2.', 'Color of the displayed font on the DoCashQ2 board', 'Цвет отображаемого шрифта на табло DoCashQ2.',
        'The color of the displayed font on the DoCashQ2 board.', 'Q2RGBColor', 2);
-- 16.Цвет текста названия окна оператора на табло оператора в формате RGB (только для DoCashQ3 RGB)
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (3, 'Цвет текста названия окна оператора на табло оператора в формате RGB (только для DoCashQ3 RGB)',
        'Color of the operator window title text on the operator panel in RGB format (only for DoCashQ3 RGB)', 'Цвет текста названия окна оператора на табло оператора.',
        'The color of the text of the operator window name on the operator panel.', 'DeviceColorHex', 8);



-- РЕГИСТРАТОР
-- 17.Максимально допустимое время опоздания ПР клиентов
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Максимально допустимое время опоздания ПР клиентов', 'Maximum allowable lateness of PR clients',
        'Максимально допустимое время опоздания при предварительной регистрации в минутах.', 'Maximum allowed late registration in minutes.', 'PRAfterInterval', 9);
-- 18.Допустимое время до активации кода ПР клиентов
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Допустимое время до активации кода ПР клиентов', 'Allowed time before activation of the client''s PR CODE', 'Допустимое время до активации кода ПР клиентов.',
        'Allowed time before activation of the client''s PR CODE.', 'PRBeforeInterval', 9);
-- 19.Разрешать регистрировать клиента при отсутствии бумаги на Регистраторе услуг
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Разрешать регистрировать клиента при отсутствии бумаги на Регистраторе услуг', 'Allow to register a client in the absence of paper on the Service Registrar',
        'Регистрировать клиента даже в случае, если в принтере закончилась бумага.', 'Register a client even if the printer runs out of paper.',
        'registrateClientWithoutpaper', 1);
-- 20.Сообщение о запросе на регистрацию
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Сообщение о запросе на регистрацию', 'Registration request message', 'Сообщение о запросе на регистрацию.', 'Registration request message.',
        'registrationRequestMessage', 5);
-- 21.Таймер возврата на гравную страницу Регистратора услуг при бездействии вклиента
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Таймер возврата на главную страницу Регистратора услуг при бездействии клиента',
        'Timer for returning to the main page of the Service Registrar when the client is IDle', 'Таймер возврата в начальное состояние регистратора.',
        'Timer for returning to the initial state of the recorder.', 'resetInterval', 9);
-- 22.Отображать кнопку для регистрации по карте со штрих-кодом
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Отображать кнопку для регистрации по карте со штрих-кодом', 'Show button for registration by card with barCODE',
        'Отображать кнопку для регистрации по карте со штрих-кодом.', 'Display a button for registration with a barCODE card.', 'showAuthClientByBarCODEButton', 1);
-- 23.Отображать кнопку для регистрации по карточке
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Отображать кнопку для регистрации по карточке', 'Show button for registration by card', 'Отображать кнопку для регистрации по карточке.',
        'Show button for registration by card.', 'showAuthClientByCardButton', 1);
-- 24.Отображать список услуг на экране Регистратора услуг при шаблоне welcome
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Отображать список услуг на экране Регистратора услуг при шаблоне welcome',
        'Display the list of services on the Service Registrar screen with the welcome template',
        'Отображать список услуг на экране Регистратора услуг при шаблоне welcome.',
        'Display the list of services on the Service Registrar screen with the welcome template.', 'showServices', 1);
-- 25.Отображать описание услуг на Регистраторе услуг
INSERT INTO DEVICE_SETTING (DEVICE_TYPE_ID, NAME_RU, NAME_EN, DESCRIPTION_RU, DESCRIPTION_EN, CODE, TYPE_ID)
VALUES (1, 'Отображать описание услуг на Регистраторе услуг', 'Display service description on Service Registrar', 'Отображать описание услуг на Регистраторе услуг.',
        'Display service descriptions on the Service Registrar.', 'ShowServicesDescription', 1);


--Для набора настроек по умолчанию
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (1, 1, 'true', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (2, 1, '10', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (3, 1, null, 'Обед', 'Lunch', null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (3, 1, null, 'Туалет', 'Restroom', null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (3, 1, null, 'Перекур', 'Smoke break', null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (4, 1, 'true', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (5, 1, '0', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (6, 1, '120', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (7, 1, '192.168.7.41', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (8, 1, '5', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (9, 1, null, null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (10, 1, '80', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (11, 1, '0', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (12, 1, 'Стиль 2', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (13, 1, 'DoCashQ2', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (14, 1, 'FF0000', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (15, 1, 'red', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (16, 1, 'FF0000', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (17, 1, '30', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (18, 1, '30', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (19, 1, 'false', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (20, 1, null, 'Перед Вами в очереди на данную услугу %clientsCount% человек(а). Встать в очередь?',
        'There are% clientsCount% people in front of you in the queue for this service. To get in line?', null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (21, 1, '10', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (22, 1, 'true', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (23, 1, 'true', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (24, 1, 'false', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (25, 1, 'true', null, null, null, null, null);


--Тоже самое для текущего набора настроек
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (1, 2, 'true', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (2, 2, '10', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (3, 2, null, 'Обед', 'Lunch', null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (3, 2, null, 'Туалет', 'Restroom', null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (3, 2, null, 'Перекур', 'Smoke break', null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (4, 2, 'true', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (5, 2, '0', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (6, 2, '120', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (7, 2, '192.168.7.41', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (8, 2, '5', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (9, 2, null, null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (10, 2, '80', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (11, 2, '0', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (12, 2, 'Стиль 2', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (13, 2, 'DoCashQ2', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (14, 2, 'FF0000', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (15, 2, 'red', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (16, 2, 'FF0000', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (17, 2, '30', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (18, 2, '30', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (19, 2, 'false', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (20, 2, null, 'Перед Вами в очереди на данную услугу %clientsCount% человек(а). Встать в очередь?',
        'There are% clientsCount% people in front of you in the queue for this service. To get in line?', null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (21, 2, '10', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (22, 2, 'true', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (23, 2, 'true', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (24, 2, 'false', null, null, null, null, null);
INSERT INTO DEFAULT_DEVICE_SETTING_VALUE (DEVICE_SETTING_ID, SETTINGS_KIT_ID, VALUE_COMMON, VALUE_RU, VALUE_EN, VALUE_CUSTOM_LANGUAGE1, VALUE_CUSTOM_LANGUAGE2,
                                          VALUE_CUSTOM_LANGUAGE3)
VALUES (25, 2, 'true', null, null, null, null, null);