/*
 * Залиты функции по задачам:  QFIVEDEV-383, QFIVEDEV-388, QFIVEDEV-418.
 * Изменена функция GET_CLIENT_SESSIONS. Добавлены дополнительные поля.
 * Добавлен отчет "Сводный отчет по работе оператора".
 * Добавлен отчет "Детальный отчет по работе оператора".
 * Добавлен отчет "Сводный отчет по работе оператора".
*/
-- ИЗМЕНЕНА ФУНКЦИЯ GET_CLIENT_SESSIONS. ДОБАВЛЕНЫ ДОПОЛНИТЕЛЬНЫЕ ПОЛЯ.-----------------------------------------------------------

DROP FUNCTION IF EXISTS GET_CLIENT_SESSIONS;

CREATE FUNCTION GET_CLIENT_SESSIONS(IN_DATE_START TIMESTAMP WITHOUT TIME ZONE, IN_DATE_END TIMESTAMP WITHOUT TIME ZONE, IN_DEPARTMENT_ID BIGINT)
    RETURNS TABLE(CLIENT_ID BIGINT, WAITING_TIME INTEGER, SERVICE_TIME INTEGER, REG_DT TIMESTAMP WITHOUT TIME ZONE, CALL_DT TIMESTAMP WITHOUT TIME ZONE, FINISH_DT TIMESTAMP WITHOUT TIME ZONE, SESSION_STATUS BIGINT, DEPARTMENT_ID BIGINT, USER_ID BIGINT, TICKET TEXT,OPERATION_ID BIGINT,
                  OPERATION_NAME_RU TEXT, OPERATION_NAME_EN TEXT, OPERATION_NAME_CUSTOM1 TEXT, OPERATION_NAME_CUSTOM2 TEXT,
                  OPERATION_NAME_CUSTOM3 TEXT, WORKPLACE_ID BIGINT, WORKPLACE_NAME_RU TEXT,
                  WORKPLACE_NAME_EN TEXT, WORKPLACE_NAME_CUSTOM TEXT, OPERATOR_NAME TEXT, FINISH_EVENT_TYPE_ID INTEGER)
    LANGUAGE PLPGSQL
AS
$$
DECLARE
    EVENT_LOOP EVENT%ROWTYPE;
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ВЫВОДА.
    CREATE TEMPORARY TABLE IF NOT EXISTS TEMP_CLIENT_SESSIONS
    (
        CLIENT_ID      BIGINT,
        WAITING_TIME   INTEGER DEFAULT 0,
        SERVICE_TIME   INTEGER DEFAULT 0,
        REG_DT         TIMESTAMP,
        CALL_DT        TIMESTAMP,
        FINISH_DT      TIMESTAMP,
        -- SESSION_STATUS: 0(СЕССИЯ ОТКРЫТА, КЛИЕНТ В ОЧЕРЕДИ), 1(КЛИЕНТ ОБСЛУЖИВАЕТСЯ ОПЕРАТОРОМ), 2(СЕССИЯ ЗАКРЫТА, ОБСЛУЖИВАНИЕ ЗАВЕРШЕНО), 3(СЕССИЯ ЗАВЕРШЕНА, КЛИЕНТ УДАЛЕН)
        SESSION_STATUS BIGINT,
        DEPARTMENT_ID BIGINT,
        USER_ID BIGINT,
        TICKET TEXT,
        OPERATION_ID BIGINT,
        OPERATION_NAME_RU TEXT,
        OPERATION_NAME_EN TEXT,
        OPERATION_NAME_CUSTOM1 TEXT,
        OPERATION_NAME_CUSTOM2 TEXT,
        OPERATION_NAME_CUSTOM3 TEXT,
        WORKPLACE_ID BIGINT,
        WORKPLACE_NAME_RU TEXT,
        WORKPLACE_NAME_EN TEXT,
        WORKPLACE_NAME_CUSTOM TEXT,
        OPERATOR_NAME TEXT,
        FINISH_EVENT_TYPE_ID INTEGER
    );

    -- СОЗДАТЬ ЦИКЛ ПО ТАБЛИЦЕ EVENT С КЛИЕНТСКИМИ ТИПАМИ СОБЫТИЙ.
    FOR EVENT_LOOP IN SELECT *
                      FROM EVENT E
                      WHERE (E.DEPARTMENT_ID = IN_DEPARTMENT_ID OR IN_DEPARTMENT_ID = -1)
                        AND E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END
                        AND E.CLIENT_ID IS NOT NULL
                        AND E.EVENT_TYPE_ID IN (9, 10, 11, 14, 15, 16, 19, 20, 21, 22, 23)
                      ORDER BY CLIENT_ID, DATE_TIME_COLUMN
        LOOP
            -- РЕГИСТРАЦИЯ КЛИЕНТА [%S%S] НА УСЛУГУ [%S].
            IF EVENT_LOOP.EVENT_TYPE_ID = 9 THEN
                INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID, TICKET, OPERATION_ID, OPERATION_NAME_RU,
                                                  OPERATION_NAME_EN, OPERATION_NAME_CUSTOM1, OPERATION_NAME_CUSTOM2, OPERATION_NAME_CUSTOM3,
                                                  WORKPLACE_ID, WORKPLACE_NAME_RU, WORKPLACE_NAME_EN, WORKPLACE_NAME_CUSTOM, OPERATOR_NAME, FINISH_EVENT_TYPE_ID)
                VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID, CONCAT(EVENT_LOOP.CLIENT_TICKET_LETTER, EVENT_LOOP.CLIENT_TICKET_NUMBER),
                        EVENT_LOOP.OPERATION_ID, EVENT_LOOP.OPERATION_NAME_RU, EVENT_LOOP.OPERATION_NAME_EN, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE1, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE2, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE3,
                        EVENT_LOOP.WORKPLACE_ID, EVENT_LOOP.WORKPLACE_NAME_RU, EVENT_LOOP.WORKPLACE_NAME_EN, EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE, CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ',EVENT_LOOP.USER_LAST_NAME), EVENT_LOOP.EVENT_TYPE_ID);
            END IF;

            -- РЕГИСТРАЦИЯ КЛИЕНТА [%S%S] НА УСЛУГУ  [%S] С ПОМОЩЬЮ СПЕЦИАЛЬНОЙ РЕГИСТРАЦИИ.
            IF EVENT_LOOP.EVENT_TYPE_ID = 14 THEN
                IF EXISTS(SELECT * FROM EVENT E WHERE EVENT_LOOP.CLIENT_ID = E.CLIENT_ID AND E.EVENT_TYPE_ID = 10) AND
                   NOT EXISTS(SELECT * FROM EVENT E WHERE EVENT_LOOP.CLIENT_ID = E.CLIENT_ID AND E.EVENT_TYPE_ID IN (15, 20))
                THEN
                    INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID, TICKET, OPERATION_ID, OPERATION_NAME_RU,
                                                      OPERATION_NAME_EN, OPERATION_NAME_CUSTOM1, OPERATION_NAME_CUSTOM2, OPERATION_NAME_CUSTOM3, WORKPLACE_ID, WORKPLACE_NAME_RU, WORKPLACE_NAME_EN, WORKPLACE_NAME_CUSTOM, OPERATOR_NAME, FINISH_EVENT_TYPE_ID)
                    VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID, CONCAT(EVENT_LOOP.CLIENT_TICKET_LETTER, EVENT_LOOP.CLIENT_TICKET_NUMBER),
                            EVENT_LOOP.OPERATION_ID, EVENT_LOOP.OPERATION_NAME_RU, EVENT_LOOP.OPERATION_NAME_EN, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE1, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE2, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE3,
                            EVENT_LOOP.WORKPLACE_ID, EVENT_LOOP.WORKPLACE_NAME_RU, EVENT_LOOP.WORKPLACE_NAME_EN, EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE, CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ',EVENT_LOOP.USER_LAST_NAME), EVENT_LOOP.EVENT_TYPE_ID);
                ELSE
                    INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, CALL_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID, TICKET, OPERATION_ID, OPERATION_NAME_RU,
                                                      OPERATION_NAME_EN, OPERATION_NAME_CUSTOM1, OPERATION_NAME_CUSTOM2, OPERATION_NAME_CUSTOM3, WORKPLACE_ID, WORKPLACE_NAME_RU, WORKPLACE_NAME_EN, WORKPLACE_NAME_CUSTOM, OPERATOR_NAME, FINISH_EVENT_TYPE_ID)
                    VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID, CONCAT(EVENT_LOOP.CLIENT_TICKET_LETTER, EVENT_LOOP.CLIENT_TICKET_NUMBER), EVENT_LOOP.OPERATION_ID,
                            EVENT_LOOP.OPERATION_NAME_RU, EVENT_LOOP.OPERATION_NAME_EN, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE1, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE2, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE3,
                            EVENT_LOOP.WORKPLACE_ID, EVENT_LOOP.WORKPLACE_NAME_RU, EVENT_LOOP.WORKPLACE_NAME_EN, EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE, CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ',EVENT_LOOP.USER_LAST_NAME), EVENT_LOOP.EVENT_TYPE_ID);
                END IF;

            END IF;

            -- ВЫЗОВ КЛИЕНТА [%S%S] ПО УСЛУГЕ [%S].
            IF EVENT_LOOP.EVENT_TYPE_ID = 10 THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET WAITING_TIME   = TCS.WAITING_TIME +
                                     DATE_DIFF('SECOND', TCS.REG_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    CALL_DT        = EVENT_LOOP.DATE_TIME_COLUMN,
                    OPERATOR_NAME = CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ',EVENT_LOOP.USER_LAST_NAME),
                    WORKPLACE_ID = EVENT_LOOP.WORKPLACE_ID,
                    WORKPLACE_NAME_RU = EVENT_LOOP.WORKPLACE_NAME_RU,
                    WORKPLACE_NAME_EN = EVENT_LOOP.WORKPLACE_NAME_EN,
                    WORKPLACE_NAME_CUSTOM = EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS = 1
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ПЕРЕВОД КЛИЕНТА [%S%S] ИЗ ОКНА [%S] В ОКНО [%S]. ПРИЧИНА ПЕРЕВОДА: [%S].
            -- НАЗНАЧЕНИЕ КЛИЕНТА [%S%S] ОКНУ [%S]. ПРИЧИНА ПЕРЕВОДА: [%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID IN (15, 23)) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME   = TCS.SERVICE_TIME +
                                     DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    REG_DT         = EVENT_LOOP.DATE_TIME_COLUMN,
                    OPERATOR_NAME = CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ',EVENT_LOOP.USER_LAST_NAME),
                    WORKPLACE_ID = EVENT_LOOP.WORKPLACE_ID,
                    WORKPLACE_NAME_RU = EVENT_LOOP.WORKPLACE_NAME_RU,
                    WORKPLACE_NAME_EN = EVENT_LOOP.WORKPLACE_NAME_EN,
                    WORKPLACE_NAME_CUSTOM = EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ОТКЛАДЫВАНИЕ КЛИЕНТА [%S%S] НА [%D] МИНУТ.
            -- СБРОС КЛИЕНТА [%S%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID IN (19, 22)) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME   = TCS.SERVICE_TIME +
                                     DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ВОЗВРАЩЕНИЕ КЛИЕНТА [%S%S] В ОЧЕРЕДЬ.
            IF (EVENT_LOOP.EVENT_TYPE_ID = 20) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET REG_DT         = EVENT_LOOP.DATE_TIME_COLUMN,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ЗАВЕРШЕНИЕ ОБСЛУЖИВАНИЯ КЛИЕНТА [%S%S] ПО УСЛУГЕ [%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID = 11) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME   = TCS.SERVICE_TIME +
                                     DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    FINISH_DT      = EVENT_LOOP.DATE_TIME_COLUMN,
                    OPERATOR_NAME = CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ',EVENT_LOOP.USER_LAST_NAME),
                    WORKPLACE_ID = EVENT_LOOP.WORKPLACE_ID,
                    WORKPLACE_NAME_RU = EVENT_LOOP.WORKPLACE_NAME_RU,
                    WORKPLACE_NAME_EN = EVENT_LOOP.WORKPLACE_NAME_EN,
                    WORKPLACE_NAME_CUSTOM = EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS = 2
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- УДАЛЕНИЕ КЛИЕНТА [%S%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID = 21) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME   = TCS.SERVICE_TIME +
                                     DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    FINISH_DT      = EVENT_LOOP.DATE_TIME_COLUMN,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS = 3
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;
        END LOOP;

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ.
    RETURN QUERY
        SELECT TCS.CLIENT_ID, TCS.WAITING_TIME, TCS.SERVICE_TIME, TCS.REG_DT, TCS.CALL_DT, TCS.FINISH_DT, TCS.SESSION_STATUS, TCS.USER_ID, TCS.DEPARTMENT_ID,TCS.TICKET,
               TCS.OPERATION_ID, TCS.OPERATION_NAME_RU, TCS.OPERATION_NAME_EN, TCS.OPERATION_NAME_CUSTOM1, TCS.OPERATION_NAME_CUSTOM2, TCS.OPERATION_NAME_CUSTOM3,
               TCS.WORKPLACE_ID, TCS.WORKPLACE_NAME_RU, TCS.WORKPLACE_NAME_EN, TCS.WORKPLACE_NAME_CUSTOM, TCS.OPERATOR_NAME, TCS.FINISH_EVENT_TYPE_ID
        FROM TEMP_CLIENT_SESSIONS TCS;

    -- УДАЛИТЬ ВРЕМЕННУЮ ТАБЛИЦУ.
    DROP TABLE TEMP_CLIENT_SESSIONS;
END;
$$;


-------------------------------------------------------- GET_OPERATOR_SESSIONS ---------------------------------------------------------
DROP FUNCTION IF EXISTS GET_OPERATOR_SESSIONS;

CREATE FUNCTION GET_OPERATOR_SESSIONS(IN_DATESTART TIMESTAMP,
                                      IN_DATEEND TIMESTAMP, IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID                             BIGINT,
                DEPARTMENT_ID                  BIGINT,
                DEPARTMENT_NAME                TEXT,
                USER_ID                        BIGINT,
                USER_LOGIN                     TEXT,
                USER_FIRST_NAME                TEXT,
                USER_LAST_NAME                 TEXT,
                USER_MIDDLE_NAME               TEXT,
                WORKPLACE_ID                   BIGINT,
                WORKPLACE_NAME                 TEXT,
                START_DT                       TIMESTAMP WITHOUT TIME ZONE,
                START_EVENT_TYPE_ID            BIGINT,
                FINISH_DT                      TIMESTAMP WITHOUT TIME ZONE,
                FINISH_EVENT_TYPE_ID           BIGINT,
                FLAG_FULL_SESSION              INTEGER
            )
    LANGUAGE PLPGSQL
AS
$$
DECLARE
    EVENT_LOOP          EVENT%ROWTYPE;
    OPERATOR_SESSION_ID BIGINT := 1;
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ВЫВОДА.
    CREATE TEMPORARY TABLE IF NOT EXISTS TEMP_OPERATOR_SESSIONS
    (
        ID                             BIGINT,
        DEPARTMENT_ID                  BIGINT,
        DEPARTMENT_NAME                TEXT,
        USER_ID                        BIGINT,
        USER_LOGIN                     TEXT,
        USER_FIRST_NAME                TEXT,
        USER_LAST_NAME                 TEXT,
        USER_MIDDLE_NAME               TEXT,
        WORKPLACE_ID                   BIGINT,
        WORKPLACE_NAME                  TEXT,
        START_DT                       TIMESTAMP WITHOUT TIME ZONE,
        START_EVENT_TYPE_ID            BIGINT,
        FINISH_DT                      TIMESTAMP WITHOUT TIME ZONE,
        FINISH_EVENT_TYPE_ID           BIGINT,
        FLAG_FULL_SESSION              INTEGER
    );

    -- СОЗДАТЬ ЦИКЛ ПО ТАБЛИЦЕ EVENT С КЛИЕНТСКИМИ ТИПАМИ СОБЫТИЙ.
    FOR EVENT_LOOP IN SELECT *
                      FROM EVENT E
                      WHERE E.USER_ID IS NOT NULL
                        AND E.USER_ACCESS_GROUP_ID = 4
                        AND E.EVENT_TYPE_ID IN (1, 2, 10, 11, 12, 13, 15, 16, 17, 18, 19, 20, 22, 23, 36, 37)
                        AND (E.DATE_TIME_COLUMN BETWEEN IN_DATESTART AND IN_DATEEND)
                        AND E.USER_ACCESS_GROUP_ID = 4
                      ORDER BY E.ID, E.USER_ID, E.DATE_TIME_COLUMN
        LOOP
        --------------------------------------------
        -- 1 - ВХОД В СИСТЕМУ
        -- 10 - ВЫЗОВ КЛИЕНТА [%S%D] ПО УСЛУГЕ [%S]
        -- 11 - ЗАВЕРШЕНИЕ ОБСЛУЖИВАНИЯ КЛИЕНТА [%S%D] ПО УСЛУГЕ [%S]
        -- 12 - ЯВКА КЛИЕНТА [%S%D]
        -- 13 - НЕЯВКА КЛИЕНТА [%S%D]
        -- 15 - ПЕРЕВОД КЛИЕНТА [%S%D] ИЗ ОКНА [%S] В ОКНО [%S]. ПРИЧИНА ПЕРЕВОДА: [%S]
        -- 16 - ИЗМЕНЕНИЕ КЛИЕНТУ [%S%D] УСЛУГИ C [%S] НА [%S]. ПРИЧИНА ПЕРЕВОДА: [%S]
        -- 17 - НАЧАЛО ПОСТ-ОБРАБОТКИ ПОЛЬЗОВАТЕЛЕМ [%S].
        -- 18 - ЗАВЕРШЕНИЕ ПОСТ-ОБРАБОТКИ ПОЛЬЗОВАТЕЛЕМ [%S]
        -- 19 - ОТКЛАДЫВАНИЕ КЛИЕНТА [%S%D] НА [%D] МИНУТ
        -- 20 - ВОЗВРАЩЕНИЕ КЛИЕНТА [%S%D] В ОЧЕРЕДЬ
        -- 22 - СБРОС КЛИЕНТА [%S%D]
        -- 23 - НАЗНАЧЕНИЕ КЛИЕНТА [%S%D] ОКНУ [%S]. ПРИЧИНА ПЕРЕВОДА: [%S]
        --ЕСЛИ ОПЕРАТОР ТОЛЬКО АВТОРИЗОВАЛСЯ ЛИБО НЕТ ОТКРЫТЫХ СЕССИЙ
            IF (EVENT_LOOP.EVENT_TYPE_ID IN (1)) OR
               (EVENT_LOOP.EVENT_TYPE_ID IN (7, 8, 9, 10, 11, 12, 13, 38, 53, 54) AND
                ((SELECT COUNT(*)
                  FROM TEMP_OPERATOR_SESSIONS S
                  WHERE EXTRACT(DAYS FROM (EVENT_LOOP.DATE_TIME_COLUMN - S.START_DT)) <= 1
                    AND S.START_DT <= EVENT_LOOP.DATE_TIME_COLUMN
                    AND S.DEPARTMENT_ID = EVENT_LOOP.DEPARTMENT_ID
                    AND S.WORKPLACE_ID = EVENT_LOOP.WORKPLACE_ID
                    AND S.USER_ID = EVENT_LOOP.USER_ID
                    AND S.FLAG_FULL_SESSION = 0) = 0))
            THEN
                UPDATE TEMP_OPERATOR_SESSIONS S
                SET FINISH_DT            = EVENT_LOOP.DATE_TIME_COLUMN,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    FLAG_FULL_SESSION    = 2
                WHERE EXTRACT(DAYS FROM (EVENT_LOOP.DATE_TIME_COLUMN - S.START_DT)) <= 1
                  AND S.START_DT < EVENT_LOOP.DATE_TIME_COLUMN
                  AND S.DEPARTMENT_ID = EVENT_LOOP.DEPARTMENT_ID
                  AND S.WORKPLACE_ID = EVENT_LOOP.WORKPLACE_ID
                  AND S.USER_ID = EVENT_LOOP.USER_ID
                  AND S.FLAG_FULL_SESSION = 0;

                INSERT INTO TEMP_OPERATOR_SESSIONS (ID,
                                                    DEPARTMENT_ID,
                                                    DEPARTMENT_NAME,
                                                    USER_ID,
                                                    USER_LOGIN,
                                                    USER_FIRST_NAME,
                                                    USER_LAST_NAME,
                                                    USER_MIDDLE_NAME,
                                                    WORKPLACE_ID,
                                                    WORKPLACE_NAME,
                                                    START_DT,
                                                    START_EVENT_TYPE_ID,
                                                    FINISH_DT,
                                                    FINISH_EVENT_TYPE_ID,
                                                    FLAG_FULL_SESSION)
                VALUES (OPERATOR_SESSION_ID,
                        EVENT_LOOP.DEPARTMENT_ID,
                        CASE
                                WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                                    THEN EVENT_LOOP.DEPARTMENT_NAME_EN
                                WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                                    THEN EVENT_LOOP.DEPARTMENT_NAME_RU
                                ELSE EVENT_LOOP.DEPARTMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                            END,
                        EVENT_LOOP.USER_ID,
                        EVENT_LOOP.USER_LOGIN,
                        EVENT_LOOP.USER_FIRST_NAME,
                        EVENT_LOOP.USER_LAST_NAME,
                        EVENT_LOOP.USER_MIDDLE_NAME,
                        EVENT_LOOP.WORKPLACE_ID,
                        CASE
                            WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                                THEN EVENT_LOOP.WORKPLACE_NAME_EN
                            WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                                THEN EVENT_LOOP.WORKPLACE_NAME_RU
                            ELSE EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                            END,
                        EVENT_LOOP.DATE_TIME_COLUMN,
                        EVENT_LOOP.EVENT_TYPE_ID,
                        EVENT_LOOP.DATE_TIME_COLUMN,
                        EVENT_LOOP.EVENT_TYPE_ID,
                        0);
                OPERATOR_SESSION_ID := OPERATOR_SESSION_ID + 1;
            END IF;
            -- НАЧАЛО ПЕРЕРЫВА ОПЕРАТОРА
            IF EVENT_LOOP.EVENT_TYPE_ID = 36 THEN
                UPDATE TEMP_OPERATOR_SESSIONS S
                SET FINISH_DT            = EVENT_LOOP.DATE_TIME_COLUMN,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    FLAG_FULL_SESSION    = 1
                WHERE EXTRACT(DAYS FROM (EVENT_LOOP.DATE_TIME_COLUMN - S.START_DT)) <= 1
                  -- DATE_DIFF('DAY', EVENT_LOOP.DATE_TIME_COLUMN, S.START_DT) <= 1
                  AND S.START_DT < EVENT_LOOP.DATE_TIME_COLUMN
                  AND S.DEPARTMENT_ID = EVENT_LOOP.DEPARTMENT_ID
                  AND S.USER_ID = EVENT_LOOP.USER_ID
                  AND S.FLAG_FULL_SESSION = 0;

            END IF;

            -- КОНЕЦ ПЕРЕРЫВА ОПЕРАТОРА
            IF EVENT_LOOP.EVENT_TYPE_ID = 37 THEN
                INSERT INTO TEMP_OPERATOR_SESSIONS (ID,
                                                    DEPARTMENT_ID,
                                                    DEPARTMENT_NAME,
                                                    USER_ID,
                                                    USER_LOGIN,
                                                    USER_FIRST_NAME,
                                                    USER_LAST_NAME,
                                                    USER_MIDDLE_NAME,
                                                    WORKPLACE_ID,
                                                    WORKPLACE_NAME,
                                                    START_DT,
                                                    START_EVENT_TYPE_ID,
                                                    FINISH_DT,
                                                    FINISH_EVENT_TYPE_ID,
                                                    FLAG_FULL_SESSION)
                VALUES (OPERATOR_SESSION_ID,
                        EVENT_LOOP.DEPARTMENT_ID,
                        CASE
                            WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                                THEN EVENT_LOOP.DEPARTMENT_NAME_EN
                            WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                                THEN EVENT_LOOP.DEPARTMENT_NAME_RU
                            ELSE EVENT_LOOP.DEPARTMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                            END,
                        EVENT_LOOP.USER_ID,
                        EVENT_LOOP.USER_LOGIN,
                        EVENT_LOOP.USER_FIRST_NAME,
                        EVENT_LOOP.USER_LAST_NAME,
                        EVENT_LOOP.USER_MIDDLE_NAME,
                        EVENT_LOOP.WORKPLACE_ID,
                        CASE
                            WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                                THEN EVENT_LOOP.WORKPLACE_NAME_EN
                            WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                                THEN EVENT_LOOP.WORKPLACE_NAME_RU
                            ELSE EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                            END,
                        EVENT_LOOP.DATE_TIME_COLUMN,
                        EVENT_LOOP.EVENT_TYPE_ID,
                        EVENT_LOOP.DATE_TIME_COLUMN,
                        EVENT_LOOP.EVENT_TYPE_ID,
                        0);
                OPERATOR_SESSION_ID := OPERATOR_SESSION_ID + 1;
            END IF;

            -- ВЫХОД ИЗ СИСТЕМЫ
            IF EVENT_LOOP.EVENT_TYPE_ID = 2 THEN
                UPDATE TEMP_OPERATOR_SESSIONS S
                SET FINISH_DT            = EVENT_LOOP.DATE_TIME_COLUMN,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    FLAG_FULL_SESSION    = 2
                WHERE EXTRACT(DAYS FROM (EVENT_LOOP.DATE_TIME_COLUMN - S.START_DT)) <= 1
                  -- DATE_DIFF('DAY', EVENT_LOOP.DATE_TIME_COLUMN, S.START_DT) <= 1
                  AND S.START_DT < EVENT_LOOP.DATE_TIME_COLUMN
                  AND S.DEPARTMENT_ID = EVENT_LOOP.DEPARTMENT_ID
                  AND S.USER_ID = EVENT_LOOP.USER_ID
                  AND S.FLAG_FULL_SESSION = 0;
            END IF;
        END LOOP;

    -------------------------------------------------
    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ.
    RETURN QUERY
        SELECT * FROM TEMP_OPERATOR_SESSIONS ORDER BY ID;

    -- УДАЛИТЬ ВРЕМЕННУЮ ТАБЛИЦУ.
    DROP TABLE TEMP_OPERATOR_SESSIONS;
END;
$$;


------------------------------------------------ REPORT_OPERATOR_WORK_SUMMARY-------------------------------------------------
DROP FUNCTION IF EXISTS REPORT_OPERATOR_WORK_SUMMARY;

CREATE FUNCTION REPORT_OPERATOR_WORK_SUMMARY(IN_DEPARTMENTID BIGINT, IN_DATESTART TIMESTAMP WITHOUT TIME ZONE, IN_DATEEND TIMESTAMP WITHOUT TIME ZONE, IN_USERID BIGINT, IN_GROUPMONTH BOOLEAN, IN_GROUPDAY BOOLEAN, IN_GROUPHOUR BOOLEAN, IN_GROUPDEPARTMENTID BOOLEAN, IN_GROUPUSERID BOOLEAN, IN_PREV_PAGE_LAST_ID BIGINT, IN_PAGE_SIZE BIGINT, IN_ORDER_BY_COLUMN_ID INTEGER, IN_IS_DESCENDING BOOLEAN, IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE(ID BIGINT, YEAR INTEGER, MONTH INTEGER, DAY INTEGER, HOUR INTEGER, DEPARTMENT_NAME TEXT, USER_NAME TEXT, SUM_WORKPLACE_TIME NUMERIC, CLIENT_SERVICE_TIME INTEGER, DOWNTIME NUMERIC, DOWNTIME_PERCENT NUMERIC)
    SECURITY DEFINER
    LANGUAGE PLPGSQL
AS
$$
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ОБРАБОТКИ ДАННЫХ.
    CREATE TEMPORARY TABLE TABLE_OPERATOR (
                                              ID BIGINT,
                                              DT_YEAR INT,
                                              DT_MONTH INT,
                                              DT_DAY INT,
                                              DT_HOUR INT,

                                              DEPARTMENT_ID BIGINT,
                                              DEPARTMENT_NAME TEXT,
                                              USER_ID BIGINT,
                                              USER_NAME  TEXT,

                                              SESSION_TIME NUMERIC,
                                              SERVICE_TIME INTEGER
    )ON COMMIT DROP;

    CREATE TEMPORARY TABLE TEMP_RESULT_TABLE (
                                                 ID                               BIGINT,           -- НОМЕР СТРОКИ
                                                 DT_YEAR INT,
                                                 DT_MONTH INT,
                                                 DT_DAY INT,
                                                 DT_HOUR INT,

                                                 DEPARTMENT_NAME                  TEXT,             -- ОТДЕЛЕНИЕ
                                                 USER_NAME                        TEXT,
                                                 SUM_WORKPLACE_TIME              NUMERIC,           -- СУММАРНОЕ НАХОЖДЕНИЕ НА РАБОЧЕМ МЕСТЕ
                                                 CLIENT_SERVICE_TIME             INTEGER,           -- ВРЕМЯ ОБСЛУЖИВАНИЯ КЛИЕНТОВ
                                                 DOWNTIME                        NUMERIC,           -- (В Q2 - ВРЕМЯ ПРОСТОЯ)
                                                 DOWNTIME_PERCENT                NUMERIC          -- ПРОЦЕНТ ВРЕМЕНИ ПРОСТОЯ ОТ ВРЕМЕНИ НАХОЖДЕНИЯ ЗА СТОЙКОЙ, %
    )ON COMMIT DROP;

    INSERT INTO TABLE_OPERATOR(ID,
                               DT_YEAR,
                               DT_MONTH,
                               DT_DAY,
                               DT_HOUR,

                               DEPARTMENT_ID,
                               DEPARTMENT_NAME,
                               USER_ID,
                               USER_NAME,

                               SESSION_TIME,
                               SERVICE_TIME)
    SELECT
                ROW_NUMBER() OVER (PARTITION BY 1),
                DATE_PART('YEAR', MIN(O.START_DT)),
                DATE_PART('MONTH', MIN(O.START_DT)),
                DATE_PART('DAY', MIN(O.START_DT)),
                DATE_PART('HOUR', MIN(O.START_DT)),
                MAX(O.DEPARTMENT_ID),
                MAX(O.DEPARTMENT_NAME),
                MAX(O.USER_ID),
                CASE
                    WHEN MAX(O.USER_FIRST_NAME) || ' ' || MAX(O.USER_MIDDLE_NAME) || ' ' || MAX(O.USER_LAST_NAME) IS NOT NULL THEN
                                        MAX(O.USER_FIRST_NAME) || ' ' || MAX(O.USER_MIDDLE_NAME) || ' ' || MAX(O.USER_LAST_NAME)
                    ELSE MAX(O.USER_LOGIN) END,

                MAX(DATE_DIFF('SECOND', START_DT, FINISH_DT)),
                (SELECT SUM(CS.SERVICE_TIME)
                 FROM GET_CLIENT_SESSIONS(IN_DATESTART, IN_DATEEND, IN_DEPARTMENTID) CS
                 WHERE CS.DEPARTMENT_ID = O.DEPARTMENT_ID
                   AND CS.USER_ID = O.USER_ID )
    FROM GET_OPERATOR_SESSIONS(IN_DATESTART, IN_DATEEND, IN_CURRENT_LANGUAGE_ID) O
    WHERE ((O.START_DT BETWEEN IN_DATESTART AND IN_DATEEND) OR
           (O.FINISH_DT BETWEEN IN_DATESTART AND IN_DATEEND))
      AND (O.USER_ID = IN_USERID OR IN_USERID = -1)
      --GROUP BY O.DEPARTMENT_ID, O.SESSION_ID, O.USER_ID;
    GROUP BY O.DEPARTMENT_ID, O.ID, O.USER_ID;

    INSERT INTO TEMP_RESULT_TABLE(
        ID                             ,           -- НОМЕР СТРОКИ
        DT_YEAR                       , -- ГОД
        DT_MONTH                       , -- МЕСЯЦ
        DT_DAY                         , -- ДЕНЬ
        DT_HOUR                        , -- ЧАС

        DEPARTMENT_NAME                  ,             -- ОТДЕЛЕНИЕ
        USER_NAME                        ,
        SUM_WORKPLACE_TIME              ,           -- СУММАРНОЕ НАХОЖДЕНИЕ НА РАБОЧЕМ МЕСТЕ
        CLIENT_SERVICE_TIME             ,           -- ВРЕМЯ ОБСЛУЖИВАНИЯ КЛИЕНТОВ
        DOWNTIME                        ,           -- (В Q2 - ВРЕМЯ ПРОСТОЯ)
        DOWNTIME_PERCENT                          -- ПРОЦЕНТ ВРЕМЕНИ ПРОСТОЯ ОТ ВРЕМЕНИ НАХОЖДЕНИЯ ЗА СТОЙКОЙ, %
    )
        (SELECT MAX(T.ID) ID,
                MAX(T.DT_YEAR) DT_YEAR,
                MAX(T.DT_MONTH) DT_MONTH,
                MAX(T.DT_DAY) DT_DAY,
                MAX(T.DT_HOUR) DT_HOUR,
                MAX(T.DEPARTMENT_NAME) DEPARTMENT_NAME,
                MAX(T.USER_NAME) USER_NAME,
                SUM(T.SESSION_TIME) SUM_WORKPLACE_TIME,
                SUM(T.SERVICE_TIME) CLIENT_SERVICE_TIME,
                CASE WHEN SUM(T.SESSION_TIME) IS NOT NULL AND SUM(T.SERVICE_TIME)IS NOT NULL THEN SUM(T.SESSION_TIME) - SUM(T.SERVICE_TIME) ELSE 0 END AS DOWNTIME,
                CASE WHEN SUM(T.SESSION_TIME) > 0 THEN (1 - SUM(T.SERVICE_TIME) / SUM(T.SESSION_TIME))*100 END AS DOWNTIME_PERCENT
         FROM
             TABLE_OPERATOR T  GROUP BY CASE WHEN IN_GROUPMONTH = TRUE OR IN_GROUPDAY = TRUE OR IN_GROUPHOUR = TRUE THEN T.DT_YEAR ELSE NULL END,
                                        CASE WHEN IN_GROUPMONTH = TRUE OR IN_GROUPDAY = TRUE OR IN_GROUPHOUR = TRUE THEN T.DT_MONTH ELSE NULL END,
                                        CASE WHEN IN_GROUPDAY = TRUE OR IN_GROUPHOUR = TRUE THEN T.DT_DAY ELSE NULL END,
                                        CASE WHEN IN_GROUPHOUR = TRUE THEN T.DT_HOUR ELSE NULL END,
                                        CASE WHEN IN_GROUPDEPARTMENTID = TRUE OR IN_GROUPUSERID = TRUE THEN T.DEPARTMENT_ID ELSE NULL END,
                                        CASE WHEN IN_GROUPUSERID = TRUE THEN T.USER_ID ELSE NULL END,
                                        CASE WHEN NOT (IN_GROUPMONTH = TRUE OR
                                                       IN_GROUPDAY = TRUE OR
                                                       IN_GROUPHOUR = TRUE OR
                                                       IN_GROUPDEPARTMENTID = TRUE OR
                                                       IN_GROUPUSERID = TRUE) THEN T.ID ELSE NULL END);

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ TEMP_RESULT_TABLE, ДОБАВИТЬ СОРТИРОВКУ, ПАГИНАЦИЮ И ИТОГИ.
    RETURN QUERY
        (SELECT TRT.ID, TRT.DT_YEAR, TRT.DT_MONTH, TRT.DT_DAY, TRT.DT_HOUR, TRT.DEPARTMENT_NAME, TRT.USER_NAME, TRT.SUM_WORKPLACE_TIME, TRT.CLIENT_SERVICE_TIME, TRT.DOWNTIME, TRT.DOWNTIME_PERCENT
         FROM TEMP_RESULT_TABLE TRT
         WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN TRT.ID > IN_PREV_PAGE_LAST_ID ELSE TRT.ID < IN_PREV_PAGE_LAST_ID END
         ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN TRT.ID END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN TRT.ID END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN TRT.DT_YEAR END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN TRT.DT_YEAR END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN TRT.DT_MONTH END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN TRT.DT_MONTH END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN TRT.DT_DAY END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN TRT.DT_DAY END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN TRT.DT_HOUR END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN TRT.DT_HOUR END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN TRT.DEPARTMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN TRT.DEPARTMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN TRT.USER_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN TRT.USER_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = TRUE THEN TRT.SUM_WORKPLACE_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = FALSE THEN TRT.SUM_WORKPLACE_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = TRUE THEN TRT.CLIENT_SERVICE_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = FALSE THEN TRT.CLIENT_SERVICE_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = TRUE THEN TRT.DOWNTIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = FALSE THEN TRT.DOWNTIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = TRUE THEN TRT.DOWNTIME_PERCENT END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = FALSE THEN TRT.DOWNTIME_PERCENT END) ASC

         LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END);

END
$$;

----------------------------------------------- REPORT_DETAIL_OPERATOR_WORK -------------------------------------------------------------------
DROP FUNCTION IF EXISTS REPORT_DETAIL_OPERATOR_WORK;

CREATE FUNCTION REPORT_DETAIL_OPERATOR_WORK(IN IN_DEPARTMENTID BIGINT,
                                            IN IN_DATESTART TIMESTAMP,
                                            IN IN_DATEEND TIMESTAMP,
                                            IN IN_USERID BIGINT,
                                            IN_PREV_PAGE_LAST_ID BIGINT,
                                            IN_PAGE_SIZE BIGINT,
                                            IN_ORDER_BY_COLUMN_ID INTEGER,
                                            IN_IS_DESCENDING BOOLEAN,
                                            IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID              BIGINT,
                DEPARTMENT_NAME TEXT,      -- ОТДЕЛЕНИЕ
                USER_NAME       TEXT,      -- ОПЕРАТОР
                INTERVAL_TYPE   TEXT,
                START_DT        TIMESTAMP, -- НАЧАЛО ИНТЕРВАЛА
                END_DT          TIMESTAMP, -- ОКОНЧАНИЕ ИНТЕРВАЛА
                SESSION_TIME    INT        -- ДЛИТЕЛЬНОСТЬ ИНТЕВАЛА
            )
    SECURITY DEFINER
    LANGUAGE PLPGSQL
AS
$$
DECLARE
    ID                                 BIGINT := 0;
    CUR CURSOR FOR SELECT *
                   FROM GET_OPERATOR_SESSIONS(IN_DATESTART, IN_DATEEND, IN_CURRENT_LANGUAGE_ID);
    -- R RECORD;
    CUR_SESSION_ID                     BIGINT;
    CUR_DEPARTMENT_ID                  BIGINT;
    CUR_DEPARTMENT_NAME                TEXT;
    CUR_USER_ID                        BIGINT;
    CUR_USER_LOGIN                     TEXT;
    CUR_USER_FIRST_NAME                TEXT;
    CUR_USER_LAST_NAME                 TEXT;
    CUR_USER_MIDDLE_NAME               TEXT;
    CUR_WORKPLACE_ID                   BIGINT;
    CUR_WORKPLACE_NAME                  TEXT;
    CUR_START_DT                       TIMESTAMP WITHOUT TIME ZONE;
    CUR_START_EVENT_TYPE_ID            BIGINT;
    CUR_FINISH_DT                      TIMESTAMP WITHOUT TIME ZONE;
    CUR_FINISH_EVENT_TYPE_ID           BIGINT;
    CUR_FLAG_FULL_SESSION              INTEGER;
BEGIN


    CREATE TEMPORARY TABLE TABLE_DETAIL_OPERATOR
    (
        ID              BIGINT,
        DEPARTMENT_ID   BIGINT,
        DEPARTMENT_NAME TEXT,
        SESSION_ID      BIGINT,
        START_DT        TIMESTAMP,
        FINISH_DT       TIMESTAMP,
        USER_ID         BIGINT,
        USER_NAME       TEXT,
        PRESENCE        BOOL,
        SESSION_FULL    BOOL
    ) ON COMMIT DROP;
    OPEN CUR;
    LOOP
        FETCH CUR INTO
            CUR_SESSION_ID,
            CUR_DEPARTMENT_ID,
            CUR_DEPARTMENT_NAME,
            CUR_USER_ID,
            CUR_USER_LOGIN,
            CUR_USER_FIRST_NAME,
            CUR_USER_LAST_NAME,
            CUR_USER_MIDDLE_NAME,

            CUR_WORKPLACE_ID,
            CUR_WORKPLACE_NAME,
            CUR_START_DT,
            CUR_START_EVENT_TYPE_ID,
            CUR_FINISH_DT,
            CUR_FINISH_EVENT_TYPE_ID,
            CUR_FLAG_FULL_SESSION;

        IF NOT FOUND THEN EXIT; END IF;
        ID := ID + 1;
        INSERT INTO TABLE_DETAIL_OPERATOR (ID,
                                           DEPARTMENT_ID,
                                           DEPARTMENT_NAME,
                                           SESSION_ID,
                                           START_DT,
                                           FINISH_DT,
                                           USER_ID,
                                           USER_NAME,
                                           PRESENCE,
                                           SESSION_FULL)
        VALUES (ID,
                CUR_DEPARTMENT_ID,
                CUR_DEPARTMENT_NAME,
                CUR_SESSION_ID,
                CUR_START_DT,
                CUR_FINISH_DT,
                CUR_USER_ID,
                CASE
                    WHEN CUR_USER_FIRST_NAME || ' ' || CUR_USER_MIDDLE_NAME || ' ' || CUR_USER_LAST_NAME IS NOT NULL THEN
                        CUR_USER_FIRST_NAME || ' ' || CUR_USER_MIDDLE_NAME || ' ' || CUR_USER_LAST_NAME
                    ELSE CUR_USER_LOGIN END,
                TRUE,
                TRUE);

        IF CUR_FINISH_EVENT_TYPE_ID = 36 THEN
            ID := ID + 1;
            INSERT INTO TABLE_DETAIL_OPERATOR (ID,
                                               DEPARTMENT_ID,
                                               DEPARTMENT_NAME,
                                               SESSION_ID,
                                               START_DT,
                                               USER_ID,
                                               USER_NAME,
                                               PRESENCE,
                                               SESSION_FULL)
            VALUES (ID,
                    CUR_DEPARTMENT_ID,
                    CUR_DEPARTMENT_NAME,
                    CUR_SESSION_ID,
                    CUR_FINISH_DT,
                    CUR_USER_ID,
                    CASE
                        WHEN CUR_USER_FIRST_NAME || ' ' || CUR_USER_MIDDLE_NAME || ' ' || CUR_USER_LAST_NAME IS NOT NULL THEN
                            CUR_USER_FIRST_NAME || ' ' || CUR_USER_MIDDLE_NAME || ' ' || CUR_USER_LAST_NAME
                        ELSE CUR_USER_LOGIN END,
                    FALSE,
                    FALSE);
        END IF;

        IF CUR_START_EVENT_TYPE_ID = 37 THEN
            UPDATE TABLE_DETAIL_OPERATOR TDO
            SET FINISH_DT    = CUR_START_DT,
                SESSION_FULL = TRUE
            WHERE TDO.DEPARTMENT_ID = CUR_DEPARTMENT_ID
              AND TDO.USER_ID = CUR_USER_ID
              AND TDO.SESSION_FULL = FALSE;
        END IF;



    END LOOP;
    CLOSE CUR;

    RETURN QUERY (SELECT T.ID,
                         T.DEPARTMENT_NAME,
                         T.USER_NAME,
                         CASE WHEN T.PRESENCE IS TRUE THEN 'ПРИСУТСТВИЕ' ELSE 'ОТСУТСТВИЕ' END AS INTERVAL_TYPE,
                         T.START_DT,
                         T.FINISH_DT,
                         DATE_DIFF('SECOND', T.START_DT::TIMESTAMP, T.FINISH_DT::TIMESTAMP)
                         -- EXTRACT(SECONDS FROM (T.FINISH_DT - T.START_DT))
                  FROM TABLE_DETAIL_OPERATOR T
                  WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN T.ID > IN_PREV_PAGE_LAST_ID ELSE T.ID < IN_PREV_PAGE_LAST_ID END
                  ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN T.ID END) DESC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN T.ID END) ASC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN T.DEPARTMENT_NAME END) DESC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN T.DEPARTMENT_NAME END) ASC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN T.USER_NAME END) DESC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN T.USER_NAME END) ASC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN T.PRESENCE END) DESC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN T.PRESENCE END) ASC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN T.START_DT END) DESC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN T.START_DT END) ASC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN T.FINISH_DT END) DESC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN T.FINISH_DT END) ASC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN T.SESSION_FULL END) DESC,
                           (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN T.SESSION_FULL END) ASC

                  LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END
    );
END
$$;

---------------------------------------------------- REPORT_TICKETS -----------------------------------------------------------------------
DROP FUNCTION IF EXISTS REPORT_TICKETS;

CREATE FUNCTION REPORT_TICKETS(             IN IN_DEPARTMENTID BIGINT,
                                                          IN IN_DATESTART TIMESTAMP,
                                                          IN IN_DATEEND TIMESTAMP,
                                                          IN_WORKPLACEID BIGINT,
                                                          IN_TICKET TEXT,
                                                          IN_PREV_PAGE_LAST_ID BIGINT,
                                                          IN_PAGE_SIZE BIGINT,
                                                          IN_ORDER_BY_COLUMN_ID INTEGER,
                                                          IN_IS_DESCENDING BOOLEAN,
                                                          IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID BIGINT,
                DEPARTMENT_NAME TEXT,
                TICKET TEXT,
                OPERATION_NAME TEXT,
                WORKPLACE_NAME TEXT,
                OPERATOR_NAME TEXT,
                REGISTRATION_DATE_TIME TIMESTAMP,
                START_SERVICE_TIME TIMESTAMP,
                FINISH_SERVICE_TIME TIMESTAMP,
                SERVICE_DURATION_TIME INTEGER,
                DEFERRED_TIME BIGINT,
                WAITING_DURATION_TIME INTEGER,
                PRESENCE_IN_DEPARTMENT_TIME INTEGER
            )
    SECURITY DEFINER
    LANGUAGE PLPGSQL
AS
$$
BEGIN
    CREATE TEMPORARY TABLE TABLE_RESULT
    (
        ID BIGINT,
        DEPARTMENT_NAME TEXT,
        TICKET TEXT,
        OPERATION_NAME TEXT,
        WORKPLACE_NAME TEXT,
        OPERATOR_NAME TEXT,
        REGISTRATION_DATE_TIME TIMESTAMP,
        START_SERVICE_TIME TIMESTAMP,
        FINISH_SERVICE_TIME TIMESTAMP,
        SERVICE_DURATION_TIME INTEGER,
        DEFERRED_TIME BIGINT,
        WAITING_DURATION_TIME INTEGER,
        PRESENCE_IN_DEPARTMENT_TIME INTEGER
    ) ON COMMIT DROP;

    INSERT INTO TABLE_RESULT (ID ,
                              DEPARTMENT_NAME ,
                              TICKET ,
                              OPERATION_NAME ,
                              WORKPLACE_NAME ,
                              OPERATOR_NAME ,
                              REGISTRATION_DATE_TIME ,
                              START_SERVICE_TIME ,
                              FINISH_SERVICE_TIME ,
                              SERVICE_DURATION_TIME ,
                              DEFERRED_TIME ,
                              WAITING_DURATION_TIME ,
                              PRESENCE_IN_DEPARTMENT_TIME )
    (SELECT ROW_NUMBER() OVER (PARTITION BY 1) AS ID,
                   MAX(D.NAME_RU) AS DEPARTMENT_NAME,
                   MAX(CS.TICKET),
            MAX(CASE
                    WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                        THEN CS.OPERATION_NAME_EN
                    WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                        THEN CS.OPERATION_NAME_RU
                    ELSE
                        CASE
                            WHEN CS.OPERATION_NAME_CUSTOM1 IS NOT NULL THEN
                                CS.OPERATION_NAME_CUSTOM1
                            WHEN CS.OPERATION_NAME_CUSTOM2 IS NOT NULL THEN
                                CS.OPERATION_NAME_CUSTOM2
                            WHEN CS.OPERATION_NAME_CUSTOM3 IS NOT NULL THEN
                                CS.OPERATION_NAME_CUSTOM3 -- КАСТОМНЫЙ ЯЗЫК
                            END
                END),
            MAX(CASE
                    WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                        THEN CS.WORKPLACE_NAME_EN
                    WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                        THEN CS.WORKPLACE_NAME_RU
                    ELSE CS.WORKPLACE_NAME_CUSTOM -- КАСТОМНЫЙ ЯЗЫК
                END),
                   MAX(CS.OPERATOR_NAME),
                   MAX(CS.REG_DT) AS REGISTRATION_DATE_TIME,
                   MAX(CS.CALL_DT),
                   MAX(CS.FINISH_DT),
                   MAX(CS.SERVICE_TIME),
                   SUM(CASE WHEN CS.FINISH_EVENT_TYPE_ID IN (19) THEN
                                (DATE_DIFF('SECOND',CS.FINISH_DT, (SELECT E.DATE_TIME_COLUMN FROM EVENT E
                                                                   WHERE E.DATE_TIME_COLUMN BETWEEN CS.FINISH_DT AND IN_DATEEND
                                                                     AND E.DEPARTMENT_ID = CS.DEPARTMENT_ID
                                                                     AND E.CLIENT_ID = CS.CLIENT_ID
                                                                     AND E.EVENT_TYPE_ID IN (10,21,22,20) LIMIT 1)
                                    )) ELSE 0 END
                       )  AS DEFERRED_TIME,
                   MAX(CS.WAITING_TIME),
                   DATE_DIFF('SECOND', MAX(CS.REG_DT)::TIMESTAMP, MAX(CS.FINISH_DT)::TIMESTAMP)
                       FROM GET_CLIENT_SESSIONS(IN_DATESTART, IN_DATEEND, IN_DEPARTMENTID) CS
              INNER JOIN DEPARTMENT D ON D.ID = CS.DEPARTMENT_ID
     WHERE ((CS.REG_DT BETWEEN IN_DATESTART AND IN_DATEEND) OR
            (CS.CALL_DT BETWEEN IN_DATESTART AND IN_DATEEND))
       AND (CS.TICKET = IN_TICKET OR IN_TICKET = '')
       AND (CS.WORKPLACE_ID = IN_WORKPLACEID OR IN_WORKPLACEID = -1)
       AND CS.SESSION_STATUS = 2
     GROUP BY CS.DEPARTMENT_ID,
                   DATE(CS.REG_DT));
 RETURN QUERY ( SELECT  * FROM TABLE_RESULT T
 WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN T.ID > IN_PREV_PAGE_LAST_ID ELSE T.ID < IN_PREV_PAGE_LAST_ID END
                ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN T.ID END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN T.ID END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN T.DEPARTMENT_NAME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN T.DEPARTMENT_NAME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN T.TICKET END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN T.TICKET END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN T.OPERATION_NAME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN T.OPERATION_NAME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN T.WORKPLACE_NAME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN T.WORKPLACE_NAME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN T.OPERATOR_NAME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN T.OPERATOR_NAME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN T.REGISTRATION_DATE_TIME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN T.REGISTRATION_DATE_TIME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = TRUE THEN T.START_SERVICE_TIME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = FALSE THEN T.START_SERVICE_TIME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = TRUE THEN T.FINISH_SERVICE_TIME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = FALSE THEN T.FINISH_SERVICE_TIME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = TRUE THEN T.SERVICE_DURATION_TIME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = FALSE THEN T.SERVICE_DURATION_TIME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = TRUE THEN T.DEFERRED_TIME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = FALSE THEN T.DEFERRED_TIME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = TRUE THEN T.WAITING_DURATION_TIME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = FALSE THEN T.WAITING_DURATION_TIME END) ASC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = TRUE THEN T.PRESENCE_IN_DEPARTMENT_TIME END) DESC,
                         (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = FALSE THEN T.PRESENCE_IN_DEPARTMENT_TIME END) ASC

                LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END
 );
END
$$;