/**
QFIVEDEV-1053 Переименовать OriginatorType в WayOfQueuing.
 */

ALTER TABLE ORIGINATOR_TYPE RENAME TO WAY_OF_QUEUING;

ALTER TABLE EVENT RENAME COLUMN ORIGINATOR_TYPE_ID TO WAY_OF_QUEUING_ID;

ALTER TABLE REGISTRATION RENAME COLUMN ORIGINATOR_TYPE_ID TO WAY_OF_QUEUING_ID;

ALTER TABLE REGISTRATION_STATISTICS RENAME COLUMN ORIGINATOR_TYPE_ID TO WAY_OF_QUEUING_ID;


 /*
 * Залиты функции по задачам:  QFIVEDEV-381, QFIVEDEV-376, QFIVEDEV-396, QFIVEDEV-406.
 * Изменена функция GET_CLIENT_SESSIONS. Добавлены ограничения и дополнительные поля.
 * Изменен отчет "Показатели обслуживания клиентов". Исправлены ошибки.
 * Добавлен отчет "Детализация обслуживания клиентов".
 * Добавлен отчет "Отчет по операциям в разрезе услуг".
 * Добавлен отчет "Отчет по предварительным записям".
*/

-- Изменена функция GET_CLIENT_SESSIONS. Добавлены ограничения и дополнительные поля.
DROP FUNCTION IF EXISTS GET_CLIENT_SESSIONS;
CREATE OR REPLACE FUNCTION GET_CLIENT_SESSIONS(IN_DATE_START TIMESTAMP,
                                               IN_DATE_END TIMESTAMP,
                                               IN_DEPARTMENT_ID BIGINT)
    RETURNS TABLE
            (
                CLIENT_ID      BIGINT,
                WAITING_TIME   INTEGER,
                SERVICE_TIME   INTEGER,
                REG_DT         TIMESTAMP,
                CALL_DT        TIMESTAMP,
                FINISH_DT      TIMESTAMP,
                SESSION_STATUS BIGINT,
                DEPARTMENT_ID  BIGINT,
                USER_ID        BIGINT
            )
AS
$$
DECLARE
    EVENT_LOOP EVENT%ROWTYPE;
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ВЫВОДА.
    CREATE TEMPORARY TABLE IF NOT EXISTS TEMP_CLIENT_SESSIONS
    (
        CLIENT_ID      BIGINT,
        WAITING_TIME   INTEGER DEFAULT 0,
        SERVICE_TIME   INTEGER DEFAULT 0,
        REG_DT         TIMESTAMP,
        CALL_DT        TIMESTAMP,
        FINISH_DT      TIMESTAMP,
        -- SESSION_STATUS: 0(СЕССИЯ ОТКРЫТА, КЛИЕНТ В ОЧЕРЕДИ), 1(КЛИЕНТ ОБСЛУЖИВАЕТСЯ ОПЕРАТОРОМ), 2(СЕССИЯ ЗАКРЫТА, ОБСЛУЖИВАНИЕ ЗАВЕРШЕНО), 3(СЕССИЯ ЗАВЕРШЕНА, КЛИЕНТ УДАЛЕН)
        SESSION_STATUS BIGINT,
        DEPARTMENT_ID  BIGINT,
        USER_ID        BIGINT
    );

    -- СОЗДАТЬ ЦИКЛ ПО ТАБЛИЦЕ EVENT С КЛИЕНТСКИМИ ТИПАМИ СОБЫТИЙ.
    FOR EVENT_LOOP IN SELECT *
                      FROM EVENT E
                      WHERE (E.DEPARTMENT_ID = IN_DEPARTMENT_ID OR IN_DEPARTMENT_ID = -1)
                        AND E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END
                        AND E.CLIENT_ID IS NOT NULL
                        AND E.EVENT_TYPE_ID IN (9, 10, 11, 14, 15, 16, 19, 20, 21, 22, 23)
                      ORDER BY CLIENT_ID, DATE_TIME_COLUMN
        LOOP
            -- РЕГИСТРАЦИЯ КЛИЕНТА [%S%S] НА УСЛУГУ [%S].
            IF EVENT_LOOP.EVENT_TYPE_ID = 9 THEN
                INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID)
                VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID);
            END IF;

            -- РЕГИСТРАЦИЯ КЛИЕНТА [%S%S] НА УСЛУГУ  [%S] С ПОМОЩЬЮ СПЕЦИАЛЬНОЙ РЕГИСТРАЦИИ.
            IF EVENT_LOOP.EVENT_TYPE_ID = 14 THEN
                IF EXISTS(SELECT * FROM EVENT E WHERE EVENT_LOOP.CLIENT_ID = E.CLIENT_ID AND E.EVENT_TYPE_ID = 10) AND
                   NOT EXISTS(SELECT * FROM EVENT E WHERE EVENT_LOOP.CLIENT_ID = E.CLIENT_ID AND E.EVENT_TYPE_ID IN (15, 20))
                THEN
                    INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID)
                    VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID);
                ELSE
                    INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, CALL_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID)
                    VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID);
                END IF;

            END IF;

            -- ВЫЗОВ КЛИЕНТА [%S%S] ПО УСЛУГЕ [%S].
            IF EVENT_LOOP.EVENT_TYPE_ID = 10 THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET WAITING_TIME   = TCS.WAITING_TIME +
                                     DATE_DIFF('SECOND', TCS.REG_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    CALL_DT        = EVENT_LOOP.DATE_TIME_COLUMN,
                    SESSION_STATUS = 1
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ПЕРЕВОД КЛИЕНТА [%S%S] ИЗ ОКНА [%S] В ОКНО [%S]. ПРИЧИНА ПЕРЕВОДА: [%S].
            -- НАЗНАЧЕНИЕ КЛИЕНТА [%S%S] ОКНУ [%S]. ПРИЧИНА ПЕРЕВОДА: [%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID IN (15, 23)) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME   = TCS.SERVICE_TIME +
                                     DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    REG_DT         = EVENT_LOOP.DATE_TIME_COLUMN,
                    SESSION_STATUS = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ОТКЛАДЫВАНИЕ КЛИЕНТА [%S%S] НА [%D] МИНУТ.
            -- СБРОС КЛИЕНТА [%S%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID IN (19, 22)) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME   = TCS.SERVICE_TIME +
                                     DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    SESSION_STATUS = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ВОЗВРАЩЕНИЕ КЛИЕНТА [%S%S] В ОЧЕРЕДЬ.
            IF (EVENT_LOOP.EVENT_TYPE_ID = 20) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET REG_DT         = EVENT_LOOP.DATE_TIME_COLUMN,
                    SESSION_STATUS = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ЗАВЕРШЕНИЕ ОБСЛУЖИВАНИЯ КЛИЕНТА [%S%S] ПО УСЛУГЕ [%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID = 11) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME   = TCS.SERVICE_TIME +
                                     DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    FINISH_DT      = EVENT_LOOP.DATE_TIME_COLUMN,
                    SESSION_STATUS = 2
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- УДАЛЕНИЕ КЛИЕНТА [%S%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID = 21) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET WAITING_TIME   = TCS.WAITING_TIME +
                                     DATE_DIFF('SECOND', TCS.REG_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    FINISH_DT      = EVENT_LOOP.DATE_TIME_COLUMN,
                    SESSION_STATUS = 3
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;
        END LOOP;

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ.
    RETURN QUERY
        SELECT TCS.CLIENT_ID,
               TCS.WAITING_TIME,
               TCS.SERVICE_TIME,
               TCS.REG_DT,
               TCS.CALL_DT,
               TCS.FINISH_DT,
               TCS.SESSION_STATUS,
               TCS.DEPARTMENT_ID,
               TCS.USER_ID
        FROM TEMP_CLIENT_SESSIONS TCS;

    -- УДАЛИТЬ ВРЕМЕННУЮ ТАБЛИЦУ.
    DROP TABLE TEMP_CLIENT_SESSIONS;
END;
$$ LANGUAGE PLPGSQL;



--Изменен отчет "Показатели обслуживания клиентов".
DROP FUNCTION IF EXISTS REPORT_CLIENTS_SERVICE_METRICS;
CREATE OR REPLACE FUNCTION REPORT_CLIENTS_SERVICE_METRICS(IN_DEPARTMENT_ID BIGINT,
                                                          IN_DATE_START TIMESTAMP,
                                                          IN_DATE_END TIMESTAMP,
                                                          IN_OPERATION_ID BIGINT,
                                                          IN_GROUP_QUALIFICATION_ID BIGINT,
                                                          IN_USER_ID BIGINT,
                                                          IN_CLIENT_WAITING_TIME INT,
                                                          IN_GROUP_MONTH BOOLEAN,
                                                          IN_GROUP_DAY BOOLEAN,
                                                          IN_GROUP_HOUR BOOLEAN,
                                                          IN_GROUP_GROUP_ID BOOLEAN,
                                                          IN_GROUP_CLIENT_SEGMENT_ID BOOLEAN,
                                                          IN_GROUP_DEPARTMENT_ID BOOLEAN,
                                                          IN_GROUP_USER_ID BOOLEAN,
                                                          IN_PREV_PAGE_LAST_ID BIGINT,
                                                          IN_PAGE_SIZE BIGINT,
                                                          IN_ORDER_BY_COLUMN_ID INT,
                                                          IN_IS_DESCENDING BOOLEAN,
                                                          IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID                               BIGINT,           -- НОМЕР СТРОКИ, ID
                DEPARTMENT_NAME                  TEXT,             -- ОТДЕЛЕНИЕ
                OPERATION_GROUP_NAME             TEXT,             -- ГРУППА
                USER_NAME                        TEXT,             -- ФИО ОПЕРАТОРА
                CLIENT_SEGMENT_NAME              TEXT,             -- СЕГМЕНТ КЛИЕНТОВ
                DATE_YEAR                        DOUBLE PRECISION, -- ГОД
                DATE_MONTH                       DOUBLE PRECISION, -- МЕСЯЦ
                DATE_DAY                         DOUBLE PRECISION, -- ДЕНЬ
                DATE_HOUR                        DOUBLE PRECISION, -- ЧАС
                NUMBER_TICKETS                   NUMERIC,          -- КОЛИЧЕСТВО ТАЛОНОВ
                TOTAL_NUMBER_OPERATIONS          NUMERIC,          -- ОБЩЕЕ КОЛИЧЕСТВО ОПЕРАЦИЙ
                NUMBER_SERVED_CLIENTS            NUMERIC,          -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, N
                PERCENT_SERVED_CLIENTS           NUMERIC,          -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, %
                NUMBER_CLIENTS_WAITED_NO_MOREN   NUMERIC,          -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, N
                PERCENT_CLIENTS_WAITED_NO_MOREN  NUMERIC,          -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, %
                NUMBER_OUT_OF_SERVICE_CUSTOMERS  NUMERIC,          -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, N
                PERCENT_OUT_OF_SERVICE_CUSTOMERS NUMERIC,          -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, %
                AVERAGE_SERVICE_TIME             NUMERIC,          -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                AVERAGE_WAITING_TIME             NUMERIC,          -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
                AVERAGE_TIME_SPENT_IN_DEPARTMENT NUMERIC           -- СРЕДНЕЕ ВРЕМЯ НАХОЖДЕНИЯ В ОТДЕЛЕНИИ
            )
AS
$$
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ОБРАБОТКИ ДАННЫХ.
    CREATE TEMPORARY TABLE TEMP_RESULT_EVENTS
    (
        ID                               BIGINT,           -- НОМЕР СТРОКИ
        DEPARTMENT_NAME                  TEXT,             -- ОТДЕЛЕНИЕ, NAME
        OPERATION_GROUP_NAME             TEXT,             -- ГРУППА, NAME
        USER_NAME                        TEXT,             -- ФИО ОПЕРАТОРА
        CLIENT_SEGMENT_NAME              TEXT,             -- СЕГМЕНТ КЛИЕНТОВ
        DATE_YEAR                        DOUBLE PRECISION, -- ГОД
        DATE_MONTH                       DOUBLE PRECISION, -- МЕСЯЦ
        DATE_DAY                         DOUBLE PRECISION, -- ДЕНЬ
        DATE_HOUR                        DOUBLE PRECISION, -- ЧАС
        NUMBER_TICKETS                   BIGINT,           -- КОЛИЧЕСТВО ТАЛОНОВ
        TOTAL_NUMBER_OPERATIONS          BIGINT,           -- ОБЩЕЕ КОЛИЧЕСТВО УСЛУГ
        NUMBER_SERVED_CLIENTS            BIGINT,           -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, N
        PERCENT_SERVED_CLIENTS           NUMERIC,          -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, %
        NUMBER_CLIENTS_WAITED_NO_MOREN   BIGINT,           -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, N
        PERCENT_CLIENTS_WAITED_NO_MOREN  NUMERIC,          -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, N
        NUMBER_OUT_OF_SERVICE_CUSTOMERS  BIGINT,           -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, N
        PERCENT_OUT_OF_SERVICE_CUSTOMERS NUMERIC,          -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, %
        AVERAGE_SERVICE_TIME             NUMERIC,          -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
        AVERAGE_WAITING_TIME             NUMERIC,          -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
        AVERAGE_TIME_SPENT_IN_DEPARTMENT NUMERIC           -- СРЕДНЕЕ ВРЕМЯ НАХОЖДЕНИЯ В ОТДЕЛЕНИИ
    ) ON COMMIT DROP;

    -- СОЗДАТЬ ОТФИЛЬТРОВАННУЮ КОПИЮ ТАБЛИЦЫ EVENT.
    CREATE TEMPORARY TABLE POST_FILTERING_EVENTS ON COMMIT DROP AS
    SELECT *
    FROM EVENT E
    WHERE (E.DEPARTMENT_ID = IN_DEPARTMENT_ID OR IN_DEPARTMENT_ID = -1)
      AND E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END
      AND (E.OPERATION_ID = IN_OPERATION_ID OR IN_OPERATION_ID = -1)
      AND (E.GROUP_QUALIFICATION_ID = IN_GROUP_QUALIFICATION_ID OR IN_GROUP_QUALIFICATION_ID = -1)
      AND (E.USER_ID = IN_USER_ID OR IN_USER_ID = -1)
      AND E.CLIENT_ID IS NOT NULL;

    -- ОБРАБОТАТЬ ДАННЫЕ И ПОМЕСТИТЬ ВО ВРЕМЕННУЮ ТАБЛИЦУ.
    INSERT INTO TEMP_RESULT_EVENTS (ID, -- НОМЕР СТРОКИ
                                    DEPARTMENT_NAME, -- ОТДЕЛЕНИЕ
                                    OPERATION_GROUP_NAME, -- ГРУППА
                                    USER_NAME, -- ФИО ОПЕРАТОРА
                                    CLIENT_SEGMENT_NAME, -- СЕГМЕНТ КЛИЕНТОВ
                                    DATE_YEAR, -- ГОД
                                    DATE_MONTH, -- МЕСЯЦ
                                    DATE_DAY, -- ДЕНЬ
                                    DATE_HOUR, -- ЧАС
                                    NUMBER_TICKETS, -- КОЛИЧЕСТВО ТАЛОНОВ
                                    TOTAL_NUMBER_OPERATIONS, -- ОБЩЕЕ КОЛИЧЕСТВО УСЛУГ
                                    NUMBER_SERVED_CLIENTS, -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, N
                                    NUMBER_CLIENTS_WAITED_NO_MOREN, -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, N
                                    NUMBER_OUT_OF_SERVICE_CUSTOMERS, -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, N
                                    AVERAGE_SERVICE_TIME, -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                                    AVERAGE_WAITING_TIME, -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
                                    AVERAGE_TIME_SPENT_IN_DEPARTMENT -- СРЕДНЕЕ ВРЕМЯ НАХОЖДЕНИЯ В ОТДЕЛЕНИИ
    )
    SELECT ROW_NUMBER() OVER (PARTITION BY 1)                                                                  ID,                              -- НОМЕР СТРОКИ
           CASE
               WHEN IN_GROUP_DEPARTMENT_ID = TRUE OR IN_GROUP_USER_ID = TRUE THEN
                   CASE
                       WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                           THEN PFE.DEPARTMENT_NAME_EN
                       WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                           THEN PFE.DEPARTMENT_NAME_RU
                       ELSE PFE.DEPARTMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                       END
               ELSE NULL END                                                                                   DEPARTMENT_NAME,                 -- ОТДЕЛЕНИЕ ID
           CASE
               WHEN IN_GROUP_GROUP_ID = TRUE THEN
                   CASE
                       WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                           THEN PFE.OPERATION_GROUP_NAME_EN
                       WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                           THEN PFE.OPERATION_GROUP_NAME_RU
                       ELSE PFE.OPERATION_GROUP_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                       END
               ELSE NULL END                                                                                   OPERATION_GROUP_NAME,            -- ГРУППА NAME
           CASE
               WHEN IN_GROUP_USER_ID = TRUE THEN
                   CASE
                       WHEN PFE.USER_FIRST_NAME || ' ' || PFE.USER_MIDDLE_NAME || ' ' || PFE.USER_LAST_NAME IS NOT NULL THEN
                           PFE.USER_FIRST_NAME || ' ' || PFE.USER_MIDDLE_NAME || ' ' || PFE.USER_LAST_NAME
                       ELSE PFE.USER_LOGIN END
               ELSE NULL END                                                                                   USER_NAME,                       -- ФИО ОПЕРАТОРА
           CASE
               WHEN IN_GROUP_CLIENT_SEGMENT_ID = TRUE THEN CASE
                                                               WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                                                                   THEN PFE.CLIENT_SEGMENT_NAME_EN
                                                               WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                                                                   THEN PFE.CLIENT_SEGMENT_NAME_RU
                                                               ELSE PFE.CLIENT_SEGMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                   END
               ELSE NULL END                                                                                   CLIENT_SEGMENT_NAME,             -- СЕГМЕНТ КЛИЕНТОВ ID
           CASE
               WHEN IN_GROUP_MONTH = TRUE OR IN_GROUP_DAY = TRUE OR IN_GROUP_HOUR = TRUE
                   THEN DATE_PART('YEAR', PFE.DATE_TIME_COLUMN)
               ELSE NULL END                                                                                   DATE_YEAR,                       -- ГОД
           CASE
               WHEN IN_GROUP_MONTH = TRUE OR IN_GROUP_DAY = TRUE OR IN_GROUP_HOUR = TRUE
                   THEN DATE_PART('MONTH', PFE.DATE_TIME_COLUMN)
               ELSE NULL END                                                                                   DATE_MONTH,                      -- МЕСЯЦ
           CASE
               WHEN IN_GROUP_DAY = TRUE OR IN_GROUP_HOUR = TRUE THEN DATE_PART('DAY', PFE.DATE_TIME_COLUMN)
               ELSE NULL END                                                                                   DATE_DAY,                        -- ДЕНЬ
           CASE WHEN IN_GROUP_HOUR = TRUE THEN DATE_PART('HOUR', PFE.DATE_TIME_COLUMN) ELSE NULL END           DATE_HOUR,                       -- ЧАС
           COUNT(Q1.CLIENT_ID)                                                                                 NUMBER_TICKETS,                  -- КОЛИЧЕСТВО ТАЛОНОВ
           COUNT(1)                                                                                            TOTAL_NUMBER_OPERATIONS,         -- ОБЩЕЕ КОЛИЧЕСТВО УСЛУГ
           COUNT(Q2.CLIENT_ID)                                                                                 NUMBER_SERVED_CLIENTS,           -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, N
           COUNT(DISTINCT Q3.CLIENT_ID) FILTER (WHERE Q3.WAITING_TIME < IN_CLIENT_WAITING_TIME)                NUMBER_CLIENTS_WAITED_NO_MOREN,  -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, N
           COUNT(DISTINCT PFE.CLIENT_ID) - COUNT(DISTINCT PFE.CLIENT_ID) FILTER (WHERE PFE.EVENT_TYPE_ID = 11) NUMBER_OUT_OF_SERVICE_CUSTOMERS, -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, N
           AVG(DISTINCT Q3.SERVICE_TIME)                                                                       AVERAGE_SERVICE_TIME,            -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
           AVG(DISTINCT Q3.WAITING_TIME)                                                                       AVERAGE_WAITING_TIME,            -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
           AVG(DISTINCT Q3.WAITING_TIME + Q3.SERVICE_TIME)                                                     AVERAGE_TIME_SPENT_IN_DEPARTMENT -- СРЕДНЕЕ ВРЕМЯ НАХОЖДЕНИЯ В ОТДЕЛЕНИИ
    FROM POST_FILTERING_EVENTS PFE
             LEFT JOIN (SELECT PFE1.CLIENT_ID, PFE1.EVENT_TYPE_ID
                        FROM POST_FILTERING_EVENTS PFE1
                        WHERE PFE1.EVENT_TYPE_ID IN (9, 14)) Q1
                       ON PFE.CLIENT_ID = Q1.CLIENT_ID AND PFE.EVENT_TYPE_ID = Q1.EVENT_TYPE_ID
             LEFT JOIN (SELECT PFE2.CLIENT_ID, PFE2.EVENT_TYPE_ID
                        FROM POST_FILTERING_EVENTS PFE2
                        WHERE PFE2.EVENT_TYPE_ID IN (11, 15, 19)) Q2
                       ON PFE.CLIENT_ID = Q2.CLIENT_ID AND PFE.EVENT_TYPE_ID = Q2.EVENT_TYPE_ID
             LEFT JOIN
             (SELECT * FROM GET_CLIENT_SESSIONS(IN_DATE_START, IN_DATE_END, IN_DEPARTMENT_ID)) Q3 ON PFE.CLIENT_ID = Q3.CLIENT_ID
    GROUP BY CASE
                 WHEN IN_GROUP_MONTH = TRUE OR IN_GROUP_DAY = TRUE OR IN_GROUP_HOUR = TRUE
                     THEN DATE_PART('YEAR', PFE.DATE_TIME_COLUMN)
                 ELSE NULL END,
             CASE
                 WHEN IN_GROUP_MONTH = TRUE OR IN_GROUP_DAY = TRUE OR IN_GROUP_HOUR = TRUE
                     THEN DATE_PART('MONTH', PFE.DATE_TIME_COLUMN)
                 ELSE NULL END,
             CASE WHEN IN_GROUP_DAY = TRUE OR IN_GROUP_HOUR = TRUE THEN DATE_PART('DAY', PFE.DATE_TIME_COLUMN) ELSE NULL END,
             CASE WHEN IN_GROUP_HOUR = TRUE THEN DATE_PART('HOUR', PFE.DATE_TIME_COLUMN) ELSE NULL END,
             CASE
                 WHEN IN_GROUP_GROUP_ID = TRUE THEN
                     CASE
                         WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                             THEN PFE.OPERATION_GROUP_NAME_EN
                         WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                             THEN PFE.OPERATION_GROUP_NAME_RU
                         ELSE PFE.OPERATION_GROUP_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                         END
                 ELSE NULL END,
             CASE
                 WHEN IN_GROUP_CLIENT_SEGMENT_ID = TRUE THEN
                     CASE
                         WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                             THEN PFE.CLIENT_SEGMENT_NAME_EN
                         WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                             THEN PFE.CLIENT_SEGMENT_NAME_RU
                         ELSE PFE.CLIENT_SEGMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                         END
                 ELSE NULL END,
             CASE
                 WHEN IN_GROUP_DEPARTMENT_ID = TRUE OR IN_GROUP_USER_ID = TRUE THEN
                     CASE
                         WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                             THEN PFE.DEPARTMENT_NAME_EN
                         WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                             THEN PFE.DEPARTMENT_NAME_RU
                         ELSE PFE.DEPARTMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                         END
                 ELSE NULL END,
             CASE
                 WHEN IN_GROUP_USER_ID = TRUE THEN
                     CASE
                         WHEN PFE.USER_FIRST_NAME || ' ' || PFE.USER_MIDDLE_NAME || ' ' || PFE.USER_LAST_NAME IS NOT NULL THEN
                             PFE.USER_FIRST_NAME || ' ' || PFE.USER_MIDDLE_NAME || ' ' || PFE.USER_LAST_NAME
                         ELSE PFE.USER_LOGIN END
                 ELSE NULL END,
             CASE
                 WHEN NOT (IN_GROUP_MONTH = TRUE OR
                           IN_GROUP_DAY = TRUE OR
                           IN_GROUP_HOUR = TRUE OR
                           IN_GROUP_GROUP_ID = TRUE OR
                           IN_GROUP_CLIENT_SEGMENT_ID = TRUE OR
                           IN_GROUP_DEPARTMENT_ID = TRUE OR
                           IN_GROUP_USER_ID = TRUE) THEN PFE.ID
                 ELSE NULL END;

    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ TEMP_RESULT_TABLE ДЛЯ ВЫВОДА ДАННЫХ ИЗ ФУНКЦИИ.
    -- ДОБАВИТЬ СВЯЗЬ С ОТДЕЛЕНИЯМИ, СЕГМЕНТАМИ, ПРОЦЕНТНЫЕ ПОЛЯ.
    CREATE TEMPORARY TABLE TEMP_RESULT_TABLE ON COMMIT DROP AS
    SELECT TRE.ID                                                                                                                               ID,
           TRE.DEPARTMENT_NAME                                                                                                                  DEPARTMENT_NAME,
           TRE.OPERATION_GROUP_NAME                                                                                                             OPERATION_GROUP_NAME,
           TRE.USER_NAME                                                                                                                        USER_NAME,
           TRE.CLIENT_SEGMENT_NAME                                                                                                              CLIENT_SEGMENT_NAME,
           TRE.DATE_YEAR                                                                                                                        DATE_YEAR,
           TRE.DATE_MONTH                                                                                                                       DATE_MONTH,
           TRE.DATE_DAY                                                                                                                         DATE_DAY,
           TRE.DATE_HOUR                                                                                                                        DATE_HOUR,
           TRE.NUMBER_TICKETS                                                                                                                   NUMBER_TICKETS,
           TRE.TOTAL_NUMBER_OPERATIONS                                                                                                          TOTAL_NUMBER_OPERATIONS,
           TRE.NUMBER_SERVED_CLIENTS                                                                                                            NUMBER_SERVED_CLIENTS,
           (CASE
                WHEN TRE.NUMBER_SERVED_CLIENTS = 0 THEN 0
                ELSE (TRE.NUMBER_SERVED_CLIENTS / SUM(TRE.NUMBER_SERVED_CLIENTS) OVER ()) * 100 END)                                            PERCENT_SERVED_CLIENTS,           -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, %
           TRE.NUMBER_CLIENTS_WAITED_NO_MOREN                                                                                                   NUMBER_CLIENTS_WAITED_NO_MOREN,
           (CASE
                WHEN TRE.NUMBER_CLIENTS_WAITED_NO_MOREN = 0 THEN 0
                ELSE (TRE.NUMBER_CLIENTS_WAITED_NO_MOREN / SUM(TRE.NUMBER_CLIENTS_WAITED_NO_MOREN) OVER ()) * 100 END)                          PERCENT_CLIENTS_WAITED_NO_MOREN,  -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, %
           TRE.NUMBER_OUT_OF_SERVICE_CUSTOMERS                                                                                                  NUMBER_OUT_OF_SERVICE_CUSTOMERS,
           (CASE
                WHEN TRE.NUMBER_OUT_OF_SERVICE_CUSTOMERS = 0 THEN 0
                ELSE (TRE.NUMBER_OUT_OF_SERVICE_CUSTOMERS / SUM(TRE.NUMBER_OUT_OF_SERVICE_CUSTOMERS) OVER ()) * 100 END)                        PERCENT_OUT_OF_SERVICE_CUSTOMERS, -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, %
           TRE.AVERAGE_SERVICE_TIME                                                                                                             AVERAGE_SERVICE_TIME,
           TRE.AVERAGE_WAITING_TIME                                                                                                             AVERAGE_WAITING_TIME,
           TRE.AVERAGE_TIME_SPENT_IN_DEPARTMENT                                                                                                 AVERAGE_TIME_SPENT_IN_DEPARTMENT
    FROM TEMP_RESULT_EVENTS TRE;

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ TEMP_RESULT_TABLE, ДОБАВИТЬ СОРТИРОВКУ, ПАГИНАЦИЮ И ИТОГИ.
    RETURN QUERY
        (SELECT *
         FROM TEMP_RESULT_TABLE TRT
         WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN TRT.ID > IN_PREV_PAGE_LAST_ID ELSE TRT.ID < IN_PREV_PAGE_LAST_ID END
         ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN TRT.ID END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN TRT.ID END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN TRT.DEPARTMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN TRT.DEPARTMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN TRT.OPERATION_GROUP_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN TRT.OPERATION_GROUP_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN TRT.USER_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN TRT.USER_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN TRT.CLIENT_SEGMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN TRT.CLIENT_SEGMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN TRT.DATE_YEAR END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN TRT.DATE_YEAR END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN TRT.DATE_MONTH END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN TRT.DATE_MONTH END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = TRUE THEN TRT.DATE_DAY END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = FALSE THEN TRT.DATE_DAY END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = TRUE THEN TRT.DATE_HOUR END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = FALSE THEN TRT.DATE_HOUR END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = TRUE THEN TRT.NUMBER_TICKETS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = FALSE THEN TRT.NUMBER_TICKETS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = TRUE THEN TRT.TOTAL_NUMBER_OPERATIONS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = FALSE THEN TRT.TOTAL_NUMBER_OPERATIONS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = TRUE THEN TRT.NUMBER_SERVED_CLIENTS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = FALSE THEN TRT.NUMBER_SERVED_CLIENTS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = TRUE THEN TRT.PERCENT_SERVED_CLIENTS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = FALSE THEN TRT.PERCENT_SERVED_CLIENTS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = TRUE THEN TRT.NUMBER_CLIENTS_WAITED_NO_MOREN END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = FALSE THEN TRT.NUMBER_CLIENTS_WAITED_NO_MOREN END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = TRUE THEN TRT.PERCENT_CLIENTS_WAITED_NO_MOREN END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = FALSE THEN TRT.PERCENT_CLIENTS_WAITED_NO_MOREN END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 16 AND IN_IS_DESCENDING = TRUE THEN TRT.NUMBER_OUT_OF_SERVICE_CUSTOMERS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 16 AND IN_IS_DESCENDING = FALSE THEN TRT.NUMBER_OUT_OF_SERVICE_CUSTOMERS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 17 AND IN_IS_DESCENDING = TRUE THEN TRT.PERCENT_OUT_OF_SERVICE_CUSTOMERS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 17 AND IN_IS_DESCENDING = FALSE THEN TRT.PERCENT_OUT_OF_SERVICE_CUSTOMERS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 18 AND IN_IS_DESCENDING = TRUE THEN TRT.AVERAGE_SERVICE_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 18 AND IN_IS_DESCENDING = FALSE THEN TRT.AVERAGE_SERVICE_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 19 AND IN_IS_DESCENDING = TRUE THEN TRT.AVERAGE_WAITING_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 19 AND IN_IS_DESCENDING = FALSE THEN TRT.AVERAGE_WAITING_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 20 AND IN_IS_DESCENDING = TRUE THEN TRT.AVERAGE_TIME_SPENT_IN_DEPARTMENT END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 20 AND IN_IS_DESCENDING = FALSE THEN TRT.AVERAGE_TIME_SPENT_IN_DEPARTMENT END) ASC
         LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END
        )
        UNION ALL
        (SELECT MAX(TRT2.ID) + 1                           ID,                               -- НОМЕР СТРОКИ
                NULL                                       DEPARTMENT_NAME,                  -- ОТДЕЛЕНИЕ, NAME
                NULL                                       OPERATION_GROUP_NAME,             -- ГРУППА, NAME
                NULL                                       USER_NAME,                        -- ФИО ОПЕРАТОРА
                NULL                                       CLIENT_SEGMENT_NAME,              -- СЕГМЕНТ КЛИЕНТОВ, NAME
                NULL                                       DATE_YEAR,                        -- ГОД
                NULL                                       DATE_MONTH,                       -- МЕСЯЦ
                NULL                                       DATE_DAY,                         -- ДЕНЬ
                NULL                                       DATE_HOUR,                        -- ЧАС
                SUM(TRT2.NUMBER_TICKETS)                   NUMBER_TICKETS,                   -- КОЛИЧЕСТВО ТАЛОНОВ
                SUM(TRT2.TOTAL_NUMBER_OPERATIONS)          TOTAL_NUMBER_OPERATIONS,          -- ОБЩЕЕ КОЛИЧЕСТВО УСЛУГ
                SUM(TRT2.NUMBER_SERVED_CLIENTS)            NUMBER_SERVED_CLIENTS,            -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, N
                SUM(TRT2.PERCENT_SERVED_CLIENTS)           PERCENT_SERVED_CLIENTS,           -- ОБСЛУЖЕНЫЕ КЛИЕНТЫ, %
                SUM(TRT2.NUMBER_CLIENTS_WAITED_NO_MOREN)   NUMBER_CLIENTS_WAITED_NO_MOREN,   -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, N
                SUM(TRT2.PERCENT_CLIENTS_WAITED_NO_MOREN)  PERCENT_CLIENTS_WAITED_NO_MOREN,  -- КЛИЕНТЫ ОЖИДАВШИЕ НЕ БОЛЕЕ ЧЕМ N МИНУТ, %
                SUM(TRT2.NUMBER_OUT_OF_SERVICE_CUSTOMERS)  NUMBER_OUT_OF_SERVICE_CUSTOMERS,  -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, N
                SUM(TRT2.PERCENT_OUT_OF_SERVICE_CUSTOMERS) PERCENT_OUT_OF_SERVICE_CUSTOMERS, -- КЛИЕНТЫ ОТКАЗАВШИЕСЯ ОТ ОБСЛУЖИВАНИЯ, %
                AVG(TRT2.AVERAGE_SERVICE_TIME)             AVERAGE_SERVICE_TIME,             -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                AVG(TRT2.AVERAGE_WAITING_TIME)             AVERAGE_WAITING_TIME,             -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
                AVG(TRT2.AVERAGE_TIME_SPENT_IN_DEPARTMENT) AVERAGE_TIME_SPENT_IN_DEPARTMENT  -- СРЕДНЕЕ ВРЕМЯ НАХОЖДЕНИЯ В ОТДЕЛЕНИИ
         FROM TEMP_RESULT_TABLE TRT2);
END
$$ LANGUAGE PLPGSQL SECURITY DEFINER;



--Отчет "Детализация обслуживания клиентов".
CREATE OR REPLACE FUNCTION REPORT_DETAIL_CLIENTS_SERVICE(IN_DEPARTMENT_ID BIGINT,
                                                         IN_DATE_START TIMESTAMP,
                                                         IN_DATE_END TIMESTAMP,
                                                         IN_WORKPLACE_ID BIGINT,
                                                         IN_USER_ID BIGINT,
                                                         IN_GROUP_QUALIFICATION_ID BIGINT,
                                                         IN_OPERATION_ID BIGINT,
                                                         IN_NUMBER_TICKET TEXT,
                                                         IN_CLIENT_SEGMENT_ID BIGINT,
                                                         IN_CLIENT_WAITING_TIME_FROM INT,
                                                         IN_CLIENT_WAITING_TIME_TO INT,
                                                         IN_CLIENT_SERVICE_TIME_FROM INT,
                                                         IN_CLIENT_SERVICE_TIME_TO INT,
                                                         IN_TIME_SPENT_IN_DEPARTMENT_FROM INT,
                                                         IN_TIME_SPENT_IN_DEPARTMENT_TO INT,
                                                         IN_IS_DENIED_SERVICE INT,
                                                         IN_IS_SERVICE_CHANGED INT,
                                                         IN_AUTHORIZATION_METHOD_ID BIGINT,
                                                         IN_PREV_PAGE_LAST_ID BIGINT,
                                                         IN_PAGE_SIZE BIGINT,
                                                         IN_ORDER_BY_COLUMN_ID INT,
                                                         IN_IS_DESCENDING BOOLEAN,
                                                         IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID                          BIGINT,    -- НОМЕР СТРОКИ, ID
                DEPARTMENT_NAME             TEXT,      -- ОТДЕЛЕНИЕ
                WORKPLACE_NAME              TEXT,      -- РАБОЧЕЕ МЕСТО
                USER_LOGIN                  TEXT,      -- ЛОГИН ОПЕРАТОРА
                USER_NAME                   TEXT,      -- ФИО ОПЕРАТОРА
                SERVICE_DATE                TIMESTAMP, -- ДАТА ОБСЛУЖИВАНИЯ
                CONFIRMATION_CODE           TEXT,      -- КОД ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                TICKET_LETTER_AND_NUMBER    TEXT,      -- № ТАЛОНА
                GROUP_NAME                  TEXT,      -- ГРУППА
                OPERATION_NAME              TEXT,      -- УСЛУГА
                TIME_RECEIPT_TICKET         TIMESTAMP, -- ВРЕМЯ ВЫДАЧИ ТАЛОНА
                WAITING_TIME                NUMERIC,   -- ВРЕМЯ ОЖИДАНИЯ
                CUSTOMER_SERVICE_START_TIME TIMESTAMP, -- ВРЕМЯ НАЧАЛА ОБСЛУЖИВАНИЯ КЛИЕНТА
                SERVICE_TIME                NUMERIC,   -- ВРЕМЯ ОБСЛУЖИВАНИЯ
                CLIENT_SEGMENT_NAME         TEXT,      -- СЕГМЕНТ КЛИЕНТА
                DENIAL_SERVICE_SYMPTOM      TEXT,      -- ПРИЗНАК ОТКАЗА В ОБСЛУЖИВАНИИ
                SERVICE_CHANGE_SIGN         TEXT,      -- ПРИЗНАК СМЕНЫ УСЛУГИ
                AUTHORIZATION_METHOD        TEXT       -- ПРИЗНАК ИДЕНТИФИКАЦИИ
            )
AS
$$
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ОБРАБОТКИ ДАННЫХ.
    CREATE TEMPORARY TABLE TEMP_RESULT_EVENTS
    (
        ID                          BIGINT,    -- НОМЕР СТРОКИ, ID
        DEPARTMENT_NAME             TEXT,      -- ОТДЕЛЕНИЕ
        WORKPLACE_NAME              TEXT,      -- РАБОЧЕЕ МЕСТО
        USER_LOGIN                  TEXT,      -- ЛОГИН ОПЕРАТОРА
        USER_NAME                   TEXT,      -- ФИО ОПЕРАТОРА
        SERVICE_DATE                TIMESTAMP, -- ДАТА ОБСЛУЖИВАНИЯ
        CONFIRMATION_CODE           TEXT,      -- КОД ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
        TICKET_LETTER_AND_NUMBER    TEXT,      -- № ТАЛОНА
        GROUP_NAME                  TEXT,      -- ГРУППА
        OPERATION_NAME              TEXT,      -- УСЛУГА
        TIME_RECEIPT_TICKET         TIMESTAMP, -- ВРЕМЯ ВЫДАЧИ ТАЛОНА
        WAITING_TIME                NUMERIC,   -- ВРЕМЯ ОЖИДАНИЯ
        CUSTOMER_SERVICE_START_TIME TIMESTAMP, -- ВРЕМЯ НАЧАЛА ОБСЛУЖИВАНИЯ КЛИЕНТА
        SERVICE_TIME                NUMERIC,   -- ВРЕМЯ ОБСЛУЖИВАНИЯ
        CLIENT_SEGMENT_NAME         TEXT,      -- СЕГМЕНТ КЛИЕНТА
        DENIAL_SERVICE_SYMPTOM      TEXT,      -- ПРИЗНАК ОТКАЗА В ОБСЛУЖИВАНИИ
        SERVICE_CHANGE_SIGN         TEXT,      -- ПРИЗНАК СМЕНЫ УСЛУГИ
        AUTHORIZATION_METHOD        TEXT       -- ПРИЗНАК ИДЕНТИФИКАЦИИ
    ) ON COMMIT DROP;

    -- СОЗДАТЬ ОТФИЛЬТРОВАННУЮ КОПИЮ ТАБЛИЦЫ EVENT.
    CREATE TEMPORARY TABLE POST_FILTERING_EVENTS ON COMMIT DROP AS
    SELECT *
    FROM EVENT E
    WHERE (E.DEPARTMENT_ID = IN_DEPARTMENT_ID OR IN_DEPARTMENT_ID = -1)
      AND E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END
      AND (E.OPERATION_ID = IN_OPERATION_ID OR IN_OPERATION_ID = -1)
      AND (E.GROUP_QUALIFICATION_ID = IN_GROUP_QUALIFICATION_ID OR IN_GROUP_QUALIFICATION_ID = -1)
      AND (E.USER_ID = IN_USER_ID OR IN_USER_ID = -1)
      AND (E.WORKPLACE_ID = IN_WORKPLACE_ID OR IN_WORKPLACE_ID = -1)
      AND (E.CLIENT_TICKET_LETTER || E.CLIENT_TICKET_NUMBER = IN_NUMBER_TICKET OR IN_NUMBER_TICKET = '')
      AND (E.CLIENT_SEGMENT_ID = IN_CLIENT_SEGMENT_ID OR IN_CLIENT_SEGMENT_ID = -1)
      AND (E.AUTHORIZATION_METHOD_ID = IN_AUTHORIZATION_METHOD_ID OR IN_AUTHORIZATION_METHOD_ID = -1)
      AND E.CLIENT_ID IS NOT NULL;

    -- ОБРАБОТАТЬ ДАННЫЕ И ПОМЕСТИТЬ ВО ВРЕМЕННУЮ ТАБЛИЦУ.
    INSERT INTO TEMP_RESULT_EVENTS (ID, -- НОМЕР СТРОКИ, ID
                                    DEPARTMENT_NAME, -- ОТДЕЛЕНИЕ
                                    WORKPLACE_NAME, -- РАБОЧЕЕ МЕСТО
                                    USER_LOGIN, -- ЛОГИН ОПЕРАТОРА
                                    USER_NAME, -- ФИО ОПЕРАТОРА
                                    SERVICE_DATE, -- ДАТА ОБСЛУЖИВАНИЯ
                                    CONFIRMATION_CODE, -- КОД ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                                    TICKET_LETTER_AND_NUMBER, -- № ТАЛОНА
                                    GROUP_NAME, -- ГРУППА
                                    OPERATION_NAME, -- УСЛУГА
                                    TIME_RECEIPT_TICKET, -- ВРЕМЯ ВЫДАЧИ ТАЛОНА
                                    WAITING_TIME, -- ВРЕМЯ ОЖИДАНИЯ
                                    CUSTOMER_SERVICE_START_TIME, -- ВРЕМЯ НАЧАЛА ОБСЛУЖИВАНИЯ КЛИЕНТА
                                    SERVICE_TIME, -- ВРЕМЯ ОБСЛУЖИВАНИЯ
                                    CLIENT_SEGMENT_NAME, -- СЕГМЕНТ КЛИЕНТА
                                    DENIAL_SERVICE_SYMPTOM, -- ПРИЗНАК ОТКАЗА В ОБСЛУЖИВАНИИ
                                    SERVICE_CHANGE_SIGN, -- ПРИЗНАК СМЕНЫ УСЛУГИ
                                    AUTHORIZATION_METHOD -- ПРИЗНАК ИДЕНТИФИКАЦИИ
    )
    SELECT ROW_NUMBER() OVER (PARTITION BY 1)                        ID,                          -- НОМЕР СТРОКИ
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                       THEN PFE.DEPARTMENT_NAME_EN
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.DEPARTMENT_NAME_RU
                   ELSE PFE.DEPARTMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
               END)                                                  DEPARTMENT_NAME,             -- ОТДЕЛЕНИЕ
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                       THEN PFE.WORKPLACE_NAME_EN
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.WORKPLACE_NAME_RU
                   ELSE PFE.WORKPLACE_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
               END)                                                  WORKPLACE_NAME,              -- РАБОЧЕЕ МЕСТО NAME
           MAX(PFE.USER_LOGIN)                                       USER_LOGIN,                  -- ЛОГИН ОПЕРАТОРА
           MAX(CASE
                   WHEN PFE.USER_FIRST_NAME || ' ' || PFE.USER_MIDDLE_NAME || ' ' || PFE.USER_LAST_NAME IS NOT NULL THEN
                       PFE.USER_FIRST_NAME || ' ' || PFE.USER_MIDDLE_NAME || ' ' || PFE.USER_LAST_NAME
                   ELSE PFE.USER_LOGIN END)
                                                                     USER_NAME,                   -- ФИО ОПЕРАТОРА
           MAX(DATE(Q1.DATE_TIME_COLUMN))                            SERVICE_DATE,                -- ДАТА ОБСЛУЖИВАНИЯ
           MAX(PFE.CLIENT_CONFIRMATION_CODE)                         CONFIRMATION_CODE,           -- КОД ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
           MAX(PFE.CLIENT_TICKET_LETTER || PFE.CLIENT_TICKET_NUMBER) TICKET_LETTER_AND_NUMBER,    -- № ТАЛОНА
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                       THEN PFE.OPERATION_GROUP_NAME_EN
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.OPERATION_GROUP_NAME_RU
                   ELSE PFE.OPERATION_GROUP_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
               END)                                                  GROUP_NAME,                  -- ГРУППА NAME
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                       THEN PFE.OPERATION_NAME_EN
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.OPERATION_NAME_RU
                   ELSE
                       CASE
                           WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE1 IS NOT NULL THEN
                               PFE.OPERATION_NAME_CUSTOM_LANGUAGE1
                           WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE2 IS NOT NULL THEN
                               PFE.OPERATION_NAME_CUSTOM_LANGUAGE2
                           WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 IS NOT NULL THEN
                               PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 -- КАСТОМНЫЙ ЯЗЫК
                           END
               END)                                                  OPERATION_NAME,              -- УСЛУГА

           MAX(Q1.DATE_TIME_COLUMN)                                  TIME_RECEIPT_TICKET,         -- ВРЕМЯ ВЫДАЧИ ТАЛОНА
           MAX(Q3.WAITING_TIME)                                      WAITING_TIME,                -- ВРЕМЯ ОЖИДАНИЯ
           MAX(Q2.DATE_TIME_COLUMN)                                  CUSTOMER_SERVICE_START_TIME, -- ВРЕМЯ НАЧАЛА ОБСЛУЖИВАНИЯ КЛИЕНТА
           MAX(Q3.SERVICE_TIME)                                      SERVICE_TIME,                -- ВРЕМЯ ОБСЛУЖИВАНИЯ
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                       THEN PFE.CLIENT_SEGMENT_NAME_EN
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.CLIENT_SEGMENT_NAME_RU
                   ELSE PFE.CLIENT_SEGMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
               END)                                                  CLIENT_SEGMENT_NAME,         -- СЕГМЕНТ КЛИЕНТА
           MAX(CASE
                   WHEN Q3.SESSION_STATUS = 3 THEN CASE
                                                       WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                                                           THEN 'ДА'
                                                       ELSE
                                                           'YES' END
                   ELSE CASE
                            WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                                THEN 'НЕТ'
                            ELSE
                                'NO' END END)                        DENIAL_SERVICE_SYMPTOM,      -- ПРИЗНАК ОТКАЗА В ОБСЛУЖИВАНИИ
           CASE
               WHEN MAX(Q4.CLIENT_ID) IS NOT NULL THEN CASE
                                                           WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                                                               THEN 'ДА'
                                                           ELSE
                                                               'YES' END
               ELSE CASE
                        WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                            THEN 'НЕТ'
                        ELSE 'NO'
                   END END                                           SERVICE_CHANGE_SIGN,         -- ПРИЗНАК СМЕНЫ УСЛУГИ
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.AUTHORIZATION_METHOD_NAME_RU
                   ELSE PFE.AUTHORIZATION_METHOD_NAME_EN -- КАСТОМНЫЙ ЯЗЫК
               END)                                                  AUTHORIZATION_METHOD         -- ПРИЗНАК ИДЕНТИФИКАЦИИ
    FROM POST_FILTERING_EVENTS PFE
             LEFT JOIN (SELECT PFE1.CLIENT_ID, PFE1.EVENT_TYPE_ID, PFE1.DATE_TIME_COLUMN
                        FROM POST_FILTERING_EVENTS PFE1
                        WHERE PFE1.EVENT_TYPE_ID IN (9, 14)) Q1
                       ON PFE.CLIENT_ID = Q1.CLIENT_ID AND PFE.EVENT_TYPE_ID = Q1.EVENT_TYPE_ID
             LEFT JOIN (SELECT PFE2.CLIENT_ID, PFE2.EVENT_TYPE_ID, PFE2.DATE_TIME_COLUMN
                        FROM POST_FILTERING_EVENTS PFE2
                        WHERE PFE2.EVENT_TYPE_ID IN (11, 15, 19)) Q2
                       ON PFE.CLIENT_ID = Q2.CLIENT_ID AND PFE.EVENT_TYPE_ID = Q2.EVENT_TYPE_ID
             LEFT JOIN (SELECT * FROM GET_CLIENT_SESSIONS(IN_DATE_START, IN_DATE_END, IN_DEPARTMENT_ID)) Q3
                       ON PFE.CLIENT_ID = Q3.CLIENT_ID
             LEFT JOIN (SELECT PFE3.CLIENT_ID, PFE3.EVENT_TYPE_ID, PFE3.DATE_TIME_COLUMN
                        FROM POST_FILTERING_EVENTS PFE3
                        WHERE PFE3.EVENT_TYPE_ID = 16) Q4
                       ON PFE.CLIENT_ID = Q4.CLIENT_ID AND PFE.EVENT_TYPE_ID = Q4.EVENT_TYPE_ID
    GROUP BY PFE.CLIENT_ID;

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ TEMP_RESULT_EVENTS, ДОБАВИТЬ СОРТИРОВКУ, ПАГИНАЦИЮ И ИТОГИ.
    RETURN QUERY
        (SELECT *
         FROM TEMP_RESULT_EVENTS TRE
         WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN TRE.ID > IN_PREV_PAGE_LAST_ID ELSE TRE.ID < IN_PREV_PAGE_LAST_ID END
           AND (TRE.WAITING_TIME >= IN_CLIENT_WAITING_TIME_FROM OR IN_CLIENT_WAITING_TIME_FROM = -1)
           AND (TRE.WAITING_TIME < IN_CLIENT_WAITING_TIME_TO OR IN_CLIENT_WAITING_TIME_TO = -1)
           AND (TRE.SERVICE_TIME >= IN_CLIENT_SERVICE_TIME_FROM OR IN_CLIENT_SERVICE_TIME_FROM = -1)
           AND (TRE.SERVICE_TIME < IN_CLIENT_SERVICE_TIME_TO OR IN_CLIENT_SERVICE_TIME_TO = -1)
           AND ((TRE.SERVICE_TIME + TRE.WAITING_TIME) >= IN_TIME_SPENT_IN_DEPARTMENT_FROM OR IN_TIME_SPENT_IN_DEPARTMENT_FROM = -1)
           AND ((TRE.SERVICE_TIME + TRE.WAITING_TIME) < IN_TIME_SPENT_IN_DEPARTMENT_TO OR IN_TIME_SPENT_IN_DEPARTMENT_TO = -1)
           AND (CASE
                    WHEN IN_IS_DENIED_SERVICE = 1 THEN TRE.DENIAL_SERVICE_SYMPTOM = 'ДА' OR TRE.DENIAL_SERVICE_SYMPTOM = 'YES'
                    WHEN IN_IS_DENIED_SERVICE = 2 THEN TRE.DENIAL_SERVICE_SYMPTOM = 'НЕТ' OR TRE.DENIAL_SERVICE_SYMPTOM = 'NO'
                    ELSE IN_IS_DENIED_SERVICE = -1 END)
           AND (CASE
                    WHEN IN_IS_SERVICE_CHANGED = 1 THEN TRE.SERVICE_CHANGE_SIGN = 'ДА' OR TRE.SERVICE_CHANGE_SIGN = 'YES'
                    WHEN IN_IS_SERVICE_CHANGED = 2 THEN TRE.SERVICE_CHANGE_SIGN = 'НЕТ' OR TRE.SERVICE_CHANGE_SIGN = 'NO'
                    ELSE IN_IS_SERVICE_CHANGED = -1 END)
         ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN TRE.ID END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN TRE.ID END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN TRE.DEPARTMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN TRE.DEPARTMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN TRE.WORKPLACE_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN TRE.WORKPLACE_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN TRE.USER_LOGIN END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN TRE.USER_LOGIN END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN TRE.USER_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN TRE.USER_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN TRE.SERVICE_DATE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN TRE.SERVICE_DATE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN TRE.CONFIRMATION_CODE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN TRE.CONFIRMATION_CODE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = TRUE THEN TRE.TICKET_LETTER_AND_NUMBER END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = FALSE THEN TRE.TICKET_LETTER_AND_NUMBER END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = TRUE THEN TRE.GROUP_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = FALSE THEN TRE.GROUP_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = TRUE THEN TRE.OPERATION_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = FALSE THEN TRE.OPERATION_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = TRUE THEN TRE.TIME_RECEIPT_TICKET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = FALSE THEN TRE.TIME_RECEIPT_TICKET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = TRUE THEN TRE.WAITING_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = FALSE THEN TRE.WAITING_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = TRUE THEN TRE.CUSTOMER_SERVICE_START_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = FALSE THEN TRE.CUSTOMER_SERVICE_START_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = TRUE THEN TRE.SERVICE_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = FALSE THEN TRE.SERVICE_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = TRUE THEN TRE.CLIENT_SEGMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = FALSE THEN TRE.CLIENT_SEGMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 16 AND IN_IS_DESCENDING = TRUE THEN TRE.DENIAL_SERVICE_SYMPTOM END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 16 AND IN_IS_DESCENDING = FALSE THEN TRE.DENIAL_SERVICE_SYMPTOM END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 17 AND IN_IS_DESCENDING = TRUE THEN TRE.SERVICE_CHANGE_SIGN END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 17 AND IN_IS_DESCENDING = FALSE THEN TRE.SERVICE_CHANGE_SIGN END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 18 AND IN_IS_DESCENDING = TRUE THEN TRE.AUTHORIZATION_METHOD END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 18 AND IN_IS_DESCENDING = FALSE THEN TRE.AUTHORIZATION_METHOD END) ASC
         LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END
        )
        UNION ALL
        (SELECT MAX(TRE2.ID) + 1       ID,                          -- НОМЕР СТРОКИ, ID
                NULL                   DEPARTMENT_NAME,             -- ОТДЕЛЕНИЕ
                NULL                   WORKPLACE_NAME,              -- РАБОЧЕЕ МЕСТО
                NULL                   USER_LOGIN,                  -- ЛОГИН ОПЕРАТОРА
                NULL                   USER_NAME,                   -- ФИО ОПЕРАТОРА
                NULL                   SERVICE_DATE,                -- ДАТА ОБСЛУЖИВАНИЯ
                NULL                   CONFIRMATION_CODE,           -- КОД ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                NULL                   TICKET_LETTER_AND_NUMBER,    -- № ТАЛОНА
                NULL                   GROUP_NAME,                  -- ГРУППА
                NULL                   OPERATION_NAME,              -- УСЛУГА
                NULL                   TIME_RECEIPT_TICKET,         -- ВРЕМЯ ВЫДАЧИ ТАЛОНА
                SUM(TRE2.WAITING_TIME) WAITING_TIME,                -- ВРЕМЯ ОЖИДАНИЯ
                NULL                   CUSTOMER_SERVICE_START_TIME, -- ВРЕМЯ НАЧАЛА ОБСЛУЖИВАНИЯ КЛИЕНТА
                SUM(TRE2.SERVICE_TIME) SERVICE_TIME,                -- ВРЕМЯ ОБСЛУЖИВАНИЯ
                NULL                   CLIENT_SEGMENT_NAME,         -- СЕГМЕНТ КЛИЕНТА
                NULL                   DENIAL_SERVICE_SYMPTOM,      -- ПРИЗНАК ОТКАЗА В ОБСЛУЖИВАНИИ
                NULL                   SERVICE_CHANGE_SIGN,         -- ПРИЗНАК СМЕНЫ УСЛУГИ
                NULL                   AUTHORIZATION_METHOD         -- ПРИЗНАК ИДЕНТИФИКАЦИИ
         FROM TEMP_RESULT_EVENTS TRE2);
END
$$ LANGUAGE PLPGSQL SECURITY DEFINER;



-- Отчет "Отчет по операциям в разрезе услуг".
CREATE OR REPLACE FUNCTION REPORT_ACTIONS_IN_CONTEXT_OF_OPERATIONS(IN_DEPARTMENT_ID BIGINT,
                                                                   IN_DATE_START TIMESTAMP,
                                                                   IN_DATE_END TIMESTAMP,
                                                                   IN_WORKPLACE_ID BIGINT,
                                                                   IN_USER_ID BIGINT,
                                                                   IN_IS_GROUP_BY_GROUP BOOLEAN,
                                                                   IN_PREV_PAGE_LAST_ID BIGINT,
                                                                   IN_PAGE_SIZE BIGINT,
                                                                   IN_ORDER_BY_COLUMN_ID INT,
                                                                   IN_IS_DESCENDING BOOLEAN,
                                                                   IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID                                        BIGINT,  -- НОМЕР СТРОКИ, ID
                DEPARTMENT_NAME                           TEXT,    -- ОТДЕЛЕНИЕ
                TICKET_LETTER                             TEXT,    -- ЛИТЕРА
                OPERATION_OR_GROUP                        TEXT,    -- НАИМЕНОВАНИЕ УСЛУГИ/ГРУППЫ УСЛУГ
                TOTAL_NUMBER_OPERATIONS                   NUMERIC, -- ОБЩЕЕ КОЛИЧЕСТВО ОПЕРАЦИЙ
                NUMBER_SERVED_CLIENTS                     NUMERIC, -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, N
                PERCENT_SERVED_CLIENTS                    NUMERIC, -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, %
                NUMBER_OF_UN_SERVED_CLIENTS               NUMERIC, -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, N
                PERCENT_OF_UN_SERVED_CLIENTS              NUMERIC, -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, %
                AVERAGE_WAITING_TIME                      NUMERIC, -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
                MAXIMUM_WAITING_TIME                      NUMERIC, -- МАКСИМАЛЬНОЕ ВРЕМЯ ОЖИДАНИЯ
                WAITING_TIME_LESS_THAN_ACCEPTABLE         NUMERIC, -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, N
                PERCENT_WAITING_TIME_LESS_THAN_ACCEPTABLE NUMERIC, -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, %
                WAITING_TIME_LONGER_THAN_ALLOWED          NUMERIC, -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, N
                PERCENT_WAITING_TIME_LONGER_THAN_ALLOWED  NUMERIC, -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, %
                AVERAGE_SERVICE_TIME                      NUMERIC, -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                MAXIMUM_SERVICE_TIME                      NUMERIC, -- МАКСИМАЛЬНОЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                SERVED_SERVICE_FOR_STANDARD_TIME          NUMERIC, -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, N
                PERCENT_SERVED_SERVICE_FOR_STANDARD_TIME  NUMERIC  -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, %
            )
AS
$$
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ОБРАБОТКИ ДАННЫХ.
    CREATE TEMPORARY TABLE TEMP_RESULT_EVENTS
    (
        ID                                        BIGINT,  -- НОМЕР СТРОКИ, ID
        DEPARTMENT_NAME                           TEXT,    -- ОТДЕЛЕНИЕ
        TICKET_LETTER                             TEXT,    -- ЛИТЕРА
        OPERATION_OR_GROUP                        TEXT,    -- НАИМЕНОВАНИЕ УСЛУГИ/ГРУППЫ УСЛУГ
        TOTAL_NUMBER_OPERATIONS                   NUMERIC, -- ОБЩЕЕ КОЛИЧЕСТВО ОПЕРАЦИЙ
        NUMBER_SERVED_CLIENTS                     NUMERIC, -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, N
        PERCENT_SERVED_CLIENTS                    NUMERIC, -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, %
        NUMBER_OF_UNSERVED_CLIENTS                NUMERIC, -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, N
        PERCENT_OF_UNSERVED_CLIENTS               NUMERIC, -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, %
        AVERAGE_WAITING_TIME                      NUMERIC, -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
        MAXIMUM_WAITING_TIME                      NUMERIC, -- МАКСИМАЛЬНОЕ ВРЕМЯ ОЖИДАНИЯ
        WAITING_TIME_LESS_THAN_ACCEPTABLE         NUMERIC, -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, N
        PERCENT_WAITING_TIME_LESS_THAN_ACCEPTABLE NUMERIC, -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, %
        WAITING_TIME_LONGER_THAN_ALLOWED          NUMERIC, -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, N
        PERCENT_WAITING_TIME_LONGER_THAN_ALLOWED  NUMERIC, -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, %
        AVERAGE_SERVICE_TIME                      NUMERIC, -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
        MAXIMUM_SERVICE_TIME                      NUMERIC, -- МАКСИМАЛЬНОЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
        SERVED_SERVICE_FOR_STANDARD_TIME          NUMERIC, -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, N
        PERCENT_SERVED_SERVICE_FOR_STANDARD_TIME  NUMERIC  -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, %
    ) ON COMMIT DROP;

    -- СОЗДАТЬ ОТФИЛЬТРОВАННУЮ КОПИЮ ТАБЛИЦЫ EVENT.
    CREATE TEMPORARY TABLE POST_FILTERING_EVENTS ON COMMIT DROP AS
    SELECT *
    FROM EVENT E
    WHERE (E.DEPARTMENT_ID = IN_DEPARTMENT_ID OR IN_DEPARTMENT_ID = -1)
      AND E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END
      AND (E.USER_ID = IN_USER_ID OR IN_USER_ID = -1)
      AND (E.WORKPLACE_ID = IN_WORKPLACE_ID OR IN_WORKPLACE_ID = -1)
      AND E.CLIENT_ID IS NOT NULL;

    -- ОБРАБОТАТЬ ДАННЫЕ И ПОМЕСТИТЬ ВО ВРЕМЕННУЮ ТАБЛИЦУ.
    INSERT INTO TEMP_RESULT_EVENTS (ID, -- НОМЕР СТРОКИ, ID
                                    DEPARTMENT_NAME, -- ОТДЕЛЕНИЕ
                                    TICKET_LETTER, -- ЛИТЕРА
                                    OPERATION_OR_GROUP, -- НАИМЕНОВАНИЕ УСЛУГИ/ГРУППЫ УСЛУГ
                                    TOTAL_NUMBER_OPERATIONS, -- ОБЩЕЕ КОЛИЧЕСТВО ОПЕРАЦИЙ
                                    NUMBER_SERVED_CLIENTS, -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, N
                                    NUMBER_OF_UNSERVED_CLIENTS, -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, N
                                    AVERAGE_WAITING_TIME, -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
                                    MAXIMUM_WAITING_TIME, -- МАКСИМАЛЬНОЕ ВРЕМЯ ОЖИДАНИЯ
                                    WAITING_TIME_LESS_THAN_ACCEPTABLE, -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, N
                                    WAITING_TIME_LONGER_THAN_ALLOWED, -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, N
                                    AVERAGE_SERVICE_TIME, -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                                    MAXIMUM_SERVICE_TIME, -- МАКСИМАЛЬНОЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                                    SERVED_SERVICE_FOR_STANDARD_TIME -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, N
    )
    SELECT ROW_NUMBER() OVER (PARTITION BY 1)                                         ID,                                -- НОМЕР СТРОКИ
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                       THEN PFE.DEPARTMENT_NAME_EN
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.DEPARTMENT_NAME_RU
                   ELSE PFE.DEPARTMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
               END)                                                                   DEPARTMENT_NAME,                   -- ОТДЕЛЕНИЕ
           MAX(PFE.CLIENT_TICKET_LETTER)                                              TICKET_LETTER,                     -- ЛИТЕРА
           CASE
               WHEN IN_IS_GROUP_BY_GROUP = TRUE THEN
                   CASE
                       WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                           THEN PFE.OPERATION_GROUP_NAME_EN
                       WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                           THEN PFE.OPERATION_GROUP_NAME_RU
                       ELSE PFE.OPERATION_GROUP_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                       END
               ELSE CASE
                        WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                            THEN PFE.OPERATION_NAME_EN
                        WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                            THEN PFE.OPERATION_NAME_RU
                        ELSE
                            CASE
                                WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE1 IS NOT NULL THEN
                                    PFE.OPERATION_NAME_CUSTOM_LANGUAGE1
                                WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE2 IS NOT NULL THEN
                                    PFE.OPERATION_NAME_CUSTOM_LANGUAGE2
                                WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 IS NOT NULL THEN
                                    PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 -- КАСТОМНЫЙ ЯЗЫК
                                END
                   END END                                                            OPERATION_OR_GROUP,                -- НАИМЕНОВАНИЕ УСЛУГИ/ГРУППЫ УСЛУГ
           COUNT(1)                                                                   TOTAL_NUMBER_OPERATIONS,           -- ОБЩЕЕ КОЛИЧЕСТВО ОПЕРАЦИЙ
           COUNT(Q2.CLIENT_ID)                                                        NUMBER_SERVED_CLIENTS,             -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, N
           (COUNT(Q1.CLIENT_ID) - COUNT(Q2.CLIENT_ID))                                NUMBER_OF_UNSERVED_CLIENTS,        -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, N
           AVG(DISTINCT Q3.WAITING_TIME)                                              AVERAGE_WAITING_TIME,              -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
           MAX(DISTINCT Q3.WAITING_TIME)                                              MAXIMUM_WAITING_TIME,              -- МАКСИМАЛЬНОЕ ВРЕМЯ ОЖИДАНИЯ
           SUM(CASE WHEN Q3.WAITING_TIME < Q1.WAIT_MAX_TIME THEN 1 ELSE 0 END)        WAITING_TIME_LESS_THAN_ACCEPTABLE, -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, N
           SUM(CASE WHEN Q3.WAITING_TIME >= Q1.WAIT_MAX_TIME THEN 1 ELSE 0 END)       WAITING_TIME_LONGER_THAN_ALLOWED,  -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, N
           AVG(DISTINCT Q3.SERVICE_TIME)                                              AVERAGE_SERVICE_TIME,              -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
           MAX(DISTINCT Q3.SERVICE_TIME)                                              MAXIMUM_SERVICE_TIME,              -- МАКСИМАЛЬНОЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
           SUM(
                   CASE WHEN Q3.SERVICE_TIME <= PFE.NORMATIVE_TIME THEN 1 ELSE 0 END) SERVED_SERVICE_FOR_STANDARD_TIME   -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, N
    FROM POST_FILTERING_EVENTS PFE
             LEFT JOIN (SELECT PFE1.CLIENT_ID, PFE1.EVENT_TYPE_ID, PFE1.DATE_TIME_COLUMN, PFE1.WAIT_MAX_TIME
                        FROM POST_FILTERING_EVENTS PFE1
                        WHERE PFE1.EVENT_TYPE_ID IN (9, 14)) Q1
                       ON PFE.CLIENT_ID = Q1.CLIENT_ID AND PFE.EVENT_TYPE_ID = Q1.EVENT_TYPE_ID
             LEFT JOIN (SELECT PFE2.CLIENT_ID, PFE2.EVENT_TYPE_ID, PFE2.DATE_TIME_COLUMN
                        FROM POST_FILTERING_EVENTS PFE2
                        WHERE PFE2.EVENT_TYPE_ID IN (11, 15, 19)) Q2
                       ON PFE.CLIENT_ID = Q2.CLIENT_ID AND PFE.EVENT_TYPE_ID = Q2.EVENT_TYPE_ID
             LEFT JOIN (SELECT * FROM GET_CLIENT_SESSIONS(IN_DATE_START, IN_DATE_END, IN_DEPARTMENT_ID)) Q3
                       ON PFE.CLIENT_ID = Q3.CLIENT_ID
    GROUP BY CASE
                 WHEN IN_IS_GROUP_BY_GROUP = TRUE THEN
                     CASE
                         WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                             THEN PFE.OPERATION_GROUP_NAME_EN
                         WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                             THEN PFE.OPERATION_GROUP_NAME_RU
                         ELSE PFE.OPERATION_GROUP_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
                         END
                 ELSE CASE
                          WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                              THEN PFE.OPERATION_NAME_EN
                          WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                              THEN PFE.OPERATION_NAME_RU
                          ELSE
                              CASE
                                  WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE1 IS NOT NULL THEN
                                      PFE.OPERATION_NAME_CUSTOM_LANGUAGE1
                                  WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE2 IS NOT NULL THEN
                                      PFE.OPERATION_NAME_CUSTOM_LANGUAGE2
                                  WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 IS NOT NULL THEN
                                      PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 -- КАСТОМНЫЙ ЯЗЫК
                                  END
                     END END;

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ TEMP_RESULT_EVENTS, ДОБАВИТЬ СОРТИРОВКУ, ПАГИНАЦИЮ И ИТОГИ.
    RETURN QUERY
        (SELECT TRE.ID,                                                                                                                                      -- НОМЕР СТРОКИ, ID
                TRE.DEPARTMENT_NAME,                                                                                                                         -- ОТДЕЛЕНИЕ
                TRE.TICKET_LETTER,                                                                                                                           -- ЛИТЕРА
                TRE.OPERATION_OR_GROUP,                                                                                                                      -- НАИМЕНОВАНИЕ УСЛУГИ/ГРУППЫ УСЛУГ
                TRE.TOTAL_NUMBER_OPERATIONS,                                                                                                                 -- ОБЩЕЕ КОЛИЧЕСТВО ОПЕРАЦИЙ
                TRE.NUMBER_SERVED_CLIENTS,                                                                                                                   -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, N
                CASE
                    WHEN TRE.NUMBER_SERVED_CLIENTS = 0 THEN 0
                    ELSE (TRE.NUMBER_SERVED_CLIENTS / SUM(TRE.NUMBER_SERVED_CLIENTS) OVER ()) * 100 END           PERCENT_SERVED_CLIENTS,                    -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, %
                TRE.NUMBER_OF_UNSERVED_CLIENTS                                                                    NUMBER_OF_UNSERVED_CLIENTS,                -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, N
                CASE
                    WHEN TRE.NUMBER_OF_UNSERVED_CLIENTS = 0 THEN 0
                    ELSE (TRE.NUMBER_OF_UNSERVED_CLIENTS / SUM(TRE.NUMBER_OF_UNSERVED_CLIENTS) OVER ()) * 100 END PERCENT_OF_UNSERVED_CLIENTS,               -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, %
                TRE.AVERAGE_WAITING_TIME,                                                                                                                    -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
                TRE.MAXIMUM_WAITING_TIME,                                                                                                                    -- МАКСИМАЛЬНОЕ ВРЕМЯ ОЖИДАНИЯ
                TRE.WAITING_TIME_LESS_THAN_ACCEPTABLE,                                                                                                       -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, N
                CASE
                    WHEN TRE.WAITING_TIME_LESS_THAN_ACCEPTABLE = 0 THEN 0
                    ELSE (TRE.WAITING_TIME_LESS_THAN_ACCEPTABLE / SUM(TRE.WAITING_TIME_LESS_THAN_ACCEPTABLE) OVER ()) *
                         100 END                                                                                  PERCENT_WAITING_TIME_LESS_THAN_ACCEPTABLE, -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, %
                TRE.WAITING_TIME_LONGER_THAN_ALLOWED,                                                                                                        -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, N
                CASE
                    WHEN TRE.WAITING_TIME_LONGER_THAN_ALLOWED = 0 THEN 0
                    ELSE (TRE.WAITING_TIME_LONGER_THAN_ALLOWED / SUM(TRE.WAITING_TIME_LONGER_THAN_ALLOWED) OVER ()) *
                         100 END                                                                                  PERCENT_WAITING_TIME_LONGER_THAN_ALLOWED,  -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, %
                TRE.AVERAGE_SERVICE_TIME,                                                                                                                    -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                TRE.MAXIMUM_SERVICE_TIME,                                                                                                                    -- МАКСИМАЛЬНОЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                TRE.SERVED_SERVICE_FOR_STANDARD_TIME,                                                                                                        -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, N
                CASE
                    WHEN TRE.SERVED_SERVICE_FOR_STANDARD_TIME = 0 THEN 0
                    ELSE (TRE.SERVED_SERVICE_FOR_STANDARD_TIME / SUM(TRE.SERVED_SERVICE_FOR_STANDARD_TIME) OVER ()) *
                         100 END                                                                                  PERCENT_SERVED_SERVICE_FOR_STANDARD_TIME   -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, %
         FROM TEMP_RESULT_EVENTS TRE
         WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN TRE.ID > IN_PREV_PAGE_LAST_ID ELSE TRE.ID < IN_PREV_PAGE_LAST_ID END
         ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN TRE.ID END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN TRE.ID END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN TRE.DEPARTMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN TRE.DEPARTMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN TRE.TICKET_LETTER END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN TRE.TICKET_LETTER END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN TRE.OPERATION_OR_GROUP END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN TRE.OPERATION_OR_GROUP END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN TRE.TOTAL_NUMBER_OPERATIONS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN TRE.TOTAL_NUMBER_OPERATIONS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_SERVED_CLIENTS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_SERVED_CLIENTS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENT_SERVED_CLIENTS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENT_SERVED_CLIENTS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_OF_UNSERVED_CLIENTS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_OF_UNSERVED_CLIENTS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENT_OF_UNSERVED_CLIENTS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENT_OF_UNSERVED_CLIENTS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = TRUE THEN TRE.AVERAGE_WAITING_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = FALSE THEN TRE.AVERAGE_WAITING_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = TRUE THEN TRE.MAXIMUM_WAITING_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = FALSE THEN TRE.MAXIMUM_WAITING_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = TRUE THEN TRE.WAITING_TIME_LESS_THAN_ACCEPTABLE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = FALSE THEN TRE.WAITING_TIME_LESS_THAN_ACCEPTABLE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENT_WAITING_TIME_LESS_THAN_ACCEPTABLE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENT_WAITING_TIME_LESS_THAN_ACCEPTABLE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = TRUE THEN TRE.WAITING_TIME_LONGER_THAN_ALLOWED END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = FALSE THEN TRE.WAITING_TIME_LONGER_THAN_ALLOWED END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENT_WAITING_TIME_LONGER_THAN_ALLOWED END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENT_WAITING_TIME_LONGER_THAN_ALLOWED END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 16 AND IN_IS_DESCENDING = TRUE THEN TRE.AVERAGE_SERVICE_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 16 AND IN_IS_DESCENDING = FALSE THEN TRE.AVERAGE_SERVICE_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 17 AND IN_IS_DESCENDING = TRUE THEN TRE.MAXIMUM_SERVICE_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 17 AND IN_IS_DESCENDING = FALSE THEN TRE.MAXIMUM_SERVICE_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 18 AND IN_IS_DESCENDING = TRUE THEN TRE.SERVED_SERVICE_FOR_STANDARD_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 18 AND IN_IS_DESCENDING = FALSE THEN TRE.SERVED_SERVICE_FOR_STANDARD_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 19 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENT_SERVED_SERVICE_FOR_STANDARD_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 19 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENT_SERVED_SERVICE_FOR_STANDARD_TIME END) ASC
         LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END
        )
        UNION ALL
        (SELECT MAX(TRE2.ID) + 1                                                              ID,                                        -- НОМЕР СТРОКИ, ID
                NULL                                                                          DEPARTMENT_NAME,                           -- ОТДЕЛЕНИЕ
                NULL                                                                          TICKET_LETTER,                             -- ЛИТЕРА
                NULL                                                                          OPERATION_OR_GROUP,                        -- НАИМЕНОВАНИЕ УСЛУГИ/ГРУППЫ УСЛУГ
                SUM(TRE2.TOTAL_NUMBER_OPERATIONS)                                             TOTAL_NUMBER_OPERATIONS,                   -- ОБЩЕЕ КОЛИЧЕСТВО ОПЕРАЦИЙ
                SUM(TRE2.NUMBER_SERVED_CLIENTS)                                               NUMBER_SERVED_CLIENTS,                     -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, N
                CASE WHEN SUM(TRE2.NUMBER_SERVED_CLIENTS) = 0 THEN 0 ELSE 100 END             PERCENT_SERVED_CLIENTS,                    -- ОБСЛУЖЕНО ПО ОПЕРАЦИИ, %
                SUM(TRE2.NUMBER_OF_UNSERVED_CLIENTS)                                          NUMBER_OF_UNSERVED_CLIENTS,                -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, N
                CASE WHEN SUM(TRE2.NUMBER_OF_UNSERVED_CLIENTS) = 0 THEN 0 ELSE 100 END        PERCENT_OF_UNSERVED_CLIENTS,               -- НЕ ОБСЛУЖЕНО ПО ОПЕРАЦИЯМ, %
                AVG(TRE2.AVERAGE_WAITING_TIME)                                                AVERAGE_WAITING_TIME,                      -- СРЕДНЕЕ ВРЕМЯ ОЖИДАНИЯ
                MAX(TRE2.MAXIMUM_WAITING_TIME)                                                MAXIMUM_WAITING_TIME,                      -- МАКСИМАЛЬНОЕ ВРЕМЯ ОЖИДАНИЯ
                SUM(TRE2.WAITING_TIME_LESS_THAN_ACCEPTABLE)                                   WAITING_TIME_LESS_THAN_ACCEPTABLE,         -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, N
                CASE WHEN SUM(TRE2.WAITING_TIME_LESS_THAN_ACCEPTABLE) = 0 THEN 0 ELSE 100 END PERCENT_WAITING_TIME_LESS_THAN_ACCEPTABLE, -- ВРЕМЯ ОЖИДАНИЯ МЕНЬШЕ ДОПУСТИМОГО, %
                SUM(TRE2.WAITING_TIME_LONGER_THAN_ALLOWED)                                    WAITING_TIME_LONGER_THAN_ALLOWED,          -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, N
                CASE WHEN SUM(TRE2.WAITING_TIME_LONGER_THAN_ALLOWED) = 0 THEN 0 ELSE 100 END  PERCENT_WAITING_TIME_LONGER_THAN_ALLOWED,  -- ВРЕМЯ ОЖИДАНИЯ БОЛЬШЕ ДОПУСТИМОГО, %
                AVG(TRE2.AVERAGE_SERVICE_TIME)                                                AVERAGE_SERVICE_TIME,                      -- СРЕДНЕЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                MAX(TRE2.MAXIMUM_SERVICE_TIME)                                                MAXIMUM_SERVICE_TIME,                      -- МАКСИМАЛЬНОЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                SUM(TRE2.SERVED_SERVICE_FOR_STANDARD_TIME)                                    SERVED_SERVICE_FOR_STANDARD_TIME,          -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, N
                CASE WHEN SUM(TRE2.SERVED_SERVICE_FOR_STANDARD_TIME) = 0 THEN 0 ELSE 100 END  PERCENT_SERVED_SERVICE_FOR_STANDARD_TIME   -- ОБСЛУЖЕНО ПО УСЛУГЕ ЗА НОРМАТИВНОЕ ВРЕМЯ, %
         FROM TEMP_RESULT_EVENTS TRE2);
END
$$ LANGUAGE PLPGSQL SECURITY DEFINER;



-- Отчет "Отчет по предварительным записям".
CREATE OR REPLACE FUNCTION REPORT_PRE_RECORDING(IN_DEPARTMENT_ID BIGINT,
                                                IN_DATE_START TIMESTAMP,
                                                IN_DATE_END TIMESTAMP,
                                                IN_PREV_PAGE_LAST_ID BIGINT,
                                                IN_PAGE_SIZE BIGINT,
                                                IN_ORDER_BY_COLUMN_ID INT,
                                                IN_IS_DESCENDING BOOLEAN,
                                                IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID                                                BIGINT,    -- НОМЕР СТРОКИ, ID
                DEPARTMENT_NAME                                   TEXT,      -- ОТДЕЛЕНИЕ
                SERVICE_DATE                                      TIMESTAMP, -- ДАТА
                OPERATION_NAME                                    TEXT,      -- УСЛУГА
                TOTAL_PRE_REGISTRATION_TICKETS                    NUMERIC,   -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                NUMBER_OF_TICKET_IN_DEMAND                        NUMERIC,   -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                PERCENTAGE_OF_DEMANDED_TICKET                     NUMERIC,   -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                NUMBER_OF_UNCLAIMED_TICKET                        NUMERIC,   -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                PERCENTAGE_OF_UNCLAIMED_TICKET                    NUMERIC,   -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                NUMBER_RECEIVED_VIA_INTERNET                      NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
                PERCENTAGE_RECEIVED_OVER_INTERNET                 NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, %
                NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE     NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
                PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, %
                NUMBER_RECEIVED_THROUGH_TICKET_KIOSK              NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
                PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK          NUMERIC    -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, %*/
            )
AS
$$
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ОБРАБОТКИ ДАННЫХ.
    CREATE TEMPORARY TABLE TEMP_RESULT_EVENTS
    (
        ID                                                BIGINT,    -- НОМЕР СТРОКИ, ID
        DEPARTMENT_NAME                                   TEXT,      -- ОТДЕЛЕНИЕ
        SERVICE_DATE                                      TIMESTAMP, -- ДАТА
        OPERATION_NAME                                    TEXT,      -- УСЛУГА
        TOTAL_PRE_REGISTRATION_TICKETS                    NUMERIC,   -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
        NUMBER_OF_TICKET_IN_DEMAND                        NUMERIC,   -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
        PERCENTAGE_OF_DEMANDED_TICKET                     NUMERIC,   -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, %
        NUMBER_OF_UNCLAIMED_TICKET                        NUMERIC,   -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
        PERCENTAGE_OF_UNCLAIMED_TICKET                    NUMERIC,   -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, %
        NUMBER_RECEIVED_VIA_INTERNET                      NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
        PERCENTAGE_RECEIVED_OVER_INTERNET                 NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, %
        NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE     NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
        PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, %
        NUMBER_RECEIVED_THROUGH_TICKET_KIOSK              NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
        PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK          NUMERIC    -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, %
    ) ON COMMIT DROP;

    -- СОЗДАТЬ ОТФИЛЬТРОВАННУЮ КОПИЮ ТАБЛИЦЫ EVENT.
    CREATE TEMPORARY TABLE POST_FILTERING_EVENTS ON COMMIT DROP AS
    SELECT E.*, NULL START_SERVICE_DATE_TIME
    FROM EVENT E
    WHERE E.EVENT_TYPE_ID NOT IN (42, 43, 44)
      AND (E.DEPARTMENT_ID = IN_DEPARTMENT_ID OR IN_DEPARTMENT_ID = -1)
      AND E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END
      AND E.CLIENT_CONFIRMATION_CODE IS NOT NULL
    UNION ALL
    (SELECT EE.*, R.START_SERVICE_DATE_TIME START_SERVICE_DATE_TIME
     FROM EVENT EE
              LEFT JOIN REGISTRATION R
                        ON EE.CLIENT_CONFIRMATION_CODE = R.CONFIRMATION_CODE
     WHERE EE.EVENT_TYPE_ID IN (42, 43, 44)
       AND R.START_SERVICE_DATE_TIME BETWEEN IN_DATE_START AND IN_DATE_END
       AND EE.CLIENT_CONFIRMATION_CODE IS NOT NULL);

    -- ОБРАБОТАТЬ ДАННЫЕ И ПОМЕСТИТЬ ВО ВРЕМЕННУЮ ТАБЛИЦУ.
    INSERT INTO TEMP_RESULT_EVENTS (ID, -- НОМЕР СТРОКИ, ID
                                    DEPARTMENT_NAME, -- ОТДЕЛЕНИЕ
                                    SERVICE_DATE, -- ДАТА
                                    OPERATION_NAME, -- УСЛУГА
                                    TOTAL_PRE_REGISTRATION_TICKETS, -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                                    NUMBER_OF_TICKET_IN_DEMAND, -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                                    NUMBER_OF_UNCLAIMED_TICKET, -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                                    NUMBER_RECEIVED_VIA_INTERNET, -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
                                    NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE, -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
                                    NUMBER_RECEIVED_THROUGH_TICKET_KIOSK -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
    )
    SELECT ROW_NUMBER() OVER (PARTITION BY 1)                                                                                      ID,                                            -- НОМЕР СТРОКИ
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                       THEN PFE.DEPARTMENT_NAME_EN
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.DEPARTMENT_NAME_RU
                   ELSE PFE.DEPARTMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
               END)                                                                                                                DEPARTMENT_NAME,                               -- ОТДЕЛЕНИЕ
           MAX(DATE(CASE WHEN PFE.START_SERVICE_DATE_TIME IS NULL THEN PFE.DATE_TIME_COLUMN ELSE PFE.START_SERVICE_DATE_TIME END)) SERVICE_DATE,                                  -- ДАТА
           CASE
               WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                   THEN PFE.OPERATION_NAME_EN
               WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                   THEN PFE.OPERATION_NAME_RU
               ELSE
                   CASE
                       WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE1 IS NOT NULL THEN
                           PFE.OPERATION_NAME_CUSTOM_LANGUAGE1
                       WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE2 IS NOT NULL THEN
                           PFE.OPERATION_NAME_CUSTOM_LANGUAGE2
                       WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 IS NOT NULL THEN
                           PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 -- КАСТОМНЫЙ ЯЗЫК
                       END
               END                                                                                                                 OPERATION_NAME,                                -- НАИМЕНОВАНИЕ УСЛУГИ
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 ) -
            COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 44 ))                                  TOTAL_PRE_REGISTRATION_TICKETS,                -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
           COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID IN (11, 15, 19) )                         NUMBER_OF_TICKET_IN_DEMAND,                    -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
           ((COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 ) -
             COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 44 )) -
            COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID IN (11, 15, 19) ))                       NUMBER_OF_UNCLAIMED_TICKET,                    -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 AND PFE.WAY_OF_QUEUING_ID = 2 ) -
            COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE)
            FILTER ( WHERE PFE.EVENT_TYPE_ID = 44 AND PFE.WAY_OF_QUEUING_ID = 2 ))                                                NUMBER_RECEIVED_VIA_INTERNET,                  -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 AND PFE.WAY_OF_QUEUING_ID = 3 ) -
            COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE)
            FILTER ( WHERE PFE.EVENT_TYPE_ID = 44 AND PFE.WAY_OF_QUEUING_ID = 3 ))                                                NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE, -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 AND PFE.WAY_OF_QUEUING_ID = 1 ) -
            COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE)
            FILTER ( WHERE PFE.EVENT_TYPE_ID = 44 AND PFE.WAY_OF_QUEUING_ID = 1 ))                                                NUMBER_RECEIVED_THROUGH_TICKET_KIOSK           -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
    FROM POST_FILTERING_EVENTS PFE
    GROUP BY DATE(CASE WHEN PFE.START_SERVICE_DATE_TIME IS NULL THEN PFE.DATE_TIME_COLUMN ELSE PFE.START_SERVICE_DATE_TIME END),
             CASE
                 WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                     THEN PFE.OPERATION_NAME_EN
                 WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                     THEN PFE.OPERATION_NAME_RU
                 ELSE
                     CASE
                         WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE1 IS NOT NULL THEN
                             PFE.OPERATION_NAME_CUSTOM_LANGUAGE1
                         WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE2 IS NOT NULL THEN
                             PFE.OPERATION_NAME_CUSTOM_LANGUAGE2
                         WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 IS NOT NULL THEN
                             PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 -- КАСТОМНЫЙ ЯЗЫК
                         END
                 END;

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ TEMP_RESULT_EVENTS, ДОБАВИТЬ СОРТИРОВКУ, ПАГИНАЦИЮ И ИТОГИ.
    RETURN QUERY
        (SELECT TRE.ID,                                                                                                                                                                  -- НОМЕР СТРОКИ, ID
                TRE.DEPARTMENT_NAME,                                                                                                                                                     -- ОТДЕЛЕНИЕ
                TRE.SERVICE_DATE,                                                                                                                                                        -- ДАТА
                TRE.OPERATION_NAME,                                                                                                                                                      -- УСЛУГА
                TRE.TOTAL_PRE_REGISTRATION_TICKETS,                                                                                                                                      -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                TRE.NUMBER_OF_TICKET_IN_DEMAND,                                                                                                                                          -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                CASE
                    WHEN TRE.NUMBER_OF_TICKET_IN_DEMAND = 0 THEN 0
                    ELSE (TRE.NUMBER_OF_TICKET_IN_DEMAND / SUM(TRE.NUMBER_OF_TICKET_IN_DEMAND) OVER ()) * 100 END                     PERCENTAGE_OF_DEMANDED_TICKET,                     -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                TRE.NUMBER_OF_UNCLAIMED_TICKET,                                                                                                                                          -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                CASE
                    WHEN TRE.NUMBER_OF_UNCLAIMED_TICKET = 0 THEN 0
                    ELSE (TRE.NUMBER_OF_UNCLAIMED_TICKET / SUM(TRE.NUMBER_OF_UNCLAIMED_TICKET) OVER ()) * 100 END                     PERCENTAGE_OF_UNCLAIMED_TICKET,                    -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                TRE.NUMBER_RECEIVED_VIA_INTERNET,                                                                                                                                        -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
                CASE
                    WHEN TRE.NUMBER_RECEIVED_VIA_INTERNET = 0 THEN 0
                    ELSE (TRE.NUMBER_RECEIVED_VIA_INTERNET / SUM(TRE.NUMBER_RECEIVED_VIA_INTERNET) OVER ()) * 100 END                 PERCENTAGE_RECEIVED_OVER_INTERNET,                 -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, %
                TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE,                                                                                                                       -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
                CASE
                    WHEN TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE = 0 THEN 0
                    ELSE (TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE / SUM(TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE) OVER ()) *
                         100 END                                                                                                      PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE, -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, %
                TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK,                                                                                                                                -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
                CASE
                    WHEN TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK = 0 THEN 0
                    ELSE (TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK / SUM(TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK) OVER ()) * 100 END PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK           -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, %
         FROM TEMP_RESULT_EVENTS TRE
         WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN TRE.ID > IN_PREV_PAGE_LAST_ID ELSE TRE.ID < IN_PREV_PAGE_LAST_ID END
         ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN TRE.ID END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN TRE.ID END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN TRE.DEPARTMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN TRE.DEPARTMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN TRE.SERVICE_DATE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN TRE.SERVICE_DATE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN TRE.OPERATION_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN TRE.OPERATION_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN TRE.TOTAL_PRE_REGISTRATION_TICKETS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN TRE.TOTAL_PRE_REGISTRATION_TICKETS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_OF_TICKET_IN_DEMAND END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_OF_TICKET_IN_DEMAND END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_OF_DEMANDED_TICKET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_OF_DEMANDED_TICKET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_OF_UNCLAIMED_TICKET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_OF_UNCLAIMED_TICKET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_OF_UNCLAIMED_TICKET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_OF_UNCLAIMED_TICKET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_RECEIVED_VIA_INTERNET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_RECEIVED_VIA_INTERNET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_RECEIVED_OVER_INTERNET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_RECEIVED_OVER_INTERNET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK END) ASC
         LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END
        )
        UNION ALL
        (SELECT MAX(TRE2.ID) + 1                                                                              ID,                                                -- НОМЕР СТРОКИ, ID
                NULL                                                                                          DEPARTMENT_NAME,                                   -- ОТДЕЛЕНИЕ
                NULL                                                                                          SERVICE_DATE,                                      -- ДАТА
                NULL                                                                                          OPERATION_NAME,                                    -- УСЛУГА
                SUM(TRE2.TOTAL_PRE_REGISTRATION_TICKETS)                                                      TOTAL_PRE_REGISTRATION_TICKETS,                    -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                SUM(TRE2.NUMBER_OF_TICKET_IN_DEMAND)                                                          NUMBER_OF_TICKET_IN_DEMAND,                        -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                CASE WHEN SUM(TRE2.PERCENTAGE_OF_DEMANDED_TICKET) = 0 THEN 0 ELSE 100 END                     PERCENTAGE_OF_DEMANDED_TICKET,                     -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                SUM(TRE2.NUMBER_OF_UNCLAIMED_TICKET)                                                          NUMBER_OF_UNCLAIMED_TICKET,                        -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                CASE WHEN SUM(TRE2.PERCENTAGE_OF_UNCLAIMED_TICKET) = 0 THEN 0 ELSE 100 END                    PERCENTAGE_OF_UNCLAIMED_TICKET,                    -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                SUM(TRE2.NUMBER_RECEIVED_VIA_INTERNET)                                                        NUMBER_RECEIVED_VIA_INTERNET,                      -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
                CASE WHEN SUM(TRE2.PERCENTAGE_RECEIVED_OVER_INTERNET) = 0 THEN 0 ELSE 100 END                 PERCENTAGE_RECEIVED_OVER_INTERNET,                 -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, %
                SUM(TRE2.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE)                                       NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE,     -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
                CASE WHEN SUM(TRE2.PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE) = 0 THEN 0 ELSE 100 END PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE, -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, %
                SUM(TRE2.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK)                                                NUMBER_RECEIVED_THROUGH_TICKET_KIOSK,              -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
                CASE WHEN SUM(TRE2.PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK) = 0 THEN 0 ELSE 100 END          PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK           -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, %
         FROM TEMP_RESULT_EVENTS TRE2);
END
$$ LANGUAGE PLPGSQL SECURITY DEFINER;