/**
 * QFIVEDEV-1105 - Минусовые значения в отчете Предварительная запись.
 * Скрипт включает в себя следующие изменения:
 * 1. Добавление в таблицу event нового поля pre_registration_start_service_date_time.
 * 2. GET_CLIENT_SESSIONS - Перезалита функция.
 * 3. REPORT_PRE_RECORDING - Исправлен "Отчет по предварительным записям". Убрана связь с таблицей registration. Переработана фильтрация отделения, удаленных и отредактированных записей. Добавлена обработка нового поля pre_registration_start_service_date_time вместо аналогичного из таблицы registration.
*/

-- Добавлено поле pre_registration_start_service_date_time.
ALTER TABLE EVENT ADD COLUMN IF NOT EXISTS PRE_REGISTRATION_START_SERVICE_DATE_TIME TIMESTAMP;

-- Перезалита функция GET_CLIENT_SESSIONS.
DROP FUNCTION IF EXISTS GET_CLIENT_SESSIONS;
CREATE FUNCTION GET_CLIENT_SESSIONS(IN_DATE_START TIMESTAMP,
                                    IN_DATE_END TIMESTAMP,
                                    IN_DEPARTMENT_ID BIGINT)
    RETURNS TABLE
            (
                CLIENT_ID              BIGINT,
                WAITING_TIME           INTEGER,
                SERVICE_TIME           INTEGER,
                REG_DT                 TIMESTAMP,
                CALL_DT                TIMESTAMP,
                FINISH_DT              TIMESTAMP,
                SESSION_STATUS         BIGINT,
                DEPARTMENT_ID          BIGINT,
                USER_ID                BIGINT,
                TICKET                 TEXT,
                OPERATION_ID           BIGINT,
                OPERATION_NAME_RU      TEXT,
                OPERATION_NAME_EN      TEXT,
                OPERATION_NAME_CUSTOM1 TEXT,
                OPERATION_NAME_CUSTOM2 TEXT,
                OPERATION_NAME_CUSTOM3 TEXT,
                WORKPLACE_ID           BIGINT,
                WORKPLACE_NAME_RU      TEXT,
                WORKPLACE_NAME_EN      TEXT,
                WORKPLACE_NAME_CUSTOM  TEXT,
                OPERATOR_NAME          TEXT,
                FINISH_EVENT_TYPE_ID   INTEGER
            )
    LANGUAGE PLPGSQL
AS
$$
DECLARE
    EVENT_LOOP EVENT%ROWTYPE;
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ВЫВОДА.
    CREATE TEMPORARY TABLE IF NOT EXISTS TEMP_CLIENT_SESSIONS
    (
        CLIENT_ID              BIGINT,
        WAITING_TIME           INTEGER DEFAULT 0,
        SERVICE_TIME           INTEGER DEFAULT 0,
        REG_DT                 TIMESTAMP,
        CALL_DT                TIMESTAMP,
        FINISH_DT              TIMESTAMP,
        -- SESSION_STATUS: 0(СЕССИЯ ОТКРЫТА, КЛИЕНТ В ОЧЕРЕДИ), 1(КЛИЕНТ ОБСЛУЖИВАЕТСЯ ОПЕРАТОРОМ), 2(СЕССИЯ ЗАКРЫТА, ОБСЛУЖИВАНИЕ ЗАВЕРШЕНО), 3(СЕССИЯ ЗАВЕРШЕНА, КЛИЕНТ УДАЛЕН)
        SESSION_STATUS         BIGINT,
        DEPARTMENT_ID          BIGINT,
        USER_ID                BIGINT,
        TICKET                 TEXT,
        OPERATION_ID           BIGINT,
        OPERATION_NAME_RU      TEXT,
        OPERATION_NAME_EN      TEXT,
        OPERATION_NAME_CUSTOM1 TEXT,
        OPERATION_NAME_CUSTOM2 TEXT,
        OPERATION_NAME_CUSTOM3 TEXT,
        WORKPLACE_ID           BIGINT,
        WORKPLACE_NAME_RU      TEXT,
        WORKPLACE_NAME_EN      TEXT,
        WORKPLACE_NAME_CUSTOM  TEXT,
        OPERATOR_NAME          TEXT,
        FINISH_EVENT_TYPE_ID   INTEGER
    );

    -- СОЗДАТЬ ЦИКЛ ПО ТАБЛИЦЕ EVENT С КЛИЕНТСКИМИ ТИПАМИ СОБЫТИЙ.
    FOR EVENT_LOOP IN SELECT *
                      FROM EVENT E
                      WHERE (E.DEPARTMENT_ID = IN_DEPARTMENT_ID OR IN_DEPARTMENT_ID = -1)
                        AND E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END
                        AND E.CLIENT_ID IS NOT NULL
                        AND E.EVENT_TYPE_ID IN (9, 10, 11, 14, 15, 16, 19, 20, 21, 22, 23)
                      ORDER BY CLIENT_ID, DATE_TIME_COLUMN
        LOOP
            -- РЕГИСТРАЦИЯ КЛИЕНТА [%S%S] НА УСЛУГУ [%S].
            IF EVENT_LOOP.EVENT_TYPE_ID = 9 THEN
                INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID, TICKET, OPERATION_ID, OPERATION_NAME_RU,
                                                  OPERATION_NAME_EN, OPERATION_NAME_CUSTOM1, OPERATION_NAME_CUSTOM2, OPERATION_NAME_CUSTOM3,
                                                  WORKPLACE_ID, WORKPLACE_NAME_RU, WORKPLACE_NAME_EN, WORKPLACE_NAME_CUSTOM, OPERATOR_NAME, FINISH_EVENT_TYPE_ID)
                VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID,
                        CONCAT(EVENT_LOOP.CLIENT_TICKET_LETTER, EVENT_LOOP.CLIENT_TICKET_NUMBER),
                        EVENT_LOOP.OPERATION_ID, EVENT_LOOP.OPERATION_NAME_RU, EVENT_LOOP.OPERATION_NAME_EN, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE1,
                        EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE2, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE3,
                        EVENT_LOOP.WORKPLACE_ID, EVENT_LOOP.WORKPLACE_NAME_RU, EVENT_LOOP.WORKPLACE_NAME_EN, EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                        CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ', EVENT_LOOP.USER_LAST_NAME), EVENT_LOOP.EVENT_TYPE_ID);
            END IF;

            -- РЕГИСТРАЦИЯ КЛИЕНТА [%S%S] НА УСЛУГУ  [%S] С ПОМОЩЬЮ СПЕЦИАЛЬНОЙ РЕГИСТРАЦИИ.
            IF EVENT_LOOP.EVENT_TYPE_ID = 14 THEN
                IF EXISTS(SELECT * FROM EVENT E WHERE EVENT_LOOP.CLIENT_ID = E.CLIENT_ID AND E.EVENT_TYPE_ID = 10) AND
                   NOT EXISTS(SELECT * FROM EVENT E WHERE EVENT_LOOP.CLIENT_ID = E.CLIENT_ID AND E.EVENT_TYPE_ID IN (15, 20))
                THEN
                    INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID, TICKET, OPERATION_ID,
                                                      OPERATION_NAME_RU,
                                                      OPERATION_NAME_EN, OPERATION_NAME_CUSTOM1, OPERATION_NAME_CUSTOM2, OPERATION_NAME_CUSTOM3, WORKPLACE_ID, WORKPLACE_NAME_RU,
                                                      WORKPLACE_NAME_EN, WORKPLACE_NAME_CUSTOM, OPERATOR_NAME, FINISH_EVENT_TYPE_ID)
                    VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID,
                            CONCAT(EVENT_LOOP.CLIENT_TICKET_LETTER, EVENT_LOOP.CLIENT_TICKET_NUMBER),
                            EVENT_LOOP.OPERATION_ID, EVENT_LOOP.OPERATION_NAME_RU, EVENT_LOOP.OPERATION_NAME_EN, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE1,
                            EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE2, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE3,
                            EVENT_LOOP.WORKPLACE_ID, EVENT_LOOP.WORKPLACE_NAME_RU, EVENT_LOOP.WORKPLACE_NAME_EN, EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                            CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ', EVENT_LOOP.USER_LAST_NAME), EVENT_LOOP.EVENT_TYPE_ID);
                ELSE
                    INSERT INTO TEMP_CLIENT_SESSIONS (CLIENT_ID, WAITING_TIME, SERVICE_TIME, REG_DT, CALL_DT, SESSION_STATUS, USER_ID, DEPARTMENT_ID, TICKET, OPERATION_ID,
                                                      OPERATION_NAME_RU,
                                                      OPERATION_NAME_EN, OPERATION_NAME_CUSTOM1, OPERATION_NAME_CUSTOM2, OPERATION_NAME_CUSTOM3, WORKPLACE_ID, WORKPLACE_NAME_RU,
                                                      WORKPLACE_NAME_EN, WORKPLACE_NAME_CUSTOM, OPERATOR_NAME, FINISH_EVENT_TYPE_ID)
                    VALUES (EVENT_LOOP.CLIENT_ID, 0, 0, EVENT_LOOP.DATE_TIME_COLUMN, EVENT_LOOP.DATE_TIME_COLUMN, 0, EVENT_LOOP.USER_ID, EVENT_LOOP.DEPARTMENT_ID,
                            CONCAT(EVENT_LOOP.CLIENT_TICKET_LETTER, EVENT_LOOP.CLIENT_TICKET_NUMBER), EVENT_LOOP.OPERATION_ID,
                            EVENT_LOOP.OPERATION_NAME_RU, EVENT_LOOP.OPERATION_NAME_EN, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE1, EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE2,
                            EVENT_LOOP.OPERATION_NAME_CUSTOM_LANGUAGE3,
                            EVENT_LOOP.WORKPLACE_ID, EVENT_LOOP.WORKPLACE_NAME_RU, EVENT_LOOP.WORKPLACE_NAME_EN, EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                            CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ', EVENT_LOOP.USER_LAST_NAME), EVENT_LOOP.EVENT_TYPE_ID);
                END IF;

            END IF;

            -- ВЫЗОВ КЛИЕНТА [%S%S] ПО УСЛУГЕ [%S].
            IF EVENT_LOOP.EVENT_TYPE_ID = 10 THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET WAITING_TIME          = TCS.WAITING_TIME +
                                            DATE_DIFF('SECOND', TCS.REG_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    CALL_DT               = EVENT_LOOP.DATE_TIME_COLUMN,
                    USER_ID               = EVENT_LOOP.USER_ID,
                    OPERATOR_NAME         = CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ', EVENT_LOOP.USER_LAST_NAME),
                    WORKPLACE_ID          = EVENT_LOOP.WORKPLACE_ID,
                    WORKPLACE_NAME_RU     = EVENT_LOOP.WORKPLACE_NAME_RU,
                    WORKPLACE_NAME_EN     = EVENT_LOOP.WORKPLACE_NAME_EN,
                    WORKPLACE_NAME_CUSTOM = EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                    FINISH_EVENT_TYPE_ID  = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS        = 1
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ПЕРЕВОД КЛИЕНТА [%S%S] ИЗ ОКНА [%S] В ОКНО [%S]. ПРИЧИНА ПЕРЕВОДА: [%S].
            -- НАЗНАЧЕНИЕ КЛИЕНТА [%S%S] ОКНУ [%S]. ПРИЧИНА ПЕРЕВОДА: [%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID IN (15, 23)) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME          = TCS.SERVICE_TIME +
                                            DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    REG_DT                = EVENT_LOOP.DATE_TIME_COLUMN,
                    OPERATOR_NAME         = CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ', EVENT_LOOP.USER_LAST_NAME),
                    WORKPLACE_ID          = EVENT_LOOP.WORKPLACE_ID,
                    WORKPLACE_NAME_RU     = EVENT_LOOP.WORKPLACE_NAME_RU,
                    WORKPLACE_NAME_EN     = EVENT_LOOP.WORKPLACE_NAME_EN,
                    WORKPLACE_NAME_CUSTOM = EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                    FINISH_EVENT_TYPE_ID  = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS        = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ОТКЛАДЫВАНИЕ КЛИЕНТА [%S%S] НА [%D] МИНУТ.
            -- СБРОС КЛИЕНТА [%S%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID IN (19, 22)) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME         = TCS.SERVICE_TIME +
                                           DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS       = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ВОЗВРАЩЕНИЕ КЛИЕНТА [%S%S] В ОЧЕРЕДЬ.
            IF (EVENT_LOOP.EVENT_TYPE_ID = 20) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET REG_DT               = EVENT_LOOP.DATE_TIME_COLUMN,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS       = 0
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- ЗАВЕРШЕНИЕ ОБСЛУЖИВАНИЯ КЛИЕНТА [%S%S] ПО УСЛУГЕ [%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID = 11) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME          = TCS.SERVICE_TIME +
                                            DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    FINISH_DT             = EVENT_LOOP.DATE_TIME_COLUMN,
                    USER_ID               = EVENT_LOOP.USER_ID,
                    OPERATOR_NAME         = CONCAT(EVENT_LOOP.USER_FIRST_NAME, ' ', EVENT_LOOP.USER_LAST_NAME),
                    WORKPLACE_ID          = EVENT_LOOP.WORKPLACE_ID,
                    WORKPLACE_NAME_RU     = EVENT_LOOP.WORKPLACE_NAME_RU,
                    WORKPLACE_NAME_EN     = EVENT_LOOP.WORKPLACE_NAME_EN,
                    WORKPLACE_NAME_CUSTOM = EVENT_LOOP.WORKPLACE_NAME_CUSTOM_LANGUAGE,
                    FINISH_EVENT_TYPE_ID  = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS        = 2
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;

            -- УДАЛЕНИЕ КЛИЕНТА [%S%S].
            IF (EVENT_LOOP.EVENT_TYPE_ID = 21) THEN
                UPDATE TEMP_CLIENT_SESSIONS TCS
                SET SERVICE_TIME         = TCS.SERVICE_TIME +
                                           DATE_DIFF('SECOND', TCS.CALL_DT::TIMESTAMP, EVENT_LOOP.DATE_TIME_COLUMN::TIMESTAMP),
                    FINISH_DT            = EVENT_LOOP.DATE_TIME_COLUMN,
                    FINISH_EVENT_TYPE_ID = EVENT_LOOP.EVENT_TYPE_ID,
                    SESSION_STATUS       = 3
                WHERE EVENT_LOOP.CLIENT_ID = TCS.CLIENT_ID;
            END IF;
        END LOOP;

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ.
    RETURN QUERY
        SELECT TCS.CLIENT_ID,
               TCS.WAITING_TIME,
               TCS.SERVICE_TIME,
               TCS.REG_DT,
               TCS.CALL_DT,
               TCS.FINISH_DT,
               TCS.SESSION_STATUS,
               TCS.DEPARTMENT_ID,
               TCS.USER_ID,
               TCS.TICKET,
               TCS.OPERATION_ID,
               TCS.OPERATION_NAME_RU,
               TCS.OPERATION_NAME_EN,
               TCS.OPERATION_NAME_CUSTOM1,
               TCS.OPERATION_NAME_CUSTOM2,
               TCS.OPERATION_NAME_CUSTOM3,
               TCS.WORKPLACE_ID,
               TCS.WORKPLACE_NAME_RU,
               TCS.WORKPLACE_NAME_EN,
               TCS.WORKPLACE_NAME_CUSTOM,
               TCS.OPERATOR_NAME,
               TCS.FINISH_EVENT_TYPE_ID
        FROM TEMP_CLIENT_SESSIONS TCS;

    -- УДАЛИТЬ ВРЕМЕННУЮ ТАБЛИЦУ.
    DROP TABLE TEMP_CLIENT_SESSIONS;
END;
$$;

-- Исправлены ошибки в функции REPORT_PRE_RECORDING.
DROP FUNCTION IF EXISTS REPORT_PRE_RECORDING;
CREATE FUNCTION REPORT_PRE_RECORDING(IN_DEPARTMENT_ID BIGINT,
                                    IN_DATE_START TIMESTAMP,
                                    IN_DATE_END TIMESTAMP,
                                    IN_PREV_PAGE_LAST_ID BIGINT,
                                    IN_PAGE_SIZE BIGINT,
                                    IN_ORDER_BY_COLUMN_ID INTEGER,
                                    IN_IS_DESCENDING BOOLEAN,
                                    IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID                                                BIGINT,
                DEPARTMENT_NAME                                   TEXT,
                SERVICE_DATE                                      TIMESTAMP,
                OPERATION_NAME                                    TEXT,
                TOTAL_PRE_REGISTRATION_TICKETS                    NUMERIC,
                NUMBER_OF_TICKETS_IN_DEMAND                       NUMERIC,
                PERCENTAGE_OF_DEMANDED_TICKET                     NUMERIC,
                NUMBER_OF_UNCLAIMED_TICKET                        NUMERIC,
                PERCENTAGE_OF_UNCLAIMED_TICKET                    NUMERIC,
                NUMBER_RECEIVED_VIA_INTERNET                      NUMERIC,
                PERCENTAGE_RECEIVED_OVER_INTERNET                 NUMERIC,
                NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE     NUMERIC,
                PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE NUMERIC,
                NUMBER_RECEIVED_THROUGH_TICKET_KIOSK              NUMERIC,
                PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK          NUMERIC
            )
    SECURITY DEFINER
    LANGUAGE PLPGSQL
AS
$$
DECLARE
    V_DEPARTMENT_ID BIGINT;
BEGIN
    -- ЗАДАТЬ ЗНАЧЕНИЕ ПЕРЕМЕННОЙ ДЛЯ ФИЛЬТРАЦИИ ПО ОТДЕЛЕНИЮ.
    V_DEPARTMENT_ID = CASE WHEN IN_DEPARTMENT_ID = -1 THEN NULL ELSE IN_DEPARTMENT_ID END;
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ОБРАБОТКИ ДАННЫХ.
    CREATE TEMPORARY TABLE TEMP_RESULT_EVENTS
    (
        ID                                                BIGINT,    -- НОМЕР СТРОКИ, ID
        DEPARTMENT_NAME                                   TEXT,      -- ОТДЕЛЕНИЕ
        SERVICE_DATE                                      TIMESTAMP, -- ДАТА
        OPERATION_NAME                                    TEXT,      -- УСЛУГА
        TOTAL_PRE_REGISTRATION_TICKETS                    NUMERIC,   -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
        NUMBER_OF_TICKETS_IN_DEMAND                       NUMERIC,   -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
        PERCENTAGE_OF_DEMANDED_TICKET                     NUMERIC,   -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, %
        NUMBER_OF_UNCLAIMED_TICKET                        NUMERIC,   -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
        PERCENTAGE_OF_UNCLAIMED_TICKET                    NUMERIC,   -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, %
        NUMBER_RECEIVED_VIA_INTERNET                      NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
        PERCENTAGE_RECEIVED_OVER_INTERNET                 NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, %
        NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE     NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
        PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, %
        NUMBER_RECEIVED_THROUGH_TICKET_KIOSK              NUMERIC,   -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
        PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK          NUMERIC    -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, %
    ) ON COMMIT DROP;

    -- СОЗДАТЬ ОТФИЛЬТРОВАННУЮ КОПИЮ ТАБЛИЦЫ EVENT.
    CREATE TEMPORARY TABLE POST_FILTERING_EVENTS ON COMMIT DROP AS
    SELECT E.*
    FROM EVENT E
    WHERE CASE
              WHEN E.PRE_REGISTRATION_START_SERVICE_DATE_TIME IS NOT NULL THEN (E.PRE_REGISTRATION_START_SERVICE_DATE_TIME BETWEEN IN_DATE_START AND IN_DATE_END)
              ELSE (E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END)
        END
      AND E.CLIENT_CONFIRMATION_CODE IS NOT NULL
      AND E.CLIENT_CONFIRMATION_CODE NOT IN
          (SELECT E.CLIENT_CONFIRMATION_CODE
           FROM EVENT E
           WHERE CASE
                     WHEN E.PRE_REGISTRATION_START_SERVICE_DATE_TIME IS NOT NULL THEN (E.PRE_REGISTRATION_START_SERVICE_DATE_TIME BETWEEN IN_DATE_START AND IN_DATE_END)
                     ELSE (E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END)
               END
             AND E.EVENT_TYPE_ID = 44
             AND E.CLIENT_CONFIRMATION_CODE IS NOT NULL)
      AND E.CLIENT_CONFIRMATION_CODE NOT IN (SELECT E.CLIENT_CONFIRMATION_CODE
                                             FROM (SELECT E.CLIENT_CONFIRMATION_CODE, MAX(E.EVENT_TYPE_ID), MAX(E.EVENT_TYPE_NAME_RU), MAX(E.DATE_TIME_COLUMN), MAX(E.DEPARTMENT_ID)
                                                   FROM EVENT E
                                                   WHERE CASE
                                                             WHEN E.PRE_REGISTRATION_START_SERVICE_DATE_TIME IS NOT NULL
                                                                 THEN (E.PRE_REGISTRATION_START_SERVICE_DATE_TIME BETWEEN IN_DATE_START AND IN_DATE_END)
                                                             ELSE (E.DATE_TIME_COLUMN BETWEEN IN_DATE_START AND IN_DATE_END)
                                                       END
                                                     AND E.CLIENT_CONFIRMATION_CODE IS NOT NULL
                                                   GROUP BY E.CLIENT_CONFIRMATION_CODE
                                                   HAVING MAX(E.DEPARTMENT_ID) <> V_DEPARTMENT_ID) E);

    -- ОБРАБОТАТЬ ДАННЫЕ И ПОМЕСТИТЬ ВО ВРЕМЕННУЮ ТАБЛИЦУ.
    INSERT INTO TEMP_RESULT_EVENTS (ID, -- НОМЕР СТРОКИ, ID
                                    DEPARTMENT_NAME, -- ОТДЕЛЕНИЕ
                                    SERVICE_DATE, -- ДАТА
                                    OPERATION_NAME, -- УСЛУГА
                                    TOTAL_PRE_REGISTRATION_TICKETS, -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                                    NUMBER_OF_TICKETS_IN_DEMAND, -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                                    NUMBER_OF_UNCLAIMED_TICKET, -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                                    NUMBER_RECEIVED_VIA_INTERNET, -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
                                    NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE, -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
                                    NUMBER_RECEIVED_THROUGH_TICKET_KIOSK -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
    )
    SELECT ROW_NUMBER() OVER (PARTITION BY 1)                                                                ID,                                            -- НОМЕР СТРОКИ
           MAX(CASE
                   WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                       THEN PFE.DEPARTMENT_NAME_EN
                   WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                       THEN PFE.DEPARTMENT_NAME_RU
                   ELSE PFE.DEPARTMENT_NAME_CUSTOM_LANGUAGE -- КАСТОМНЫЙ ЯЗЫК
               END)                                                                                          DEPARTMENT_NAME,                               -- ОТДЕЛЕНИЕ
           MAX(DATE(CASE
                        WHEN PFE.PRE_REGISTRATION_START_SERVICE_DATE_TIME IS NULL THEN PFE.DATE_TIME_COLUMN
                        ELSE PFE.PRE_REGISTRATION_START_SERVICE_DATE_TIME END))                              SERVICE_DATE,                                  -- ДАТА
           CASE
               WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                   THEN PFE.OPERATION_NAME_EN
               WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                   THEN PFE.OPERATION_NAME_RU
               ELSE
                   CASE
                       WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE1 IS NOT NULL THEN
                           PFE.OPERATION_NAME_CUSTOM_LANGUAGE1
                       WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE2 IS NOT NULL THEN
                           PFE.OPERATION_NAME_CUSTOM_LANGUAGE2
                       WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 IS NOT NULL THEN
                           PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 -- КАСТОМНЫЙ ЯЗЫК
                       END
               END                                                                                           OPERATION_NAME,                                -- НАИМЕНОВАНИЕ УСЛУГИ
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 ))            TOTAL_PRE_REGISTRATION_TICKETS,                -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
           COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID IN (11, 15, 19) )   NUMBER_OF_TICKETS_IN_DEMAND,                   -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 ) -
            COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE) FILTER ( WHERE PFE.EVENT_TYPE_ID IN (11, 15, 19) )) NUMBER_OF_UNCLAIMED_TICKET,                    -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE)
            FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 AND PFE.WAY_OF_QUEUING_ID = 2 ))                           NUMBER_RECEIVED_VIA_INTERNET,                  -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE)
            FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 AND PFE.WAY_OF_QUEUING_ID = 3 ))                           NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE, -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
           (COUNT(DISTINCT PFE.CLIENT_CONFIRMATION_CODE)
            FILTER ( WHERE PFE.EVENT_TYPE_ID = 42 AND PFE.WAY_OF_QUEUING_ID = 1 ))                           NUMBER_RECEIVED_THROUGH_TICKET_KIOSK           -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
    FROM POST_FILTERING_EVENTS PFE
    GROUP BY PFE.DEPARTMENT_ID,
             DATE(CASE WHEN PFE.PRE_REGISTRATION_START_SERVICE_DATE_TIME IS NULL THEN PFE.DATE_TIME_COLUMN ELSE PFE.PRE_REGISTRATION_START_SERVICE_DATE_TIME END),
             CASE
                 WHEN IN_CURRENT_LANGUAGE_ID = 41 -- АНГЛИЙСКИЙ
                     THEN PFE.OPERATION_NAME_EN
                 WHEN IN_CURRENT_LANGUAGE_ID = 134 -- РУССКИЙ
                     THEN PFE.OPERATION_NAME_RU
                 ELSE
                     CASE
                         WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE1 IS NOT NULL THEN
                             PFE.OPERATION_NAME_CUSTOM_LANGUAGE1
                         WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE2 IS NOT NULL THEN
                             PFE.OPERATION_NAME_CUSTOM_LANGUAGE2
                         WHEN PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 IS NOT NULL THEN
                             PFE.OPERATION_NAME_CUSTOM_LANGUAGE3 -- КАСТОМНЫЙ ЯЗЫК
                         END
                 END;

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ TEMP_RESULT_EVENTS, ДОБАВИТЬ СОРТИРОВКУ, ПАГИНАЦИЮ И ИТОГИ.
    RETURN QUERY
        (SELECT TRE.ID,                                                                                                                                                                  -- НОМЕР СТРОКИ, ID
                TRE.DEPARTMENT_NAME,                                                                                                                                                     -- ОТДЕЛЕНИЕ
                TRE.SERVICE_DATE,                                                                                                                                                        -- ДАТА
                TRE.OPERATION_NAME,                                                                                                                                                      -- УСЛУГА
                TRE.TOTAL_PRE_REGISTRATION_TICKETS,                                                                                                                                      -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                TRE.NUMBER_OF_TICKETS_IN_DEMAND,                                                                                                                                         -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                CASE
                    WHEN TRE.NUMBER_OF_TICKETS_IN_DEMAND = 0 THEN 0
                    ELSE (TRE.NUMBER_OF_TICKETS_IN_DEMAND / SUM(TRE.NUMBER_OF_TICKETS_IN_DEMAND) OVER ()) * 100 END                   PERCENTAGE_OF_DEMANDED_TICKET,                     -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                TRE.NUMBER_OF_UNCLAIMED_TICKET,                                                                                                                                          -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                CASE
                    WHEN TRE.NUMBER_OF_UNCLAIMED_TICKET = 0 THEN 0
                    ELSE (TRE.NUMBER_OF_UNCLAIMED_TICKET / SUM(TRE.NUMBER_OF_UNCLAIMED_TICKET) OVER ()) * 100 END                     PERCENTAGE_OF_UNCLAIMED_TICKET,                    -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                TRE.NUMBER_RECEIVED_VIA_INTERNET,                                                                                                                                        -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
                CASE
                    WHEN TRE.NUMBER_RECEIVED_VIA_INTERNET = 0 THEN 0
                    ELSE (TRE.NUMBER_RECEIVED_VIA_INTERNET / SUM(TRE.NUMBER_RECEIVED_VIA_INTERNET) OVER ()) * 100 END                 PERCENTAGE_RECEIVED_OVER_INTERNET,                 -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, %
                TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE,                                                                                                                       -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
                CASE
                    WHEN TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE = 0 THEN 0
                    ELSE (TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE / SUM(TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE) OVER ()) *
                         100 END                                                                                                      PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE, -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, %
                TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK,                                                                                                                                -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
                CASE
                    WHEN TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK = 0 THEN 0
                    ELSE (TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK / SUM(TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK) OVER ()) * 100 END PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK           -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, %
         FROM TEMP_RESULT_EVENTS TRE
         WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN TRE.ID > IN_PREV_PAGE_LAST_ID ELSE TRE.ID < IN_PREV_PAGE_LAST_ID END
         ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN TRE.ID END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN TRE.ID END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN TRE.DEPARTMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN TRE.DEPARTMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN TRE.SERVICE_DATE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN TRE.SERVICE_DATE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN TRE.OPERATION_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN TRE.OPERATION_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN TRE.TOTAL_PRE_REGISTRATION_TICKETS END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN TRE.TOTAL_PRE_REGISTRATION_TICKETS END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_OF_TICKETS_IN_DEMAND END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_OF_TICKETS_IN_DEMAND END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_OF_DEMANDED_TICKET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_OF_DEMANDED_TICKET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_OF_UNCLAIMED_TICKET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_OF_UNCLAIMED_TICKET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_OF_UNCLAIMED_TICKET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_OF_UNCLAIMED_TICKET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_RECEIVED_VIA_INTERNET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_RECEIVED_VIA_INTERNET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_RECEIVED_OVER_INTERNET END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_RECEIVED_OVER_INTERNET END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 12 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 13 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = TRUE THEN TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 14 AND IN_IS_DESCENDING = FALSE THEN TRE.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = TRUE THEN TRE.PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 15 AND IN_IS_DESCENDING = FALSE THEN TRE.PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK END) ASC
         LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END
        )
        UNION ALL
        (SELECT MAX(TRE2.ID) + 1                                                                              ID,                                                -- НОМЕР СТРОКИ, ID
                NULL                                                                                          DEPARTMENT_NAME,                                   -- ОТДЕЛЕНИЕ
                NULL                                                                                          SERVICE_DATE,                                      -- ДАТА
                NULL                                                                                          OPERATION_NAME,                                    -- УСЛУГА
                SUM(TRE2.TOTAL_PRE_REGISTRATION_TICKETS)                                                      TOTAL_PRE_REGISTRATION_TICKETS,                    -- ВСЕГО ТАЛОНОВ ПРЕДВАРИТЕЛЬНОЙ ЗАПИСИ
                SUM(TRE2.NUMBER_OF_TICKETS_IN_DEMAND)                                                         NUMBER_OF_TICKETS_IN_DEMAND,                       -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                CASE WHEN SUM(TRE2.PERCENTAGE_OF_DEMANDED_TICKET) = 0 THEN 0 ELSE 100 END                     PERCENTAGE_OF_DEMANDED_TICKET,                     -- ВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                SUM(TRE2.NUMBER_OF_UNCLAIMED_TICKET)                                                          NUMBER_OF_UNCLAIMED_TICKET,                        -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, N
                CASE WHEN SUM(TRE2.PERCENTAGE_OF_UNCLAIMED_TICKET) = 0 THEN 0 ELSE 100 END                    PERCENTAGE_OF_UNCLAIMED_TICKET,                    -- НЕВОСТРЕБОВАННЫХ ТАЛОНОВ, %
                SUM(TRE2.NUMBER_RECEIVED_VIA_INTERNET)                                                        NUMBER_RECEIVED_VIA_INTERNET,                      -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, N
                CASE WHEN SUM(TRE2.PERCENTAGE_RECEIVED_OVER_INTERNET) = 0 THEN 0 ELSE 100 END                 PERCENTAGE_RECEIVED_OVER_INTERNET,                 -- ПОЛУЧЕНО ЧЕРЕЗ ИНТЕРНЕТ, %
                SUM(TRE2.NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE)                                       NUMBER_RECEIVED_THROUGH_ADMINISTRATION_MODULE,     -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, N
                CASE WHEN SUM(TRE2.PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE) = 0 THEN 0 ELSE 100 END PERCENTAGE_RECEIVED_THROUGH_ADMINISTRATION_MODULE, -- ПОЛУЧЕНО ЧЕРЕЗ МОДУЛЬ АДМИНИСТРИРОВАНИЯ, %
                SUM(TRE2.NUMBER_RECEIVED_THROUGH_TICKET_KIOSK)                                                NUMBER_RECEIVED_THROUGH_TICKET_KIOSK,              -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, N
                CASE WHEN SUM(TRE2.PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK) = 0 THEN 0 ELSE 100 END          PERCENTAGE_RECEIVED_THROUGH_TICKET_KIOSK           -- ПОЛУЧЕНО ЧЕРЕЗ РЕГИСТРАТОР, %
         FROM TEMP_RESULT_EVENTS TRE2);
END
$$;