


------------------------------------------------ REPORT_OPERATOR_WORK_SUMMARY-------------------------------------------------
DROP FUNCTION IF EXISTS REPORT_OPERATOR_WORK_SUMMARY;

CREATE FUNCTION REPORT_OPERATOR_WORK_SUMMARY(IN_DEPARTMENTID BIGINT, IN_DATESTART TIMESTAMP WITHOUT TIME ZONE, IN_DATEEND TIMESTAMP WITHOUT TIME ZONE, IN_USERID BIGINT,
                                             IN_GROUPMONTH BOOLEAN, IN_GROUPDAY BOOLEAN, IN_GROUPHOUR BOOLEAN, IN_GROUPDEPARTMENTID BOOLEAN, IN_GROUPUSERID BOOLEAN,
                                             IN_PREV_PAGE_LAST_ID BIGINT, IN_PAGE_SIZE BIGINT, IN_ORDER_BY_COLUMN_ID INTEGER, IN_IS_DESCENDING BOOLEAN,
                                             IN_CURRENT_LANGUAGE_ID BIGINT)
    RETURNS TABLE
            (
                ID                  BIGINT,
                YEAR                INTEGER,
                MONTH               INTEGER,
                DAY                 INTEGER,
                HOUR                INTEGER,
                DEPARTMENT_NAME     TEXT,
                USER_NAME           TEXT,
                SUM_WORKPLACE_TIME  NUMERIC,
                CLIENT_SERVICE_TIME NUMERIC,
                DOWNTIME            NUMERIC,
                DOWNTIME_PERCENT    NUMERIC
            )
    SECURITY DEFINER
    LANGUAGE PLPGSQL
AS
$$
BEGIN
    -- СОЗДАТЬ ВРЕМЕННУЮ ТАБЛИЦУ ДЛЯ ОБРАБОТКИ ДАННЫХ.
    CREATE TEMPORARY TABLE TABLE_OPERATOR
    (
        ID              BIGINT,
        DT_YEAR         INT,
        DT_MONTH        INT,
        DT_DAY          INT,
        DT_HOUR         INT,

        DEPARTMENT_ID   BIGINT,
        DEPARTMENT_NAME TEXT,
        USER_ID         BIGINT,
        USER_NAME       TEXT,

        SESSION_TIME    NUMERIC,
        SERVICE_TIME    INTEGER
    ) ON COMMIT DROP;

    CREATE TEMPORARY TABLE TEMP_RESULT_TABLE
    (
        ID                  BIGINT,  -- НОМЕР СТРОКИ
        DT_YEAR             INT,
        DT_MONTH            INT,
        DT_DAY              INT,
        DT_HOUR             INT,

        DEPARTMENT_NAME     TEXT,    -- ОТДЕЛЕНИЕ
        USER_NAME           TEXT,
        SUM_WORKPLACE_TIME  NUMERIC, -- СУММАРНОЕ НАХОЖДЕНИЕ НА РАБОЧЕМ МЕСТЕ
        CLIENT_SERVICE_TIME NUMERIC, -- ВРЕМЯ ОБСЛУЖИВАНИЯ КЛИЕНТОВ
        DOWNTIME            NUMERIC, -- (В Q2 - ВРЕМЯ ПРОСТОЯ)
        DOWNTIME_PERCENT    NUMERIC  -- ПРОЦЕНТ ВРЕМЕНИ ПРОСТОЯ ОТ ВРЕМЕНИ НАХОЖДЕНИЯ ЗА СТОЙКОЙ, %
    ) ON COMMIT DROP;

    INSERT INTO TABLE_OPERATOR(ID,
                               DT_YEAR,
                               DT_MONTH,
                               DT_DAY,
                               DT_HOUR,
                               DEPARTMENT_ID,
                               DEPARTMENT_NAME,
                               USER_ID,
                               USER_NAME,
                               SESSION_TIME,
                               SERVICE_TIME)
    SELECT ROW_NUMBER() OVER (PARTITION BY 1),
           DATE_PART('YEAR', MIN(O.START_DT)),
           DATE_PART('MONTH', MIN(O.START_DT)),
           DATE_PART('DAY', MIN(O.START_DT)),
           DATE_PART('HOUR', MIN(O.START_DT)),
           MAX(O.DEPARTMENT_ID),
           MAX(O.DEPARTMENT_NAME),
           MAX(O.USER_ID),
           CASE
               WHEN MAX(O.USER_FIRST_NAME) || ' ' || MAX(O.USER_MIDDLE_NAME) || ' ' || MAX(O.USER_LAST_NAME) IS NOT NULL THEN
                   MAX(O.USER_FIRST_NAME) || ' ' || MAX(O.USER_MIDDLE_NAME) || ' ' || MAX(O.USER_LAST_NAME)
               ELSE MAX(O.USER_LOGIN) END,

           CASE WHEN FINISH_DT=START_DT  THEN MAX(DATE_DIFF('SECOND', START_DT, now()))
              ELSE MAX(DATE_DIFF('SECOND', START_DT, FINISH_DT)) END,
           (SELECT SUM(CS.SERVICE_TIME)
            FROM GET_CLIENT_SESSIONS(IN_DATESTART, IN_DATEEND, IN_DEPARTMENTID) CS
            WHERE CS.DEPARTMENT_ID = O.DEPARTMENT_ID
              AND CS.USER_ID = O.USER_ID)
    FROM GET_OPERATOR_SESSIONS(IN_DATESTART, IN_DATEEND, IN_CURRENT_LANGUAGE_ID) O
    WHERE ((O.START_DT BETWEEN IN_DATESTART AND IN_DATEEND) OR
           (O.FINISH_DT BETWEEN IN_DATESTART AND IN_DATEEND))
      AND (O.USER_ID = IN_USERID OR IN_USERID = -1)
      --GROUP BY O.DEPARTMENT_ID, O.SESSION_ID, O.USER_ID;
    GROUP BY O.DEPARTMENT_ID, O.ID, O.USER_ID;

    INSERT INTO TEMP_RESULT_TABLE(ID, -- НОМЕР СТРОКИ
                                  DT_YEAR, -- ГОД
                                  DT_MONTH, -- МЕСЯЦ
                                  DT_DAY, -- ДЕНЬ
                                  DT_HOUR, -- ЧАС

                                  DEPARTMENT_NAME, -- ОТДЕЛЕНИЕ
                                  USER_NAME,
                                  SUM_WORKPLACE_TIME, -- СУММАРНОЕ НАХОЖДЕНИЕ НА РАБОЧЕМ МЕСТЕ
                                  CLIENT_SERVICE_TIME, -- ВРЕМЯ ОБСЛУЖИВАНИЯ КЛИЕНТОВ
                                  DOWNTIME, -- (В Q2 - ВРЕМЯ ПРОСТОЯ)
                                  DOWNTIME_PERCENT -- ПРОЦЕНТ ВРЕМЕНИ ПРОСТОЯ ОТ ВРЕМЕНИ НАХОЖДЕНИЯ ЗА СТОЙКОЙ, %
    )
        (SELECT MAX(T.ID)                                                                                                                                  ID,
                MAX(T.DT_YEAR)                                                                                                                             DT_YEAR,
                MAX(T.DT_MONTH)                                                                                                                            DT_MONTH,
                MAX(T.DT_DAY)                                                                                                                              DT_DAY,
                MAX(T.DT_HOUR)                                                                                                                             DT_HOUR,
                MAX(T.DEPARTMENT_NAME)                                                                                                                     DEPARTMENT_NAME,
                MAX(T.USER_NAME)                                                                                                                           USER_NAME,
                SUM(T.SESSION_TIME) + 0                                                                                                                    SUM_WORKPLACE_TIME,
                SUM(T.SERVICE_TIME) + 0                                                                                                                    CLIENT_SERVICE_TIME,
                CASE WHEN SUM(T.SESSION_TIME) IS NOT NULL AND SUM(T.SERVICE_TIME) IS NOT NULL THEN SUM(T.SESSION_TIME) - SUM(T.SERVICE_TIME) ELSE 0 END AS DOWNTIME,
                CASE WHEN SUM(T.SESSION_TIME) > 0 THEN (1 - SUM(T.SERVICE_TIME) / SUM(T.SESSION_TIME)) * 100 END                                        AS DOWNTIME_PERCENT
         FROM TABLE_OPERATOR T
         GROUP BY CASE WHEN IN_GROUPMONTH = TRUE OR IN_GROUPDAY = TRUE OR IN_GROUPHOUR = TRUE THEN T.DT_YEAR ELSE NULL END,
                  CASE WHEN IN_GROUPMONTH = TRUE OR IN_GROUPDAY = TRUE OR IN_GROUPHOUR = TRUE THEN T.DT_MONTH ELSE NULL END,
                  CASE WHEN IN_GROUPDAY = TRUE OR IN_GROUPHOUR = TRUE THEN T.DT_DAY ELSE NULL END,
                  CASE WHEN IN_GROUPHOUR = TRUE THEN T.DT_HOUR ELSE NULL END,
                  CASE WHEN IN_GROUPDEPARTMENTID = TRUE OR IN_GROUPUSERID = TRUE THEN T.DEPARTMENT_ID ELSE NULL END,
                  CASE WHEN IN_GROUPUSERID = TRUE THEN T.USER_ID ELSE NULL END,
                  CASE
                      WHEN NOT (IN_GROUPMONTH = TRUE OR
                                IN_GROUPDAY = TRUE OR
                                IN_GROUPHOUR = TRUE OR
                                IN_GROUPDEPARTMENTID = TRUE OR
                                IN_GROUPUSERID = TRUE) THEN T.ID
                      ELSE NULL END);

    -- ВЕРНУТЬ РЕЗУЛЬТАТ РАБОТЫ ФУНКЦИИ ИЗ ВРЕМЕННОЙ ТАБЛИЦЫ TEMP_RESULT_TABLE, ДОБАВИТЬ СОРТИРОВКУ, ПАГИНАЦИЮ И ИТОГИ.
    RETURN QUERY
        (SELECT TRT.ID,
                TRT.DT_YEAR,
                TRT.DT_MONTH,
                TRT.DT_DAY,
                TRT.DT_HOUR,
                TRT.DEPARTMENT_NAME,
                TRT.USER_NAME,
                TRT.SUM_WORKPLACE_TIME,
                TRT.CLIENT_SERVICE_TIME,
                TRT.DOWNTIME,
                TRT.DOWNTIME_PERCENT
         FROM TEMP_RESULT_TABLE TRT
         WHERE CASE WHEN IN_IS_DESCENDING = FALSE THEN TRT.ID > IN_PREV_PAGE_LAST_ID ELSE TRT.ID < IN_PREV_PAGE_LAST_ID END
         ORDER BY (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = TRUE THEN TRT.ID END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 1 AND IN_IS_DESCENDING = FALSE THEN TRT.ID END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = TRUE THEN TRT.DT_YEAR END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 2 AND IN_IS_DESCENDING = FALSE THEN TRT.DT_YEAR END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = TRUE THEN TRT.DT_MONTH END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 3 AND IN_IS_DESCENDING = FALSE THEN TRT.DT_MONTH END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = TRUE THEN TRT.DT_DAY END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 4 AND IN_IS_DESCENDING = FALSE THEN TRT.DT_DAY END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = TRUE THEN TRT.DT_HOUR END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 5 AND IN_IS_DESCENDING = FALSE THEN TRT.DT_HOUR END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = TRUE THEN TRT.DEPARTMENT_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 6 AND IN_IS_DESCENDING = FALSE THEN TRT.DEPARTMENT_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = TRUE THEN TRT.USER_NAME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 7 AND IN_IS_DESCENDING = FALSE THEN TRT.USER_NAME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = TRUE THEN TRT.SUM_WORKPLACE_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 8 AND IN_IS_DESCENDING = FALSE THEN TRT.SUM_WORKPLACE_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = TRUE THEN TRT.CLIENT_SERVICE_TIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 9 AND IN_IS_DESCENDING = FALSE THEN TRT.CLIENT_SERVICE_TIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = TRUE THEN TRT.DOWNTIME END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 10 AND IN_IS_DESCENDING = FALSE THEN TRT.DOWNTIME END) ASC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = TRUE THEN TRT.DOWNTIME_PERCENT END) DESC,
                  (CASE WHEN IN_ORDER_BY_COLUMN_ID = 11 AND IN_IS_DESCENDING = FALSE THEN TRT.DOWNTIME_PERCENT END) ASC

         LIMIT CASE WHEN IN_PAGE_SIZE = -1 THEN NULL ELSE IN_PAGE_SIZE END
        )
        UNION ALL
        (SELECT MAX(TRT2.ID) + 1                                                                                                            ID,
                NULL                                                                                                                        DATE_YEAR,           -- ГОД
                NULL                                                                                                                        DATE_MONTH,          -- МЕСЯЦ
                NULL                                                                                                                        DATE_DAY,            -- ДЕНЬ
                NULL                                                                                                                        DATE_HOUR,           -- ЧАС
                NULL                                                                                                                        DEPARTMENT_NAME,     -- ОТДЕЛЕНИЕ, NAME
                NULL                                                                                                                        USER_NAME,           -- ОТДЕЛЕНИЕ, NAME
                SUM(TRT2.SUM_WORKPLACE_TIME) + 0                                                                                            SUM_WORKPLACE_TIME,  -- СУММАРНОЕ ВРЕМЯ ЗА РАБОЧИМ МЕСТОМ
                SUM(TRT2.CLIENT_SERVICE_TIME) + 0                                                                                           CLIENT_SERVICE_TIME, -- СУММАРНОЕ ВРЕМЯ ОБСЛУЖИВАНИЯ
                CASE
                    WHEN SUM(TRT2.SUM_WORKPLACE_TIME) is not null and SUM(TRT2.SUM_WORKPLACE_TIME) is not null
                        THEN SUM(TRT2.SUM_WORKPLACE_TIME) - SUM(TRT2.CLIENT_SERVICE_TIME)
                    ELSE 0 END                                                                                                              DOWNTIME,
                CASE WHEN SUM(TRT2.SUM_WORKPLACE_TIME) > 0 THEN (1 - SUM(TRT2.CLIENT_SERVICE_TIME) / SUM(TRT2.SUM_WORKPLACE_TIME)) * 100 END DOWNTIME_PERCENT
         FROM TEMP_RESULT_TABLE TRT2);

END
$$;